@@ -194,19 +194,15 @@ typedef GList measurenode;
 typedef struct 
 {
   measurenode *measures; /**< This is a pointer to each measure in the staff */
-  gint sclef; /**< The initial clef see denemo_objects.h clefs */
-  gint skey; /**< The inital keysig. >0=sharps <0 = flats */  
-  gint skey_isminor;  /**< Values 0 = major, 1 = minor, 2 = mode */
-  gint skeyaccs[7]; /**< The initial keysignature. Values -7=Cb... -1=F, 0=C, 1=G...7=C# in a chain of fifths */
-  gint stime1; /**< This is the initial timesig numerator */
-  gint stime2; /**< This is the initial timesig denominator */
-  gint leftmost_clefcontext; /**< The clef for the leftmost measure visible in the window*/
-  gint leftmost_keysigcontext; /**< The keysig at thestart of the leftmost measure visible in the window*/
-  gint leftmost_keywidth; /**< Space allowed for leftmost keysig  */
-  gint leftmost_time1context; /**< The leftmost visible timesig numerator */
-  gint leftmost_time2context; /**< The leftmost visible timesig denominator */
+  clef clef; /**< The initial clef see denemo_objects.h clefs */
+  keysig keysig;
+  timesig timesig;
+  keysig *leftmost_keysig;
+  timesig *leftmost_timesig;
+ 
+  /* we make leftmost_clefcontext a reference to a clef (a pointer) & re-validate leftmost clefcontext in the delete of CLEF object. */
+  clef* leftmost_clefcontext; /**< The clef for the leftmost measure visible in the window*/
 
-  gint leftmost_keyaccs[7]; /**<  The keysig at thestart of the leftmost measure visible in the window */
   gint leftmost_stem_directive; /**< Stem directive at start of leftmost visible measure */
   DenemoContext context;   /**< The Lilypond context in which this staff appears */
   /*
@@ -217,6 +213,7 @@ typedef struct
   gint transposition; /**< Determines if the notes are to be played back at pitch or not */
   gint pos_in_half_lines; /**< I believe this maybe broken. It does not seem to do much*/ 
   gint volume;	/**< Volume used for midi/csound playback */
+  gboolean mute_volume; /**< mute Volume of voices playback */
   /* Back to Hiller stuff */
   GString *staff_name;
   /* RTS: I've introduced the staff name here, the other two are versions
@@ -229,7 +226,7 @@ typedef struct
   gboolean midi_prognum_override; /**< override to allow manually setting prognum + channel */
   guint8 midi_prognum; /**< midi prognum assigned to the staff voice */
   guint8 midi_channel; /**< midi channel assigned to the staff voice */
-  
+  gint jack_midi_out_port; /**< the port number that jackmidi has assigned */ 
   gint space_above; /**< space above the staff used in the denemo gui */
   gint space_below; /**< space below the staff used in the denemo gui */
   gboolean haslyrics; /**< TRUE if the staff has had lyrics attached */
@@ -246,17 +243,17 @@ typedef struct
 			the notes in this staff
 			the data are tone* */
   GString *staff_prolog;/**< Customised version of the LilyPond prolog defining the music of this staff */
-  GString *staff_prolog_insert;/**< LilyPond text to insert into a standard LilyPond staff prolog*/
-  GString *voice_prolog_insert;/**< LilyPond text to insert into a standard LilyPond voice prolog*/
-  GString *lyrics_prolog;/**< Customised version of the LilyPond prolog defining the lyrics of this staff */
-  GString *figures_prolog;/**< Customised version of the LilyPond prolog defining the figured bass of this staff */
-  GString *fakechords_prolog;/**< Customised version of the LilyPond prolog defining the chord symbols of this staff */
+  GList *staff_directives;/**< List of DenemoDirective for the staff context, (only relevant for primary staff)*/
+  GList *voice_directives;/**< List of DenemoDirective for the voice context */
+  GString *lyrics_prolog;/**< (Unused)Customised version of the LilyPond prolog defining the lyrics of this staff */
+  GString *figures_prolog;/**<  (Unused)Customised version of the LilyPond prolog defining the figured bass of this staff */
+  GString *fakechords_prolog;/**<  (Unused)Customised version of the LilyPond prolog defining the chord symbols of this staff */
 }DenemoStaff;
 
 /* The ->data part of each staffnode points to a staff structure */
 
 typedef GList staffnode;/**< The ->data part of each staffnode points to a DenemoStaff structure */
-typedef staffnode *score;
+//typedef staffnode *score;
 
 /* a pair of staffs, used to relate two staffs together */
 typedef struct staff_info
@@ -305,7 +302,8 @@ typedef struct DenemoPrefs
   gboolean overlays; /*< whether overlays or insert should be used with pitch entry */
   gboolean continuous; /*< whether pitch entry overlays should cross barlines */
   gboolean lilyentrystyle;  
-  gboolean createclones; 
+  gboolean createclones;
+  gboolean visible_titles;/*< whether the titles should be shown at the top of the score area */
   gboolean articulation_palette; /**< This switch makes the articulation pallete visable */
   gboolean notation_palette; /**< This switch makes the duration toolbar visable */
   gboolean rhythm_palette; /**< This option makes the rhythm toolbar visable */
@@ -319,6 +317,9 @@ typedef struct DenemoPrefs
   gboolean rtcs; /**< Real time csound */
   GString *sequencer;  /**< path to sequencer device */
   GString *midi_in;  /**< path to midi_in device */
+  gboolean *jacktransport; /**< toggle on and off jack transport */
+  gboolean *jacktransport_start_stopped; /**< toggle if you don't want transport to play immediately but rely on the transport controls */
+  gboolean *jack_at_startup; /**< toggle on and off jack initialization at startup */
   GString *pdfviewer; /**< PDF viewer */
   GString *imageviewer; /**< Image Viewer */
   GString *texteditor; /**< texteditor for editing scripts and lilypond files */
@@ -331,6 +332,27 @@ typedef struct DenemoPrefs
   gint resolution; /**< Resolution of exported selection in dpi */
 }DenemoPrefs;
 
+/* DenemoDirectives are attached to chords and to the individual notes of a chord. They attach LilyPond and MIDI directivees that add to the note information & describe how to display themselves in the Denemo display */
+typedef struct DenemoDirective
+{
+  GString *tag; /**< tag identifying the owner of this directive, usually the denemo command that created it */
+  GString *prefix; /**< LilyPond text to be inserted before the chord */
+  GString *postfix;/**< LilyPond text to be inserted after the chord */
+  GString *display; /**< some text to display to describe the LilyPond attached to the chord */
+  gint tx,ty; /**< x and y offsets in pixels for the display text */
+  gint minpixels;/**< horizontal space needed by the display */
+  gint x, y; /**< x and y offsets passed to LilyPond to control printed position */
+  GdkBitmap *graphic; /**< bitmap to draw for this directive */
+  gint gx, gy; /**< x and y offsets in pixels for the graphic */
+  GString *graphic_name; /**< name of the graphic to be drawn */
+  gint width, height; /**< width and height of the bitmap */
+#define DENEMO_OVERRIDE_LILYPOND (1<<0)
+#define DENEMO_OVERRIDE_GRAPHIC (1<<2)
+  gint override; /**< specifies what if anything of the built-in behaviour of the object the directive is attached to is to be overriden by this directive */
+  gboolean locked;/**< If true the directive cannot be deleted easily */
+  /* MIDI attributes not done yet */
+} DenemoDirective;
+
 /**
  * Contains the lilypond header information for the movements, plus markup between movements.
  *
@@ -353,12 +375,12 @@ typedef struct LilypondHeaderFields
   GString *copyright;
   GString *footer;
   GString *tagline;
-  GString *extra;
+  //GString *extra;
   /* lilypond before and after each \score block     */
   GString *lilypond_before;
   GString *lilypond_after;
   /* preferences to go into \layout block */
-  GString *layout;
+  //GString *layout;
 }LilypondHeaderFields;
 
 
@@ -449,11 +471,11 @@ typedef struct Bookmark
 typedef struct DenemoLilyControl
 {
   GString *papersize;
-  gint fontsize;
+  GString *staffsize;
   GString *lilyversion;
   gboolean orientation;
   gboolean excerpt;
-  GString *lilypond; /**< Lilypond directive for all music in the movements */
+  GList *directives; /**< list of DenemoDirective for all music in the movements */
 	
 } DenemoLilyControl;
 
@@ -471,6 +493,33 @@ typedef struct DenemoScoreblock {
 } DenemoScoreblock;
 
 
+typedef struct header
+{
+  GList *directives;
+}
+header;
+typedef struct scoreheader
+{
+  GList *directives;
+}
+scoreheader;
+typedef struct paper
+{
+  GList *directives;
+}
+paper;
+typedef struct layout
+{
+  GList *directives;
+}
+layout;
+
+typedef struct movementcontrol
+{
+  GList *directives;
+}
+movementcontrol;
+
 /*
  *  DenemoScore structure representing a single movement of a piece of music.
  *  A movement corresponds with a single \score{} block in the LilyPond language
@@ -496,7 +545,8 @@ typedef struct DenemoScore
 
   /* Fields that have more to do with the data model and its manipulation,
    * though they may be modified by side-effects of the drawing routines */
-  score thescore;
+  // score thescore;
+  staffnode *thescore;
   
   staffnode *currentprimarystaff;
   staffnode *currentstaff;
@@ -542,7 +592,12 @@ typedef struct DenemoScore
   gint lastmeasuremarked;
   gint firstobjmarked;
   gint lastobjmarked;
-  LilypondHeaderFields headerinfo;/**< Lilypond header fields and markup for this movement */
+
+
+  movementcontrol movementcontrol;/*< Directives for control of the whole movement */
+  layout layout;/*< Directives for the layout block of the movement */
+  header header;/*< Directives for the header block of the movement */
+  
 
 
   /* Fields used for MIDI playback */
@@ -589,6 +644,14 @@ typedef struct DenemoGUI
   GtkObject *hadjustment;
   GtkWidget *hscrollbar;
 
+  GtkWidget *printarea;/**< area holding a print preview */
+  GtkWidget *printvscrollbar;/**< scrollbar widget for printarea */
+  GtkWidget *printhscrollbar;/**< scrollbar widget for printarea */
+  GdkPixbuf *pixbuf;/**< print preview pixbuf */
+
+
+  gchar *xbm; /**< xbm representation of graphic bitmap from selected rectangle in print preview area*/
+  gint xbm_width, xbm_height;/**< width and height of the xbm data */
   GtkWidget *textwindow; /**< LilyPond output window */
   GtkTextBuffer *textbuffer;   /**< buffer for LilyPond text */
   GtkTextView *textview; /**< LilyPond output text view */
@@ -607,9 +670,13 @@ typedef struct DenemoGUI
 
   GList *movements;   /**< a list of DenemoScore, NULL if just one movement */
   DenemoScore *si;  /**< the (current)  movement in the musical score controlled by this gui */
-  DenemoLilyControl lilycontrol; /**< Control of the LilyPond output for whole musical score */
+  DenemoLilyControl lilycontrol; /**< Directives for the start of the score and before every movement */
+
+  scoreheader scoreheader;/*< Directives for the header block at the start of the score */
+  paper paper;/*< Directives for the paper block of the score */
+
   GList *custom_scoreblocks; /**< List of customized texts for LilyPond output, replaces standard score blocks, elements are DenemoScoreblock * */
-  GString *custom_prolog; /**< Customized text for LilyPond output, replaces standard prolog */
+
   gpointer lilystart, lilyend; /**<range of lilytext  */
   GString **target; /**< pointer to target string for modification in lilytext  */
   GList *anchors;/**< anchors in the LilyPond text at points where that can be edited */
