@@ -505,6 +505,7 @@ staffup (DenemoScriptParam *param)
       gui->si->currentstaff = gui->si->currentstaff->prev;
       setcurrentprimarystaff (gui->si);
       setcurrents (gui->si);
+      find_leftmost_allcontexts (si);
       gtk_widget_draw (gui->scorearea, NULL);//KLUDGE FIXME gets cursorclef set
       move_viewport_up (gui);
       return param->status = TRUE;
@@ -566,6 +567,7 @@ staffdown (DenemoScriptParam *param)
       gui->si->currentstaff = gui->si->currentstaff->next;
       setcurrentprimarystaff (gui->si);
       setcurrents (gui->si);
+      find_leftmost_allcontexts (si);
       gtk_widget_draw (gui->scorearea, NULL);//KLUDGE FIXME gets cursorclef set
       move_viewport_down (gui);
       return param->status = TRUE;
@@ -720,7 +722,7 @@ cursordown (DenemoScriptParam *param)
  * shiftcursor: FIXME change the name of this function!
  * Mode sensitive note actions:
  * In Classic mode: Move the cursor to a given note value nearest the current cursor
- * In Edit mode: Change the current note (or insert if none)
+ * In Edit mode: Change the current note (or insert if none), if INPUTRHYTHM as well, move cursor to next note.
  * In Insert mode: Insert a note at the cursor
  */
 void
@@ -732,10 +734,6 @@ shiftcursor (DenemoGUI  *gui, gint note_value)
   gui->si->cursor_y = jumpcursor (gui->si->cursor_y, oldstaffletter_y,
 				  gui->si->staffletter_y);
   int mid_c_offset = gui->si->cursor_y;
-//  if((gui->mode & INPUTRHYTHM)&&!(gui->mode&INPUTINSERT)){
-//    warningdialog("Rhythm only mode - enter durations, not notes!");
-//    return;
-//  }
      
   /* in edit mode edit the current note name */
   if((gui->mode & INPUTEDIT) && gui->si->currentobject) {
@@ -911,8 +909,7 @@ dnm_insertchord (DenemoGUI * gui, gint duration, input_mode mode,
     if(Denemo.gui->input_source==INPUTKEYBOARD) {
       DenemoStaff *curstaffstruct = (DenemoStaff *) si->currentstaff->data;
       prognum = select_program (curstaffstruct->midi_instrument->str);
-      playnotes (Denemo.prefs.immediateplayback, *(chord *) mudela_obj_new->object,
-		 prognum);
+      playnotes (Denemo.prefs.immediateplayback, *(chord *) mudela_obj_new->object, prognum);
     }
   }
 }
@@ -1100,7 +1097,6 @@ incrementenshift (DenemoGUI * gui, gint direction)
       if(Denemo.gui->input_source==INPUTKEYBOARD) {
 	DenemoStaff *curstaffstruct = (DenemoStaff *) si->currentstaff->data;
 	prognum = select_program (curstaffstruct->midi_instrument->str);
-
 	playnotes (Denemo.prefs.immediateplayback,
 		   *(chord *) curmudelaobj->object, prognum);
       }
@@ -1143,6 +1139,7 @@ setenshift (DenemoScore * si, gint enshift)
 	prognum = select_program (curstaffstruct->midi_instrument->str);
 	playnotes (Denemo.prefs.immediateplayback,
 		   *(chord *) curmudelaobj->object, prognum);
+
       }
       unre_data *data = (unre_data *) g_malloc (sizeof (unre_data));
       data->object = curmudelaobj;
@@ -1502,6 +1499,8 @@ dnm_deleteobject (DenemoScore * si)
 
 	  break;
 	case CLEF:
+/* here we have to re-validate leftmost clef e.g. find_leftmost_allcontexts (gui->si);
+ which seems to be done... */
 	  delete_object_helper (si);
 	  fixnoteheights ((DenemoStaff *) si->currentstaff->data);
 	  beamsandstemdirswholestaff ((DenemoStaff *) si->currentstaff->data);
@@ -1589,6 +1588,25 @@ void tolastobject (DenemoGUI *gui)
     }
 }
 
+
+/* Make note tied/untied */
+void
+toggle_tie (GtkAction *action, gpointer param)
+{
+  DenemoGUI *gui = Denemo.gui;
+  DenemoObject *curmudelaobj = (DenemoObject *)
+    (gui->si->currentobject ? gui->si->currentobject->data : NULL);
+  if (curmudelaobj && curmudelaobj->type == CHORD &&
+      ((chord *) curmudelaobj->object)->notes)
+    {
+
+      ((chord *) curmudelaobj->object)->is_tied ^= 1;
+    }
+}
+
+
+
+
 /**
  * Move cursor to the end of the score 
  * @param action - Gtk Action event 
