@@ -1,4 +1,4 @@
-/* draw.cpp
+/* draw.c
  * loop that draws all the items in the presently-displayed part of
  * the score
  *  
@@ -29,7 +29,6 @@
  */
 #define REDEXCL_WIDTH 3
 #define REDEXCL_HEIGHT 13
-#define MAXEXTRASPACE (150) /* maximum space for leger lines, for sanity */
 
 /**
  * scorearea_configure_event
@@ -63,7 +62,7 @@ scorearea_configure_event (GtkWidget * widget, GdkEventConfigure * event)
  */
 struct infotopass
 {
-  gint clef;
+  clef* clef;
   gint key;
   gint curaccs[7];
   gint keyaccs[7];
@@ -145,7 +144,7 @@ draw_object (objnode * curobj, gint x, gint y,
   /************ FIXME the drawing is side-effecting the DenemoScore si here *******************/
   if (si->currentobject == curobj)
     {
-      si->cursorclef = itp->clef;
+      si->cursorclef = itp->clef->type;
       if (!si->cursor_appending)
 	memcpy (si->cursoraccs, itp->curaccs, SEVENGINTS);
     }
@@ -182,7 +181,7 @@ draw_object (objnode * curobj, gint x, gint y,
 		      GPOINTER_TO_INT (itp->mwidthiterator->data),
 		      itp->curaccs, itp->mark);
 	  if((((chord *) mudelaitem->object)->highesty) < itp->highy)
-	    itp->highy  = ((chord *) mudelaitem->object)->highesty;
+ 	    itp->highy  = ((chord *) mudelaitem->object)->highesty/*, g_print("setting highy %d\n", itp->highy)*/;
 
 	  if((((chord *) mudelaitem->object)->lowesty) > itp->lowy+STAFF_HEIGHT)
 	    itp->lowy  = ((chord *) mudelaitem->object)->lowesty-STAFF_HEIGHT;
@@ -294,14 +293,14 @@ draw_object (objnode * curobj, gint x, gint y,
       break;
     case CLEF:
       draw_clef (gui->pixmap, itp->gc, x + mudelaitem->x, y,
-		 itp->clef = ((clef *) mudelaitem->object)->type);
+		 itp->clef = ((clef *) mudelaitem->object));
       if (si->currentobject == curobj && si->cursor_appending)
-	si->cursorclef = itp->clef;
+	si->cursorclef = itp->clef->type;//FIXME drawing is side-effecting the data, presumably to economize on searching for the prevailing clef at the cursor.
       break;
     case KEYSIG:
       draw_key (gui->pixmap, itp->gc, x + mudelaitem->x, y,
 		((keysig *) mudelaitem->object)->number, itp->key,
-		itp->clef, TRUE);
+		itp->clef->type, TRUE);
       itp->key = ((keysig *) mudelaitem->object)->number;
       memcpy (itp->keyaccs, ((keysig *) mudelaitem->object)->accs,
 	      SEVENGINTS);
@@ -396,7 +395,7 @@ draw_object (objnode * curobj, gint x, gint y,
 
 
   gdk_gc_set_foreground (blackgc, &black);
-    
+  //g_print("returning with %d\n", itp->highy);
   /* And give a return value and we're done */
   return (mudelaitem->starttickofnextnote > itp->tickspermeasure);
 } /* draw_object */
@@ -444,7 +443,7 @@ draw_measure (measurenode * curmeasure, gint x, gint y,
   itp->wholenotewidth = si->measurewidth * itp->time2 / itp->time1;
   if (curmeasure == si->currentmeasure)
     {
-      si->curmeasureclef = itp->clef;
+      si->curmeasureclef = itp->clef->type;
       memcpy (si->curmeasureaccs, itp->keyaccs, SEVENGINTS);
       memcpy (si->nextmeasureaccs, itp->keyaccs, SEVENGINTS);
       si->curmeasurekey = itp->key;
@@ -472,9 +471,9 @@ draw_measure (measurenode * curmeasure, gint x, gint y,
 	{
 	  /* That is, the cursor's at the beginning of this blank measure */
 	  si->cursoroffend = FALSE;
-	  draw_cursor (gui->pixmap, si, x, y, gui->mode, itp->clef);
+	  draw_cursor (gui->pixmap, si, x, y, gui->mode, itp->clef->type);
 	  memcpy (si->cursoraccs, itp->curaccs, SEVENGINTS);
-	  si->cursorclef = itp->clef;
+	  si->cursorclef = itp->clef->type;
 	}
     }
   curobj = (objnode *) curmeasure->data;
@@ -570,19 +569,21 @@ draw_staff (DenemoStaff * curstaffstruct, gint y,
   else
     gc = graygc;
 
+
+
   draw_clef (gui->pixmap, gc, LEFT_MARGIN, y,
 	     itp->clef = curstaffstruct->leftmost_clefcontext);
   x = KEY_MARGIN;
   draw_key (gui->pixmap, gc, x, y,
-	    itp->key = curstaffstruct->leftmost_keysigcontext,
-	    0, itp->clef, TRUE);
-  memcpy (itp->keyaccs, curstaffstruct->leftmost_keyaccs, SEVENGINTS);
+	    itp->key = curstaffstruct->leftmost_keysig->number,
+	    0, itp->clef->type, TRUE);
+  memcpy (itp->keyaccs, curstaffstruct->leftmost_keysig->accs, SEVENGINTS);
   x += si->maxkeywidth;
 
   draw_timesig (gui->pixmap, gc, gtk_style_get_font (itp->widget->style), x,
 		y, itp->time1 =
-		curstaffstruct->leftmost_time1context, itp->time2 =
-		curstaffstruct->leftmost_time2context);
+		curstaffstruct->leftmost_timesig->time1, itp->time2 =
+		curstaffstruct->leftmost_timesig->time2);
   x += SPACE_FOR_TIME;
   itp->stem_directive = curstaffstruct->leftmost_stem_directive;
   itp->tickspermeasure = WHOLE_NUMTICKS * itp->time1 / itp->time2;
@@ -599,16 +600,44 @@ draw_staff (DenemoStaff * curstaffstruct, gint y,
   pango_layout_set_text (layout, curstaffstruct->denemo_name->str, -1);
   desc = pango_font_description_from_string (FONT);
   pango_layout_set_font_description (layout, desc);
-  pango_font_description_free (desc);
+
 
   gdk_draw_layout (gui->pixmap, gc, KEY_MARGIN, y - buffer, layout);
+  gint title_highy = 0;
+  if(curstaffstruct->staff_directives) {
+    GList *g = curstaffstruct->staff_directives;
+    gint count=1;
+    for(;g;g=g->next, count++) {
+      DenemoDirective* directive = g->data;
+        if(directive->display) { 
+    pango_layout_set_text (layout,
+			   directive->display->str,
+			   -1);
+    pango_layout_set_font_description (layout, desc);
+    gint ypos = y-buffer+directive->ty - count*10;
+    gdk_draw_layout (gui->pixmap, gc, KEY_MARGIN + directive->tx, ypos, layout);
+    //g_print("high %d %d\n", itp->highy, -ypos);
+    if(title_highy > ypos) title_highy = ypos;
+  }
+    }
+
+  }
+  //FIXME voice directives...
+
+  pango_font_description_free (desc);
 
   /* Loop that will draw each measure. Basically a for loop, but was uglier
    * when written that way.  */
   itp->measurenum = si->leftmeasurenum;
   itp->curmeasure =
     g_list_nth (curstaffstruct->measures, itp->measurenum - 1);
+
+
+  //FIX in measureops.c for case where si->measurewidths is too short
   itp->mwidthiterator = g_list_nth (si->measurewidths, itp->measurenum - 1);
+
+
+
   itp->gc = gc;
   while (itp->measurenum <= si->rightmeasurenum+1
 	 && itp->measurenum <= g_list_length (curstaffstruct->measures))
@@ -622,7 +651,8 @@ draw_staff (DenemoStaff * curstaffstruct, gint y,
       itp->measurenum++;
     }
 
-
+  if(itp->highy > title_highy)
+    itp->highy = title_highy;
 
   /* now draw the staff lines, reset itp->slur_stack, and we're done */
   for (i = 0; i < curstaffstruct->no_of_lines; i++, y += LINE_SPACE)
@@ -638,6 +668,47 @@ draw_staff (DenemoStaff * curstaffstruct, gint y,
     }
 }
 
+/**
+ * Draw the score directives and return the amount of vertical space they took up.
+
+*/
+static gint
+draw_score_directives (void) {
+  GList *score_directives = Denemo.gui->lilycontrol.directives;
+  GList *scoreheader_directives = Denemo.gui->scoreheader.directives;
+  GList *header_directives = Denemo.gui->si->header.directives;
+  GList *paper_directives = Denemo.gui->paper.directives;
+  GList *layout_directives = Denemo.gui->si->layout.directives;
+  GList *movement_directives = Denemo.gui->si->movementcontrol.directives;
+  gint x=0, y = 0;
+
+  PangoContext *context =
+    gdk_pango_context_get_for_screen (gdk_drawable_get_screen (Denemo.gui->pixmap));
+  PangoLayout *layout = pango_layout_new (context);
+  PangoFontDescription *desc = pango_font_description_from_string (FONT);
+#define OUTPUT_DIREC(g)\
+  for(g?y+=10:1;g;g=g->next) {\
+   DenemoDirective *directive = g->data;\
+    if(directive->display) {\
+      pango_layout_set_text (layout,\
+			     directive->display->str,\
+			     -1);\
+      pango_layout_set_font_description (layout, desc);\
+      gdk_draw_layout (Denemo.gui->pixmap, gcs_blackgc(), x, y, layout);\
+      x += strlen(directive->display->str) * MAX(10, directive->tx);\
+    }\
+  }
+  OUTPUT_DIREC(score_directives);
+  OUTPUT_DIREC(scoreheader_directives);
+  OUTPUT_DIREC(header_directives);
+  OUTPUT_DIREC(paper_directives);
+  OUTPUT_DIREC(layout_directives);
+  OUTPUT_DIREC(movement_directives);
+#undef OUTPUT_DIREC
+  pango_font_description_free (desc);
+  return y;
+}
+
 /**
  * This actually draws the score, staff-by-staff 
  * @param widget pointer to the parent widget
@@ -671,13 +742,26 @@ draw_score (GtkWidget * widget, DenemoGUI * gui)
   itp.slur_stack = NULL;
   itp.hairpin_stack = NULL;
   itp.haslyrics = FALSE;
-
-
-  
+  itp.highy = 0;//in case there are no objects...
+  y = 0;
+  //draw score title etc above top staff, if it is visible and if desired by score directives
+  if(si->top_staff==1 && Denemo.prefs.visible_titles) {
+    static last_y;
+    curstaff = si->thescore;
+    gint space = ((DenemoStaff *) curstaff->data)->space_above;
+    do {
+      last_y = y;
+      y = 0;
+      gdk_draw_rectangle (gui->pixmap, gcs_lightbluegc(), TRUE, 0, 0, widget->allocation.width/*KEY_MARGIN*/, last_y);
+      y = draw_score_directives();  
+      if(space<y) 
+	space = ((DenemoStaff *) curstaff->data)->space_above = y;
+    } while (last_y != y);
+  }
   /* Draw each staff */
   for ((itp.staffnum = si->top_staff,
 	curstaff = g_list_nth (si->thescore, si->top_staff - 1),
-	y = si->staffspace / 4);
+	y += si->staffspace / 4);
        curstaff && itp.staffnum <= si->bottom_staff; itp.staffnum++)
     {
       if (curstaff && ((DenemoStaff *) curstaff->data)->voicenumber == 1)
@@ -691,9 +775,22 @@ draw_score (GtkWidget * widget, DenemoGUI * gui)
       gint lowy =  ((DenemoStaff *) curstaff->data)->space_below;
 
       itp.in_highy = highy, itp.in_lowy = lowy;
+      itp.highy = 0;//do not pass on extra_space from one staff to the next
+
+      gdk_draw_rectangle (gui->pixmap, gcs_lightbluegc(), TRUE, 0, y, LEFT_MARGIN, STAFF_HEIGHT/*staff edit*/);
+      if(si->leftmeasurenum==1) {
+	/* draw background of clef, keysig, timesig */
+	gint key = gui->si->maxkeywidth;
+	gint cmajor = key?0:5;//allow some area for keysig in C-major
+	gdk_draw_rectangle (gui->pixmap, gcs_graygc(), TRUE, LEFT_MARGIN,y,KEY_MARGIN-LEFT_MARGIN - cmajor,STAFF_HEIGHT);/*clef edit*/
+	gdk_draw_rectangle (gui->pixmap, gcs_lightbluegc(), TRUE, KEY_MARGIN-cmajor,y,key+2*cmajor,STAFF_HEIGHT);/*keysig edit*/
+	gdk_draw_rectangle (gui->pixmap, gcs_graygc(), TRUE, KEY_MARGIN+key+cmajor,y,SPACE_FOR_TIME-cmajor,STAFF_HEIGHT);/*timesig edit*/
+      }
       draw_staff ((DenemoStaff *) curstaff->data, y, gui, &itp);
+
+      //IN FACT itp.highy is only set by one measure, it is reset to zero in the measure loop
       if(-itp.highy>highy && -itp.highy<MAXEXTRASPACE) //FIXME this should be done before draw_staff returns
-	((DenemoStaff *) curstaff->data)->space_above = -itp.highy, repeat=TRUE;
+	/*g_print("setting space above %d staff %d\n", -itp.highy, itp.staffnum),*/((DenemoStaff *) curstaff->data)->space_above = -itp.highy, repeat=TRUE;
       if(itp.lowy>lowy && itp.lowy<MAXEXTRASPACE)
 	((DenemoStaff *) curstaff->data)->space_below = itp.lowy, repeat=TRUE;
 
