@@ -3,7 +3,7 @@
  * Functions for drawing stemming directives
  *
  * for Denemo, a gtk+ frontend to GNU Lilypond
- * (c) 1999, 2000, 2001, 2002 Adam Tee
+ * (c) 1999, 2000, 2001, 2002 Adam Tee, 2008, 2009 Richard Shann
  */
 
 #include "utils.h"		/* Includes <gdk.h> */
@@ -23,14 +23,22 @@ draw_lily_dir (GdkPixmap * pixmap, GdkGC * gc, GdkFont * font,
     gdk_pango_context_get_for_screen (gdk_drawable_get_screen (pixmap));
   PangoLayout *layout = pango_layout_new (context);
   PangoFontDescription *desc = pango_font_description_from_string (FONT);
-  gchar *first = (lily->directive->str);
+  gchar *first = (lily->postfix->str);
 
+  if(lily->graphic){
+    gint width = lily->width;
+    gint  height = lily->height;  
+    drawbitmapinverse (pixmap, gc, lily->graphic,
+		     xx + lily->gx, y + lily->gy, width, height);
+  }
+  else
+    gdk_draw_rectangle (pixmap, selected?gcs_bluegc():gcs_greengc(), TRUE, xx, y+3*STAFF_HEIGHT/2, 2, STAFF_HEIGHT/2);
   if(lily->display) {  //store display position x,y as well
     pango_layout_set_text (layout,
 			   lily->display->str,
 			   -1);
     pango_layout_set_font_description (layout, desc);
-    gdk_draw_layout (pixmap, selected?gcs_bluegc():gc, xx/*+display x */, y+lowy+20/*+display y */, layout);
+    gdk_draw_layout (pixmap, selected?gcs_bluegc():gc, xx+ lily->tx/*+display x */, y+lowy+lily->ty/*+display y */, layout);
   }
 #if 1
   else
@@ -51,6 +59,6 @@ draw_lily_dir (GdkPixmap * pixmap, GdkGC * gc, GdkFont * font,
    pango_font_description_free (desc); 
 
 
-
-  gdk_draw_rectangle (pixmap, selected?gcs_bluegc():gcs_greengc(), TRUE, xx, y+3*STAFF_HEIGHT/2, 2, STAFF_HEIGHT/2);
+   
+    
 }
