@@ -930,6 +930,8 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
   long ticks_written;
   long ticks_at_bar = 0;
   int cur_volume;
+  gboolean mute_volume;
+  int mix;
   int midi_channel = (-1);
   int tracknumber = 0;
   int timesigupper = 4;
@@ -1091,19 +1093,21 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
       midi_change_event (fd, MIDI_PROG_CHANGE, midi_channel, prognum);
 
       /*key signature */
-      midi_keysig (fd, curstaffstruct->skey, curstaffstruct->skey_isminor);
+      midi_keysig (fd, curstaffstruct->keysig.number, curstaffstruct->keysig.isminor);
 
       /* Time signature */
-      timesigupper = curstaffstruct->stime1;
+      timesigupper = curstaffstruct->timesig.time1;
       //printf("\nstime1 = %i\n", timesigupper);
 
-      timesiglower = curstaffstruct->stime2;
+      timesiglower = curstaffstruct->timesig.time2;
       //printf("\nstime2 = %i\n", timesiglower);
 
       midi_timesig (fd, timesigupper, timesiglower);
 
       /* set a default velocity value */
-      cur_volume = dyn_vol[DYN_MF];
+      cur_volume = curstaffstruct->volume;
+      /* mute output if set */
+      mute_volume = curstaffstruct->mute_volume;
 
       /* reset measure */
       curmeasurenum = 0;
@@ -1262,8 +1266,16 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
 			  gint tmp = cur_volume;
 			  if (curobj->isinvisible)
 			    cur_volume = 0;
+			  else if (chordval.has_dynamic){
+			      g_debug("\nThis chord has a dynamic marking attatched\n");
+			      GList *dynamic = g_list_first(chordval.dynamics);	
+			      cur_volume =
+		              string_to_vol (((GString *) dynamic->data)->str,
+				   cur_volume);
+			  }
 			  else
 			    cur_volume = tmp;
+
 			  mid_c_offset =
 			    ((note *) curtone->data)->mid_c_offset;
 			  enshift = ((note *) curtone->data)->enshift;
@@ -1321,13 +1333,13 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
 			  /* write note on/off */
 			  if (slur_on_p (note_status, n))
 			    {
+			      mix = compress(128, cur_volume + rand_delta + beat);
 			      midi_channel_event (fd, MIDI_NOTE_ON,
 						  midi_channel, n,
-						  compress (128,
-							    cur_volume +
-							    rand_delta +
-							    beat));
-			      // printf ("n = %i\n", n);
+						  (mute_volume ? 0:mix));
+#if DEBUG
+			      printf ("volume = %i\n", (mute_volume ? 0:mix));
+#endif
 			    }
 			  else if (slur_kill_p (note_status, n))
 			    {
@@ -1496,7 +1508,7 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
 		  //  ((keysig *) theobj->object)->number; referenced in src/measureops.cpp       
 		  //printf("\nKEYSIG type = %d\n", ((keysig *) curobj->object)->number);
 		  midi_keysig (fd, (((keysig *) curobj->object)->number),
-			       curstaffstruct->skey_isminor);
+			       curstaffstruct->keysig.isminor);
 
 		case CLEF:
 
