@@ -295,6 +295,41 @@ newXMLFraction (xmlNodePtr parent, xmlNsPtr ns, gint num, gint denom)
 }
 
 
+static void
+newDirectivesElem(xmlNodePtr objElem, xmlNsPtr ns, GList *g, gchar *type) { 
+  xmlNodePtr directivesElem =  xmlNewChild (objElem, ns, (xmlChar *) type, NULL);
+  //GList *g = ((chord *) curObj->object)->directives;
+  for(;g;g=g->next) {
+    DenemoDirective *directive = (DenemoDirective *)g->data;
+     xmlNodePtr directiveElem =  xmlNewChild (directivesElem, ns, (xmlChar *) "directive", NULL);
+#define DO_DIREC(field)  if (directive->field \
+                   && directive->field->len)\
+                      xmlNewChild (directiveElem, ns, (xmlChar *) #field,\
+				     (xmlChar *) directive->field->str);
+#define DO_INTDIREC(field)   if(directive->field) newXMLIntChild (directiveElem, ns, (xmlChar *) #field,\
+				             directive->field);
+    DO_DIREC(tag);
+    DO_DIREC(prefix);
+    DO_DIREC(postfix);
+    DO_DIREC(display);
+    DO_DIREC(graphic_name);
+    
+    DO_INTDIREC(minpixels);
+    DO_INTDIREC(x);
+    DO_INTDIREC(y);
+    DO_INTDIREC(tx);
+    DO_INTDIREC(ty);
+    DO_INTDIREC(gx);
+    DO_INTDIREC(gy);
+    DO_INTDIREC(override);
+
+#undef DO_DIREC
+#undef DO_INTDIREC
+  }
+}
+
+
+
 /**
  * Output a clef of the form:
  *
@@ -303,14 +338,16 @@ newXMLFraction (xmlNodePtr parent, xmlNsPtr ns, gint num, gint denom)
  * as a child of the given node.
  */
 static xmlNodePtr
-newXMLClef (xmlNodePtr parent, xmlNsPtr ns, gint clef)
+newXMLClef (xmlNodePtr parent, xmlNsPtr ns, clef * clef)
 {
   gchar *clefName = NULL;
   xmlNodePtr clefElem = NULL;
 
-  determineClef (clef, &clefName);
+  determineClef (clef->type, &clefName);
   clefElem = xmlNewChild (parent, ns, (xmlChar *) "clef", NULL);
   xmlSetProp (clefElem, (xmlChar *) "name", (xmlChar *) clefName);
+  if(clef->directives) 
+	    newDirectivesElem(clefElem, ns, clef->directives, "directives");
   return clefElem;
 }
 
@@ -320,14 +357,18 @@ newXMLClef (xmlNodePtr parent, xmlNsPtr ns, gint clef)
  *
  *   <key-signature>
  *     <modal-key-signature note-name="B" accidental="flat" mode="major"/>
+ *   <directives>
+ *         ....
+ *   </directives>
  *   </key-signature>
  *
  * as a child of the given node.
  */
 static xmlNodePtr
-newXMLKeySignature (xmlNodePtr parent, xmlNsPtr ns, gint keySig,
-		    gboolean isMinor)
+newXMLKeySignature (xmlNodePtr parent, xmlNsPtr ns, keysig *keysig)
 {
+ gint keySig = keysig->number;
+ gboolean isMinor = keysig->isminor;
   gchar *noteName = NULL, *accidental = NULL, *mode = NULL;
   xmlNodePtr keySigElem = NULL, modalKeySigElem = NULL;
 
@@ -340,7 +381,8 @@ newXMLKeySignature (xmlNodePtr parent, xmlNsPtr ns, gint keySig,
     xmlSetProp (modalKeySigElem, (xmlChar *) "accidental",
 		(xmlChar *) accidental);
   xmlSetProp (modalKeySigElem, (xmlChar *) "mode", (xmlChar *) mode);
-
+  if(keysig->directives) 
+	    newDirectivesElem(keySigElem, ns, keysig->directives, "directives");
   return keySigElem;
 }
 
@@ -353,19 +395,23 @@ newXMLKeySignature (xmlNodePtr parent, xmlNsPtr ns, gint keySig,
  *       <numerator>3</numerator>
  *       <denominator>4</denominator>
  *     </simple-time-signature>
+ *   <directives>
+ *         ....
+ *   </directives>
  *   </time-signature>
  *
  * as a child of the given node.
  */
 static xmlNodePtr
-newXMLTimeSignature (xmlNodePtr parent, xmlNsPtr ns, gint numerator,
-		     gint denominator)
+newXMLTimeSignature (xmlNodePtr parent, xmlNsPtr ns, timesig *timesig)
 {
   xmlNodePtr timeSigElem =
     xmlNewChild (parent, ns, (xmlChar *) "time-signature", NULL);
   newXMLFraction (xmlNewChild
 		  (timeSigElem, ns, (xmlChar *) "simple-time-signature",
-		   NULL), ns, numerator, denominator);
+		   NULL), ns, timesig->time1, timesig->time2);
+  if(timesig->directives) 
+	    newDirectivesElem(timeSigElem, ns, timesig->directives, "directives");
   return timeSigElem;
 }
 
@@ -511,7 +557,7 @@ exportXML (gchar * thefilename, DenemoGUI *gui, gint start, gint end)
   GString *filename = g_string_new (thefilename);
   xmlDocPtr doc;
   xmlNodePtr scoreElem, mvmntElem, stavesElem, voicesElem, voiceElem;
-  xmlNodePtr measuresElem, measureElem, objElem, prevTieElem;
+  xmlNodePtr measuresElem, measureElem, objElem, prevTieElem, directivesElem, directiveElem;
   xmlNodePtr curElem, parentElem;
   xmlNsPtr ns;
   staffnode *curStaff;
@@ -540,11 +586,11 @@ exportXML (gchar * thefilename, DenemoGUI *gui, gint start, gint end)
   //  g_string_append (filename, ".denemo");
 
   /* Initialize score-wide variables. */
-
+  
   sStructToXMLIDMap = g_hash_table_new (NULL, NULL);
-
+  
   /* Create the XML document and output the root element. */
-
+  
   doc = xmlNewDoc ((xmlChar *) "1.0");
   xmlSetDocCompressMode (doc, XML_COMPRESSION_RATIO);
   doc->xmlRootNode = scoreElem =
@@ -552,30 +598,44 @@ exportXML (gchar * thefilename, DenemoGUI *gui, gint start, gint end)
   ns = xmlNewNs (doc->xmlRootNode, (xmlChar *) DENEMO_XML_NAMESPACE, NULL);
   xmlSetProp (scoreElem, (xmlChar *) "version", (xmlChar *) "2.0");
   /* FIXME: Put comment here ("Denemo XML file generated by..."). */
-
+  
   if(getNumCharsSchemeText()) {
-    gchar *text = getSchemeText();
+    gchar *text = (gchar*) getSchemeText();
     xmlNewChild (scoreElem, ns, "scheme", (xmlChar *)text);
     g_free(text);
   }
+
+  if(gui->scoreheader.directives) 
+	    newDirectivesElem(scoreElem, ns, gui->scoreheader.directives, "scoreheader-directives");
+  if(gui->paper.directives) 
+	    newDirectivesElem(scoreElem, ns, gui->paper.directives, "paper-directives");
+
+
   /* lilycontrol for the whole musical score */
-
-
- parentElem = xmlNewChild (scoreElem, ns, (xmlChar *) "lilycontrol", NULL);
+  
+  
+  parentElem = xmlNewChild (scoreElem, ns, (xmlChar *) "lilycontrol", NULL);
 #define NEWCHILD(field) if(gui->lilycontrol.field->len) \
                        xmlNewChild (parentElem, ns, (xmlChar *) #field,\
                       (xmlChar *) gui->lilycontrol.field->str)
- NEWCHILD(papersize);
- NEWCHILD(lilyversion);
- NEWCHILD(lilypond);
- newXMLIntChild (parentElem, ns, (xmlChar *) "fontsize",  gui->lilycontrol.fontsize);
- newXMLIntChild (parentElem, ns, (xmlChar *) "orientation",  gui->lilycontrol.orientation);
-   GList *custom;
-   for(custom=g_list_last(gui->custom_scoreblocks);custom;custom=custom->prev) {
-     xmlNewChild (scoreElem, ns, "custom_scoreblock", (xmlChar *)((GString*)(((DenemoScoreblock*)custom->data)->scoreblock)->str));
-     if(((DenemoScoreblock*)custom->data)->visible)
-       xmlNewChild (scoreElem, ns, "visible_scoreblock", NULL);
-   }
+  NEWCHILD(papersize);
+  NEWCHILD(lilyversion);
+
+  newXMLIntChild (parentElem, ns, (xmlChar *) "fontsize",  atoi(gui->lilycontrol.staffsize->str));
+  newXMLIntChild (parentElem, ns, (xmlChar *) "orientation",  gui->lilycontrol.orientation);
+
+  if(gui->lilycontrol.directives) 
+	    newDirectivesElem(parentElem, ns, gui->lilycontrol.directives, "score-directives");
+
+  GList *custom;
+  for(custom=g_list_last(gui->custom_scoreblocks);custom;custom=custom->prev) {
+    xmlNewChild (scoreElem, ns, "custom_scoreblock", (xmlChar *)((GString*)(((DenemoScoreblock*)custom->data)->scoreblock)->str));
+    if(((DenemoScoreblock*)custom->data)->visible)
+      xmlNewChild (scoreElem, ns, "visible_scoreblock", NULL);
+  }
+  //  if(gui->custom_prolog && gui->custom_prolog->len)
+  //   xmlNewChild (scoreElem, ns, "custom_prolog", (xmlChar *)gui->custom_prolog->str);
+  
   GList *g;
   for(g=gui->movements;g;g=g->next) {
     DenemoScore *si = g->data;
@@ -587,47 +647,23 @@ exportXML (gchar * thefilename, DenemoGUI *gui, gint start, gint end)
 		  si->cursor_x - 1);
 
 
+  if(si->header.directives) {
+    newDirectivesElem(mvmntElem, ns, si->header.directives, "header-directives");
+  }
+  if(si->layout.directives) {
+    newDirectivesElem(mvmntElem, ns, si->layout.directives, "layout-directives");
+  }
+  if(si->movementcontrol.directives) {
+    newDirectivesElem(mvmntElem, ns, si->movementcontrol.directives, "movementcontrol-directives");
+  }
+
   parentElem = xmlNewChild (mvmntElem, ns, (xmlChar *) "score-info", NULL);
   curElem = xmlNewChild (parentElem, ns, (xmlChar *) "tempo", NULL);
   newXMLFraction (xmlNewChild (curElem, ns, (xmlChar *) "duration", NULL), ns,
 		  1, 4);
   newXMLIntChild (curElem, ns, (xmlChar *) "bpm", si->tempo);
-  xmlNewChild (parentElem, ns, (xmlChar *) "title",
-	       (xmlChar *) si->headerinfo.title->str);
-  xmlNewChild (parentElem, ns, (xmlChar *) "subtitle",
-	       (xmlChar *) si->headerinfo.subtitle->str);
-  xmlNewChild (parentElem, ns, (xmlChar *) "composer",
-	       (xmlChar *) si->headerinfo.composer->str);
-  xmlNewChild (parentElem, ns, (xmlChar *) "poet",
-	       (xmlChar *) si->headerinfo.poet->str);
-  xmlNewChild (parentElem, ns, (xmlChar *) "meter",
-	       (xmlChar *) si->headerinfo.meter->str);
-  xmlNewChild (parentElem, ns, (xmlChar *) "opus",
-	       (xmlChar *) si->headerinfo.opus->str);
-  xmlNewChild (parentElem, ns, (xmlChar *) "arranger",
-	       (xmlChar *) si->headerinfo.arranger->str);
-  xmlNewChild (parentElem, ns, (xmlChar *) "instrument",
-	       (xmlChar *) si->headerinfo.instrument->str);
-  xmlNewChild (parentElem, ns, (xmlChar *) "dedication",
-	       (xmlChar *) si->headerinfo.dedication->str);
-  xmlNewChild (parentElem, ns, (xmlChar *) "piece",
-	       (xmlChar *) si->headerinfo.piece->str);
-  xmlNewChild (parentElem, ns, (xmlChar *) "head",
-	       (xmlChar *) si->headerinfo.head->str);
-  xmlNewChild (parentElem, ns, (xmlChar *) "copyright",
-	       (xmlChar *) si->headerinfo.copyright->str);
-  xmlNewChild (parentElem, ns, (xmlChar *) "footer",
-	       (xmlChar *) si->headerinfo.footer->str);
-  xmlNewChild (parentElem, ns, (xmlChar *) "tagline",
-	       (xmlChar *) si->headerinfo.tagline->str);
-  xmlNewChild (parentElem, ns, (xmlChar *) "extra",
-	       (xmlChar *) si->headerinfo.extra->str);
-  xmlNewChild (parentElem, ns, (xmlChar *) "markup_before",
-	       (xmlChar *) si->headerinfo.lilypond_before->str);
-  xmlNewChild (parentElem, ns, (xmlChar *) "markup_after",
-	       (xmlChar *) si->headerinfo.lilypond_after->str);
-  xmlNewChild (parentElem, ns, (xmlChar *) "layout_markup",
-	       (xmlChar *) si->headerinfo.layout->str);
+  
+
 
   /* Output each (primary) staff, and store the IDs in a hash table. */
   fraction = 1.0 / (gdouble) g_list_length (si->thescore);
@@ -652,6 +688,8 @@ exportXML (gchar * thefilename, DenemoGUI *gui, gint start, gint end)
 			  curStaffStruct->transposition);
 	  xmlNewChild (curElem, ns, (xmlChar *) "instrument",
 		       (xmlChar *) curStaffStruct->midi_instrument->str);
+	   newXMLIntChild (curElem, ns, (xmlChar *) "volume",
+			   			  curStaffStruct->volume);
 	  newXMLIntChild (curElem, ns, (xmlChar *) "midi_prognum_override",
 	               curStaffStruct->midi_prognum_override);
 	  newXMLIntChild (curElem, ns, (xmlChar *) "midi_prognum",
@@ -683,12 +721,14 @@ exportXML (gchar * thefilename, DenemoGUI *gui, gint start, gint end)
 	     xmlNewChild (curElem, ns, (xmlChar *) "staff-prolog",
 		       (xmlChar *) curStaffStruct->staff_prolog->str);
 	  
-	  if(curStaffStruct->staff_prolog_insert && curStaffStruct->staff_prolog_insert->len)
-	    xmlNewChild (curElem, ns, (xmlChar *) "staff-prolog-insert",
-			 (xmlChar *) curStaffStruct->staff_prolog_insert->str);
-	  if(curStaffStruct->voice_prolog_insert && curStaffStruct->voice_prolog_insert->len)
-	    xmlNewChild (curElem, ns, (xmlChar *) "voice-prolog-insert",
-			 (xmlChar *) curStaffStruct->voice_prolog_insert->str);
+	  if(curStaffStruct->staff_directives) 
+	    newDirectivesElem(curElem, ns,curStaffStruct->staff_directives, "staff-directives");
+	  
+	  if(curStaffStruct->voice_directives)
+	    newDirectivesElem(curElem, ns,curStaffStruct->voice_directives, "voice-directives");
+	  if(curStaffStruct->clef.directives)
+	    newDirectivesElem(curElem, ns,curStaffStruct->voice_directives, "clef-directives");
+	    
 
 	  if(curStaffStruct->lyrics_prolog && curStaffStruct->lyrics_prolog->len)
 	     xmlNewChild (curElem, ns, (xmlChar *) "lyrics-prolog",
@@ -760,12 +800,11 @@ exportXML (gchar * thefilename, DenemoGUI *gui, gint start, gint end)
 				(xmlChar *) "initial-voice-params", NULL);
       curElem = xmlNewChild (parentElem, ns, (xmlChar *) "staff-ref", NULL);
       xmlSetProp (curElem, (xmlChar *) "staff", (xmlChar *) staffXMLID);
-      newXMLClef (parentElem, ns, curStaffStruct->sclef);
-      newXMLKeySignature (parentElem, ns, curStaffStruct->skey,
-			  curStaffStruct->skey_isminor);
-      curTime1 = curStaffStruct->stime1;
-      curTime2 = curStaffStruct->stime2;
-      newXMLTimeSignature (parentElem, ns, curTime1, curTime2);
+      newXMLClef (parentElem, ns, &curStaffStruct->clef);
+      newXMLKeySignature (parentElem, ns, &curStaffStruct->keysig);
+      curTime1 = curStaffStruct->timesig.time1;
+      curTime2 = curStaffStruct->timesig.time2;
+      newXMLTimeSignature (parentElem, ns, &curStaffStruct->timesig);
 
       /* Write out the measures. */
       gboolean warning_given = FALSE;//No warning yet about empty measures
@@ -789,11 +828,7 @@ exportXML (gchar * thefilename, DenemoGUI *gui, gint start, gint end)
 		  {chord *thechord = (chord *) curObj->object;
 		  emptyMeasure = FALSE;
 
-		  if(thechord->prefix && thechord->prefix->len)
-		    xmlNewChild (curElem, ns,
-				 (xmlChar *) "prefix",
-					  (xmlChar *)thechord->prefix->str);
-		  
+#if 0		  
 		  /* FIXME WHY DO WE EXPORT THIS INFO: it is derived from the data
 		     If this is the start of a beam, output a <beam-start>. */
 
@@ -805,7 +840,7 @@ exportXML (gchar * thefilename, DenemoGUI *gui, gint start, gint end)
 		      xmlSetProp (curElem, (xmlChar *) "id",
 				  (xmlChar *) lastBeamStartXMLID);
 		    }
-
+#endif
 		  /* Output the root element, "rest" or "chord". */
 
 		  if (((chord *) curObj->object)->notes == NULL)
@@ -839,16 +874,10 @@ exportXML (gchar * thefilename, DenemoGUI *gui, gint start, gint end)
 		    newXMLIntChild (parentElem, ns, (xmlChar *) "dots",
 				    ((chord *) curObj->object)->numdots);
 
-		  /* Output the LilyPond */
-#define DO(field)  if (((chord *) curObj->object)->field \
-                   && ((chord *) curObj->object)->field->len)\
-                      xmlNewChild (objElem, ns, (xmlChar *) #field,\
-				     (xmlChar *) ((chord *) curObj->object)->\
-				     field->str);
-		  DO(prefix);
-		  DO(postfix);
-		  DO(display);
-#undef DO		  
+		  /* Output the DenemoDirectives on the chord */
+		  if(((chord *) curObj->object)->directives) {
+		    newDirectivesElem(objElem, ns,  ((chord *) curObj->object)->directives, "directives");
+		  }
 		  if(((chord *) curObj->object)->chordize)
 		    newXMLIntChild (objElem, ns, (xmlChar *) "chordize", TRUE);
 
@@ -1181,21 +1210,49 @@ exportXML (gchar * thefilename, DenemoGUI *gui, gint start, gint end)
 			      newXMLNoteHead (curElem, ns,
 					      curNote->noteheadtype);
 			    }
-			  if(curNote->postfix && curNote->postfix->len)
-			     xmlNewChild (curElem, ns,
-					  (xmlChar *) "postfix",
-					  (xmlChar *)curNote->postfix->str);
-                          if(curNote->prefix && curNote->prefix->len)
-			     xmlNewChild (curElem, ns,
-					  (xmlChar *) "prefix",
-					  (xmlChar *)curNote->prefix->str);
-                          if(curNote->display && curNote->display->len)
-			     xmlNewChild (curElem, ns,
-					  (xmlChar *) "display",
-					  (xmlChar *)curNote->display->str);
-			}
-		    }
 
+			  if(curNote->directives) {
+			    newDirectivesElem(curElem, ns, curNote->directives, "directives");
+#if 0
+			    directivesElem =  xmlNewChild (curElem, ns, (xmlChar *) "directives", NULL);
+			    GList *g = curNote->directives;
+			    for(;g;g=g->next) {
+			      DenemoDirective *directive = (DenemoDirective *)g->data;
+			      directiveElem =  xmlNewChild (directivesElem, ns, (xmlChar *) "directive", NULL);	
+#define DO_DIREC(field)  if (directive->field\
+                   && directive->field->len)\
+                      xmlNewChild (directiveElem, ns, (xmlChar *) #field,\
+				     (xmlChar *) directive->field->str);
+
+#define DO_INTDIREC(field)   newXMLIntChild (directiveElem, ns, (xmlChar *) #field,\
+				             directive->field);
+
+			      DO_DIREC(tag);
+			      DO_DIREC(prefix);
+			      DO_DIREC(postfix);
+			      DO_DIREC(display);
+			      DO_DIREC(graphic_name);
+
+			      DO_INTDIREC(minpixels);
+			      DO_INTDIREC(x);
+			      DO_INTDIREC(y);
+			      DO_INTDIREC(tx);
+			      DO_INTDIREC(ty);
+			      DO_INTDIREC(gx);
+			      DO_INTDIREC(gy);
+			      DO_INTDIREC(override);
+
+
+#undef DO_DIREC
+#undef DO_INTDIREC
+			    }
+#endif
+			  }
+
+			}
+		      }
+
+#if 0
 		  /* If this is the end of a beam, output a <beam-end>. */
 
 		  if (curObj->isend_beamgroup && !curObj->isstart_beamgroup)
@@ -1217,6 +1274,8 @@ exportXML (gchar * thefilename, DenemoGUI *gui, gint start, gint end)
 			  lastBeamStartXMLID = NULL;
 			}
 		    }
+#endif
+
 		  }
 		  break;
 
@@ -1259,22 +1318,18 @@ exportXML (gchar * thefilename, DenemoGUI *gui, gint start, gint end)
 
 		case CLEF:
 		  objElem = newXMLClef (measureElem, ns,
-					((clef *) curObj->object)->type);
+					((clef *) curObj->object));
 		  break;
 
 		case TIMESIG:
-		  objElem = newXMLTimeSignature (measureElem, ns,
-						 ((timesig *)
-						  curObj->object)->time1,
-						 ((timesig *)
-						  curObj->object)->time2);
+		  objElem = newXMLTimeSignature (measureElem, ns, (timesig *)
+						  curObj->object);
 		  break;
 
 		case KEYSIG:
 		  objElem = newXMLKeySignature
 		    (measureElem, ns,
-		     ((keysig *) curObj->object)->number,
-		     ((keysig *) curObj->object)->isminor);
+		     ((keysig *) curObj->object));
 		  break;
 
 		case STEMDIRECTIVE:
@@ -1344,22 +1399,45 @@ exportXML (gchar * thefilename, DenemoGUI *gui, gint start, gint end)
 
 		  break;
 		case LILYDIRECTIVE:
-		  objElem =
-			xmlNewChild (measureElem, ns, (xmlChar *) "lily-directive",
-				     (xmlChar *) ((lilydirective *) curObj->object)->
-				     directive->str);
+		  //FIXME this should really have been the tag saved here, but for backwards compatibility we use the postfix string.
+		  if( ((lilydirective *) curObj->object)->
+				     postfix && ((lilydirective *) curObj->object)->
+		      postfix->len)
+		    objElem =
+		      xmlNewChild (measureElem, ns, (xmlChar *) "lily-directive",
+				   (xmlChar *) ((lilydirective *) curObj->object)->
+				   postfix->str);
+		  else
+		    objElem =
+		      xmlNewChild (measureElem, ns, (xmlChar *) "lily-directive",
+				   (xmlChar *)" ");
+
+		  
 		  xmlSetProp (objElem, (xmlChar *) "locked",
 			      (xmlChar *) (((lilydirective *) curObj->object)->locked?"true":"false"));
-		  if(((lilydirective *) curObj->object)->display && ((lilydirective *) curObj->object)->display->len) {
-		    xmlSetProp (objElem, (xmlChar *) "display",
-			      (xmlChar *) (((lilydirective *) curObj->object)->display->str));
-		    newXMLIntProp (objElem, (xmlChar *) "x",
-				   (((lilydirective *) curObj->object)->x));
-		    newXMLIntProp (objElem, (xmlChar *) "y",
-				   (((lilydirective *) curObj->object)->y));
 
-		  }
-		    
+#define SETSTRING_PROP(field)\
+		  if(((lilydirective *) curObj->object)->field && ((lilydirective *) curObj->object)->field->len)\
+		    xmlSetProp (objElem, (xmlChar *) #field,\
+			      (xmlChar *) (((lilydirective *) curObj->object)->field->str));
+
+		    SETSTRING_PROP (tag);
+		    SETSTRING_PROP (display);
+		    SETSTRING_PROP (graphic_name);
+		    SETSTRING_PROP (prefix);//postfix done above, for backward compatibility
+#undef SETSTRING_PROP
+
+#define SETINT_PROP(x)\
+		    newXMLIntProp (objElem, (xmlChar *) #x,\
+				   (((lilydirective *) curObj->object)->x));
+		    SETINT_PROP (x);
+		    SETINT_PROP (y);
+		    SETINT_PROP (tx);
+		    SETINT_PROP (ty);
+		    SETINT_PROP (gx);
+		    SETINT_PROP (gy);
+		    SETINT_PROP (minpixels);
+#undef SETINT_PROP		  
 		  break;
 		case BARLINE:
 		case MEASUREBREAK:
@@ -1412,4 +1490,4 @@ exportXML (gchar * thefilename, DenemoGUI *gui, gint start, gint end)
   sNextXMLID = 0;
 
   g_string_free (filename, TRUE);
-}
+  }
