@@ -33,14 +33,17 @@ struct callbackdata
  * Function to actually insert a figure to an object
  *
  */
-void
-insertfigure (GtkWidget * widget, gpointer data)
+static void
+insertfigure (gboolean filter, gpointer data)
 {
   struct callbackdata *cbdata = (struct callbackdata *) data;
   DenemoGUI *gui = cbdata->gui;
   DenemoScore *si = gui->si;
   static staff_info null_info;
   GString *current_figure;
+  gchar filter_sep = filter?'/':'|';
+  gchar filter_spc = filter?'*':' ';
+
   if (si->currentobject != NULL) {
     DenemoObject *curObj = (DenemoObject *) si->currentobject ?
       (DenemoObject *) si->currentobject->data : NULL;
@@ -52,21 +55,21 @@ insertfigure (GtkWidget * widget, gpointer data)
     gchar *c = figure;
     for(c=figure;*c;c++) {
       if(*c=='+') {
-	if(c==figure || *(c-1)==' ' || *(c-1)=='*' || *(c-1)=='|' || *(c-1)=='/')
+	if(c==figure || *(c-1)==' ' || *(c-1)==filter_spc || *(c-1)=='|' || *(c-1)==filter_sep)
 	  g_string_append(f, "_+");
 	else
 	  g_string_append(f,"+");
       }else
 	if(*c=='-') {
-	  if(c==figure || *(c-1)==' ' ||*(c-1)=='*' || *(c-1)=='|' || *(c-1)=='/')
+	  if(c==figure || *(c-1)==' ' ||*(c-1)==filter_spc || *(c-1)=='|' || *(c-1)==filter_sep)
 	    g_string_append(f, "_-");
 	  else
 	    g_string_append(f,"-");
 	}else
-	  if(*c=='/')
+	  if(*c==filter_sep)
 	    g_string_append(f, "|");
           else {
-	    if(*c=='*')
+	    if(*c==filter_spc)
 	      g_string_append(f, " ");
 		else
 		  g_string_append_c(f, *c);
@@ -80,9 +83,9 @@ insertfigure (GtkWidget * widget, gpointer data)
     do
       {
 	if (si->currentobject->next)
-	  cursorright (gui);
+	  cursorright (NULL);
 	else if (gui->si->currentmeasure->next)
-	  measureright (gui);
+	  measureright (NULL);
 	else 
 	  break;
 	curObj =
@@ -111,23 +114,39 @@ figure_insert (GtkAction *action, gpointer param)
   gchar *PreValue = NULL;
   DenemoScore *si = gui->si;
   static struct callbackdata cbdata;
-  DenemoObject *curObj = (DenemoObject *) si->currentobject ?
-    (DenemoObject *) si->currentobject->data : NULL;
- 
-  if (curObj && curObj->type == CHORD && ((chord *) curObj->object)->figure)
+
+  if(!action && param)
     {
-      PreValue = ((GString *) ((chord *) curObj->object)->figure)->str;
+    GString *values = ((DenemoScriptParam *)param)->string;
+    gchar *str;
+#define SET_STRING(a, b)     if( (str = g_strstr_len(values->str+i,strlen(values->str+i), a))) {\
+      b = g_strdup(str+strlen(a)+1);\
     }
+    gint i;
+    for(i=0;i<values->len;i+=strlen(values->str+i)+1) {
+      SET_STRING("figures", string); 
+    }
+#undef SET_STRING
+    } else {
+      DenemoObject *curObj = (DenemoObject *) si->currentobject ?
+	(DenemoObject *) si->currentobject->data : NULL;
+ 
+      if (curObj && curObj->type == CHORD && ((chord *) curObj->object)->figure)
+	{
+	  PreValue = ((GString *) ((chord *) curObj->object)->figure)->str;
+	}
 
-
-  string = string_dialog_entry(gui, "Insert/Edit Figure", "Give figures followed by Enter key", PreValue);
-
+      string = string_dialog_entry(gui, "Insert/Edit Figure", "Give figures followed by Enter key", PreValue);
+    }
   cbdata.gui = gui;
   cbdata.string = string;
    
   if (string)
     {
-      insertfigure (NULL, &cbdata);
+      insertfigure (action!=NULL, &cbdata);
+      //also \set Staff.useBassFigureExtenders = ##t
+
+
       ((DenemoStaff*)si->currentstaff->data)->hasfigures=TRUE;
       displayhelper (gui);
     }
