@@ -28,12 +28,11 @@
 #include "prefops.h"
 #include "binreloc.h"
 #include "view.h"
-
+#include "lilydirectives.h"
 #include <stdio.h>
 #include <string.h>
 #include <sys/stat.h>		/* check existance and type of files */
 #include <dirent.h>		/* filter and sort filenames */
-#include <malloc.h>		/* I use free() */
 
 
 
@@ -230,15 +229,17 @@ open_for_real (gchar * filename, DenemoGUI * gui, gboolean template, ImportType
 {
   gint result;
   result = 1;//FAILURE
-  if (strcmp (filename + strlen (filename) - 7, ".denemo") == 0)
-    result = importXML (filename, gui, type);
-  else if (strcmp (filename + strlen (filename) - 4, ".dnm") == 0)
-    result = importXML (filename, gui, type);
-  else if (strcmp (filename + strlen (filename) - 3, ".ly") == 0)
-    result = lyinput (filename, gui);
-  else if (strcmp (filename + strlen (filename) - 4, ".mid") == 0 ||
-	   strcmp (filename + strlen (filename) - 5, ".midi") == 0)
-    result = importMidi (filename, gui);
+  if(g_file_test(filename, G_FILE_TEST_EXISTS)) {
+    if (strcmp (filename + strlen (filename) - 7, ".denemo") == 0)
+      result = importXML (filename, gui, type);
+    else if (strcmp (filename + strlen (filename) - 4, ".dnm") == 0)
+      result = importXML (filename, gui, type);
+    else if (strcmp (filename + strlen (filename) - 3, ".ly") == 0)
+      result = lyinput (filename, gui);
+    else if (strcmp (filename + strlen (filename) - 4, ".mid") == 0 ||
+	     strcmp (filename + strlen (filename) - 5, ".midi") == 0)
+      result = importMidi (filename, gui);
+  }
   if (result == 0)
     {
       if(!template) {// not a template
@@ -248,6 +249,8 @@ open_for_real (gchar * filename, DenemoGUI * gui, gboolean template, ImportType
 	if(type==ADD_STAFFS || type==ADD_MOVEMENTS)
 	  score_status(gui, TRUE);
       }
+      if(gui->printarea) 
+	g_object_set_data(G_OBJECT(gui->printarea), "printviewupdate", G_MAXUINT);
       updatescoreinfo (gui);
       set_rightmeasurenum (gui->si);
       set_bottom_staff (gui);
@@ -354,8 +357,11 @@ static void save_in_format(gint format_id, DenemoGUI * gui, gchar *filename) {
       };
     case PNG_FORMAT:
       {
+	gchar *lilyfile = g_strconcat (filename, ".ly", NULL);
 	gui->lilycontrol.excerpt = TRUE;
-	exportlilypond (file, gui, TRUE);
+	exportlilypond (lilyfile, gui,  TRUE);
+	run_lilypond(file, Denemo.gui);
+	gui->lilycontrol.excerpt = FALSE;
 	break;
       }
     case ABC_FORMAT:
@@ -819,16 +825,14 @@ file_saveas (DenemoGUI * gui, gboolean template)
   /*set default folder for saving */
   set_current_folder(file_selection, gui, template);
 
-  /* assign title */ 
-  if (gui->si->headerinfo.title->len)
-    { 
-      gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (file_selection), 
-					 gui->si->headerinfo.title->str);
-    }
- // else {
-  //	gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (file_selection), "Untitled Document");
-  //}
 
+  /* assign title */ 
+  {gchar * title = get_scoretitle();
+  if (title)
+    { 
+      gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (file_selection), title);
+    }
+  }
 
   hbox = gtk_hbox_new (FALSE, 8);
   label = gtk_label_new (_("Format:"));
@@ -878,6 +882,9 @@ file_saveas (DenemoGUI * gui, gboolean template)
 	    {
 	      filesel_save (gui, file_name, format_id, template);
 	      close = TRUE;
+	      //the lilypond can now be out of sync
+	      gui->lilysync = G_MAXUINT;//FIXME move these two lines into a function, they force refresh of lily text
+	      refresh_lily_cb(NULL, gui);
 	    }
 	  g_free (file_name);
 	}
@@ -910,7 +917,22 @@ file_newwrapper (GtkAction * action, gpointer param)
   else
     {
       deletescore(NULL, gui);
-    };
+    }
+  open_user_default_template();
+  if(gui->printarea) 
+    g_object_set_data(G_OBJECT(gui->printarea), "printviewupdate", G_MAXUINT);
+}
+
+/* open_user_default_template
+ * open the user's standard template if there is one
+ **/
+void
+open_user_default_template(void) {
+  gchar *filename = g_build_filename(locatedotdenemo(), "templates", "default.denemo", NULL);
+  if(g_file_test(filename, G_FILE_TEST_EXISTS)) { 
+    open_for_real(filename, Denemo.gui, TRUE, REPLACE_SCORE);
+  }
+  g_free(filename);
 }
 
 /**
@@ -930,7 +952,7 @@ deletescore (GtkWidget * widget, DenemoGUI * gui)
     set_title_bar (gui);
   }
 
-  new_score(gui);
+  point_to_new_movement(gui);
   gui->movements = g_list_append(gui->movements, gui->si);
   set_width_to_work_with(gui);
   set_rightmeasurenum (gui->si);
