@@ -227,6 +227,53 @@ LOOKUP(GROUP_END_STRING,DENEMO_GROUP_END)
     }
 }
 
+static gint
+parseDirective (xmlNodePtr parentElem, xmlNsPtr ns,
+	       DenemoDirective *directive)
+{
+  xmlNodePtr childElem;
+#define DO_DIREC(field) if (ELEM_NAME_EQ (childElem, #field))\
+         directive->field = g_string_new(xmlNodeListGetString (childElem->doc,\
+						  childElem->xmlChildrenNode, 1));
+#define DO_INTDIREC(field) if (ELEM_NAME_EQ (childElem, #field))\
+         directive->field = getXMLIntChild(childElem);
+  FOREACH_CHILD_ELEM (childElem, parentElem) {
+    DO_DIREC(tag);
+    DO_DIREC(prefix);
+    DO_DIREC(postfix);
+    DO_DIREC(display); 
+    DO_INTDIREC(minpixels);
+    DO_INTDIREC(x);
+    DO_INTDIREC(y);
+    DO_INTDIREC(tx);
+    DO_INTDIREC(ty);
+    DO_INTDIREC(gx);
+    DO_INTDIREC(gy);
+    DO_INTDIREC(override);
+    if(ELEM_NAME_EQ (childElem, "graphic_name")) {
+      directive->graphic_name =  g_string_new(xmlNodeListGetString (childElem->doc,\
+						  childElem->xmlChildrenNode, 1));
+      loadGraphicItem(directive->graphic_name->str, &directive->graphic,  &directive->width, &directive->height);
+      /* FIXME,handle not loaded */
+    }
+      
+  }
+#undef DO_DIREC 
+#undef DO_INTDIREC  
+}
+
+static GList *
+parseDirectives (xmlNodePtr parentElem, xmlNsPtr ns)
+{
+  GList *directives = NULL;
+  xmlNodePtr childElem;
+  FOREACH_CHILD_ELEM (childElem, parentElem) {
+    DenemoDirective *directive = (DenemoDirective*)g_malloc0(sizeof(DenemoDirective));
+    parseDirective(childElem, ns, directive);
+    directives = g_list_append(directives, directive);
+  }
+  return directives;
+}
 /**
  * Return the numerator and denominator from the given XML fraction.
  */
@@ -370,9 +417,10 @@ parseClef (xmlNodePtr clefElem, xmlNsPtr ns, gint * clefType)
  * given number of sharps plus whether it's minor or not).
  */
 static void
-parseKeySignature (xmlNodePtr keySigElem, xmlNsPtr ns,
-		   gint * keySig, gboolean * isMinor)
+parseKeySignature (xmlNodePtr keySigElem, xmlNsPtr ns, keysig *keysig)
 {
+  gint * keySig = &keysig->number;
+  gboolean * isMinor = &keysig->isminor;
   xmlNodePtr childElem;
   gint childCount = 0;
   gboolean successful = FALSE;
@@ -380,139 +428,119 @@ parseKeySignature (xmlNodePtr keySigElem, xmlNsPtr ns,
   gint note, accidental;
 
   FOREACH_CHILD_ELEM (childElem, keySigElem)
-  {
-    if (childElem->ns == ns)
-      {
-	if (++childCount > 1)
-	  {
-	    /* Only print this warning once (when the child count is 2). */
-	    if (childCount == 2)
-	      g_warning ("<key-signature> element should only have one "
-			 "child (<modal-key-signature>)");
-	  }
-	else
-	  {
-	    if (ELEM_NAME_EQ (childElem, "modal-key-signature"))
-	      {
-		noteName = (gchar *) xmlGetProp
-		  (childElem, (xmlChar *) "note-name");
-		accidentalName = (gchar *) xmlGetProp
-		  (childElem, (xmlChar *) "accidental");
-		modeName =
-		  (gchar *) xmlGetProp (childElem, (xmlChar *) "mode");
+    {
+      if (ELEM_NAME_EQ (childElem, "modal-key-signature"))
+	{
+	  noteName = (gchar *) xmlGetProp
+	    (childElem, (xmlChar *) "note-name");
+	  accidentalName = (gchar *) xmlGetProp
+	    (childElem, (xmlChar *) "accidental");
+	  modeName =
+	    (gchar *) xmlGetProp (childElem, (xmlChar *) "mode");
 
-		if (noteName == NULL)
-		  {
-		    g_warning ("<modal-key-signature> should have a "
-			       "note-name attribute; defaulting to C");
-		    noteName = "C";
-		  }
-		if (accidentalName == NULL)
-		  accidentalName = "natural";
-		if (modeName == NULL)
-		  {
-		    g_warning ("<modal-key-signature> should have a "
-			       "mode attribute; defaulting to major");
-		    modeName = "major";
-		  }
+	  if (noteName == NULL)
+	    {
+	      g_warning ("<modal-key-signature> should have a "
+			 "note-name attribute; defaulting to C");
+	      noteName = "C";
+	    }
+	  if (accidentalName == NULL)
+	    accidentalName = "natural";
+	  if (modeName == NULL)
+	    {
+	      g_warning ("<modal-key-signature> should have a "
+			 "mode attribute; defaulting to major");
+	      modeName = "major";
+	    }
 
-		/* Translate note name (A to G) into note number (0 to 6). */
+	  /* Translate note name (A to G) into note number (0 to 6). */
 
-		note = noteName[0] - 'A';
-		if (strlen (noteName) != 1 || note < 0 || note > 6)
-		  {
-		    g_warning ("<modal-key-signature> note name should be A "
-			       "through G, received \"%s\"; defaulting to C",
-			       noteName);
-		    note = 2;
-		  }
+	  note = noteName[0] - 'A';
+	  if (strlen (noteName) != 1 || note < 0 || note > 6)
+	    {
+	      g_warning ("<modal-key-signature> note name should be A "
+			 "through G, received \"%s\"; defaulting to C",
+			 noteName);
+	      note = 2;
+	    }
 
-		accidental = determineAccidentalShift (accidentalName);
+	  accidental = determineAccidentalShift (accidentalName);
 
-		/* Try to determine the base key signature. */
+	  /* Try to determine the base key signature. */
 
-		if (note == 2 && accidental == -1)
-		  *keySig = -7;
-		else if (note == 6 && accidental == -1)
-		  *keySig = -6;
-		else if (note == 3 && accidental == -1)
-		  *keySig = -5;
-		else if (note == 0 && accidental == -1)
-		  *keySig = -4;
-		else if (note == 4 && accidental == -1)
-		  *keySig = -3;
-		else if (note == 1 && accidental == -1)
-		  *keySig = -2;
-		else if (note == 5 && accidental == 0)
-		  *keySig = -1;
-		else if (note == 2 && accidental == 0)
-		  *keySig = 0;
-		else if (note == 6 && accidental == 0)
-		  *keySig = 1;
-		else if (note == 3 && accidental == 0)
-		  *keySig = 2;
-		else if (note == 0 && accidental == 0)
-		  *keySig = 3;
-		else if (note == 4 && accidental == 0)
-		  *keySig = 4;
-		else if (note == 1 && accidental == 0)
-		  *keySig = 5;
-		else if (note == 5 && accidental == 1)
-		  *keySig = 6;
-		else if (note == 2 && accidental == 1)
-		  *keySig = 7;
-		else if (note == 6 && accidental == 1)
-		  *keySig = 8;
-		else if (note == 3 && accidental == 1)
-		  *keySig = 9;
-		else if (note == 0 && accidental == 1)
-		  *keySig = 10;
-		else
-		  {
-		    g_warning ("Unknown key signature with note name %s and "
-			       "accidental %s; defaulting to C", noteName,
-			       accidentalName);
-		    *keySig = 0;
-		  }
+	  if (note == 2 && accidental == -1)
+	    *keySig = -7;
+	  else if (note == 6 && accidental == -1)
+	    *keySig = -6;
+	  else if (note == 3 && accidental == -1)
+	    *keySig = -5;
+	  else if (note == 0 && accidental == -1)
+	    *keySig = -4;
+	  else if (note == 4 && accidental == -1)
+	    *keySig = -3;
+	  else if (note == 1 && accidental == -1)
+	    *keySig = -2;
+	  else if (note == 5 && accidental == 0)
+	    *keySig = -1;
+	  else if (note == 2 && accidental == 0)
+	    *keySig = 0;
+	  else if (note == 6 && accidental == 0)
+	    *keySig = 1;
+	  else if (note == 3 && accidental == 0)
+	    *keySig = 2;
+	  else if (note == 0 && accidental == 0)
+	    *keySig = 3;
+	  else if (note == 4 && accidental == 0)
+	    *keySig = 4;
+	  else if (note == 1 && accidental == 0)
+	    *keySig = 5;
+	  else if (note == 5 && accidental == 1)
+	    *keySig = 6;
+	  else if (note == 2 && accidental == 1)
+	    *keySig = 7;
+	  else if (note == 6 && accidental == 1)
+	    *keySig = 8;
+	  else if (note == 3 && accidental == 1)
+	    *keySig = 9;
+	  else if (note == 0 && accidental == 1)
+	    *keySig = 10;
+	  else
+	    {
+	      g_warning ("Unknown key signature with note name %s and "
+			 "accidental %s; defaulting to C", noteName,
+			 accidentalName);
+	      *keySig = 0;
+	    }
 
-		/* Determine whether it's major or minor. */
+	  /* Determine whether it's major or minor. */
 
-		if (strcmp (modeName, "major") == 0)
-		  *isMinor = FALSE;
-		else if (strcmp (modeName, "minor") == 0)
-		  *isMinor = TRUE;
-		else
-		  {
-		    g_warning ("Unknown mode %s; defaulting to major",
-			       modeName);
-		    *isMinor = FALSE;
-		  }
+	  if (strcmp (modeName, "major") == 0)
+	    *isMinor = FALSE;
+	  else if (strcmp (modeName, "minor") == 0)
+	    *isMinor = TRUE;
+	  else
+	    {
+	      g_warning ("Unknown mode %s; defaulting to major",
+			 modeName);
+	      *isMinor = FALSE;
+	    }
 
-		successful = TRUE;
-
-		g_free (noteName);
-		//g_free (accidentalName);
-		g_free (modeName);
-	      }
-	  }
-      }
-
-    /*
-     * Note: We can ignore other namespaces because the generic "parse this
-     *       DenemoObject" code takes care of them for us.
-     */
-  }
-
-  if (childCount == 0)
-    g_warning ("<key-signature> element should have a child in the Denemo "
-	       "namespace (<modal-key-signature>); defaulting to C Major");
+	  successful = TRUE;
 
+	  g_free (noteName);
+	  //g_free (accidentalName);
+	  g_free (modeName);
+	}
+      if(ELEM_NAME_EQ (childElem, "directives"))
+	{
+	  keysig->directives = parseDirectives(childElem, ns);
+	}
+    }
   if (!successful)
     {
       *keySig = 0;
       *isMinor = FALSE;
     }
-
   if (*isMinor)
     *keySig -= 3;
 }
@@ -523,48 +551,37 @@ parseKeySignature (xmlNodePtr keySigElem, xmlNsPtr ns,
  * given number of sharps plus whether it's minor or not).
  */
 static void
-parseTimeSignature (xmlNodePtr timeSigElem, xmlNsPtr ns,
-		    gint * numerator, gint * denominator)
+parseTimeSignature (xmlNodePtr timeSigElem, xmlNsPtr ns, timesig* timesig)
 {
   xmlNodePtr childElem;
   gint childCount = 0;
   gboolean successful = FALSE;
+  gint *numerator =  &timesig->time1;
+  gint *denominator =  &timesig->time2;
 
   FOREACH_CHILD_ELEM (childElem, timeSigElem)
   {
-    if (childElem->ns == ns)
+
+    if (ELEM_NAME_EQ (childElem, "simple-time-signature"))
       {
-	if (++childCount > 1)
-	  {
-	    /* Only print this warning once (when the child count is 2). */
-	    if (childCount == 2)
-	      g_warning ("<time-signature> element should only have one "
-			 "child (<simple-time-signature>)");
-	  }
+	if (parseFraction (childElem, ns, numerator, denominator)
+	    != 0)
+	  g_warning ("Could not parse <simple-time-signature>; "
+		     "defaulting to 4/4");
 	else
-	  {
-	    if (ELEM_NAME_EQ (childElem, "simple-time-signature"))
-	      {
-		if (parseFraction (childElem, ns, numerator, denominator)
-		    != 0)
-		  g_warning ("Could not parse <simple-time-signature>; "
-			     "defaulting to 4/4");
-		else
-		  successful = TRUE;
-	      }
-	  }
+	  successful = TRUE;
       }
 
+    if (ELEM_NAME_EQ (childElem, "directives"))
+      {
+	timesig->directives = parseDirectives(childElem, ns);
+      }
     /*
      * Note: We can ignore other namespaces because the generic "parse this
      *       DenemoObject" code takes care of them for us.
      */
   }
 
-  if (childCount == 0)
-    g_warning ("<time-signature> element should have a child in the Denemo "
-	       "namespace (<simple-time-signature>); defaulting to 4/4");
-
   if (!successful)
     {
       *numerator = 4;
@@ -646,6 +663,9 @@ parseFakechord (xmlNodePtr fakechordElem, DenemoObject * curobj)
 
 }
 
+
+
+
 /**
  * Parse the given <note> element into a note structure and add it to the
  * given chord.
@@ -658,7 +678,8 @@ parseNote (xmlNodePtr noteElem, xmlNsPtr ns,
   gint middleCOffset = 0, accidental = 0,
     noteHeadType = DENEMO_NORMAL_NOTEHEAD;
   gboolean showAccidental = FALSE;
-  gchar *accidentalName, *showAccidentalProp, *noteHeadName, *postfix = NULL, *prefix = NULL, *display = NULL;
+  gchar *accidentalName, *showAccidentalProp, *noteHeadName;
+  GList *directives = NULL;
 
   FOREACH_CHILD_ELEM (childElem, noteElem)
   {
@@ -718,20 +739,9 @@ parseNote (xmlNodePtr noteElem, xmlNsPtr ns,
 		g_free (showAccidentalProp);
 	      }
 	  }
-	else if (ELEM_NAME_EQ (childElem, "postfix"))
+	else if (ELEM_NAME_EQ (childElem, "directives"))
 	  {
-	    postfix = (gchar *) xmlNodeListGetString
-	      (childElem->doc, childElem->xmlChildrenNode, 1);	    
-	  }
-	else if (ELEM_NAME_EQ (childElem, "prefix"))
-	  {
-	    prefix = (gchar *) xmlNodeListGetString
-	      (childElem->doc, childElem->xmlChildrenNode, 1);	    
-	  }
-	else if (ELEM_NAME_EQ (childElem, "display"))
-	  {
-	    display = (gchar *) xmlNodeListGetString
-	      (childElem->doc, childElem->xmlChildrenNode, 1);	    
+	    directives = parseDirectives(childElem, ns);
 	  }
 	else if (ELEM_NAME_EQ (childElem, "note-head"))
 	  {
@@ -770,12 +780,7 @@ parseNote (xmlNodePtr noteElem, xmlNsPtr ns,
   /* Now actually construct the note object. */
 
   note *newnote = addtone (chordObj, middleCOffset, accidental, currentClef);
-  if(newnote && postfix)
-    newnote->postfix = g_string_new(postfix);
-  if(newnote && prefix)
-    newnote->prefix = g_string_new(prefix);
-  if(newnote && display)
-    newnote->display = g_string_new(display);
+  newnote->directives = directives;
 
   if (noteHeadType != DENEMO_NORMAL_NOTEHEAD)
     {
@@ -1325,25 +1330,26 @@ parseChord (xmlNodePtr chordElem, xmlNsPtr ns,
 	    parseFakechord (childElem, chordObj);
 	    si->has_fakechords = (gpointer) TRUE;
 	  }
-	else if (ELEM_NAME_EQ (childElem, "prefix"))
+	else if (ELEM_NAME_EQ (childElem, "directives")) 
 	  {
-	    ((chord *) chordObj->object)->prefix = g_string_new(xmlNodeListGetString (childElem->doc,
-						  childElem->xmlChildrenNode,
-						  1));
+	  ((chord *) chordObj->object)->directives = parseDirectives(childElem, ns);	  
 	  }
-	else if (ELEM_NAME_EQ (childElem, "postfix"))
-	  {
-	    ((chord *) chordObj->object)->postfix = g_string_new(xmlNodeListGetString (childElem->doc,
-						  childElem->xmlChildrenNode,
-						  1));
+	//Support for old files 0.8.2 only
+#define DO_DIREC(field) else if (ELEM_NAME_EQ (childElem, #field))\
+	  {\
+	    if( ((chord *) chordObj->object)->directives == NULL) {\
+	      DenemoDirective *directive =  (DenemoDirective*)g_malloc0(sizeof(DenemoDirective));\
+	  ((chord *) chordObj->object)->directives = g_list_append(NULL, directive) ;\
+	  }\
+	    ((DenemoDirective*) (((chord *) chordObj->object)->directives)->data)->field = \
+		 g_string_new(xmlNodeListGetString (childElem->doc,\
+		 childElem->xmlChildrenNode, 1));\
 	  }
-	else if (ELEM_NAME_EQ (childElem, "display"))
-	  {
-	    ((chord *) chordObj->object)->display = g_string_new(xmlNodeListGetString (childElem->doc,
-						  childElem->xmlChildrenNode,
-						  1));
-	  }
-
+    DO_DIREC(prefix)
+    DO_DIREC(postfix)
+    DO_DIREC(display)  
+#undef DO_DIREC
+	// End 0.8.2 support
 	else if (ELEM_NAME_EQ (childElem, "chordize"))
 	  {
 	    ((chord *) chordObj->object)->chordize = TRUE;
@@ -1379,28 +1385,43 @@ parseLilyDir (xmlNodePtr LilyDirectiveElem, xmlNsPtr ns, DenemoScore *si)
 						     LilyDirectiveElem->
 						     xmlChildrenNode,
 						     1);
+
+  DenemoObject *curobj = lily_directive_new (directive?directive:" "); 
+  DenemoDirective *thedirective = (lilydirective*)curobj->object;
+
   gchar *locked = (gchar *) xmlGetProp (LilyDirectiveElem, (xmlChar *) "locked");
-  gchar *display = (gchar *) xmlGetProp (LilyDirectiveElem, (xmlChar *) "display");
-  gchar *x = (gchar *) xmlGetProp (LilyDirectiveElem, (xmlChar *) "x");
-  gchar *y = (gchar *) xmlGetProp (LilyDirectiveElem, (xmlChar *) "y");
-
-
-  DenemoObject *curobj = lily_directive_new (directive);
+ 
   if(locked)
-    ((lilydirective*)curobj->object)->locked = !strcmp (locked, "true");
+    thedirective->locked = !strcmp (locked, "true");
   g_free(locked);
-  if(display)
-    ((lilydirective*)curobj->object)->display = g_string_new(display);
+
+#define GET_STR_FIELD(display)\
+  gchar *display = (gchar *) xmlGetProp (LilyDirectiveElem, (xmlChar *) #display);\
+  if(display)\
+    ((lilydirective*)curobj->object)->display = g_string_new(display);\
   g_free(display);
-  if(x)
-    ((lilydirective*)curobj->object)->x = atoi(x);
+
+  GET_STR_FIELD(tag);
+  GET_STR_FIELD(display);
+  GET_STR_FIELD(graphic_name);
+  GET_STR_FIELD(prefix);
+  if(thedirective->graphic_name && thedirective->graphic_name->len)
+    loadGraphicItem(thedirective->graphic_name->str , &thedirective->graphic, &thedirective->width, &thedirective->height);
+#define GET_INT_FIELD(x)\
+  gchar *x = (gchar *) xmlGetProp (LilyDirectiveElem, (xmlChar *) #x);\
+  if(x)\
+    ((lilydirective*)curobj->object)->x = atoi(x);\
   g_free(x);
-  if(y)
-    ((lilydirective*)curobj->object)->y = atoi(y);
-  g_free(y);
-
-
 
+  GET_INT_FIELD(x);
+  GET_INT_FIELD(y);
+  GET_INT_FIELD(tx);
+  GET_INT_FIELD(ty);
+  GET_INT_FIELD(gx);
+  GET_INT_FIELD(gy);
+  GET_INT_FIELD(override);
+  GET_INT_FIELD(minpixels);
+  curobj->minpixelsalloted = thedirective->minpixels;
   return curobj;
 }
 
@@ -1538,7 +1559,7 @@ parseSetupInfo (xmlNodePtr editInfoElem, xmlNsPtr ns, DenemoGUI * gui)
   {
     if (childElem->ns == ns)
       {
-	if (ELEM_NAME_EQ (childElem, "lilypondversion"))
+	if (ELEM_NAME_EQ (childElem, "lilyversion"))
 	  {
 	    tmp = (gchar *) xmlNodeListGetString (childElem->doc,
 						  childElem->
@@ -1546,26 +1567,30 @@ parseSetupInfo (xmlNodePtr editInfoElem, xmlNsPtr ns, DenemoGUI * gui)
 	    if (tmp != NULL)
 	      {
 		//g_print ("lilypond version %s", tmp);
-		g_string_assign (gui->lilycontrol.lilyversion, tmp);
+		//g_string_assign (gui->lilycontrol.lilyversion, tmp);
+		if(strcmp(tmp, LILYPOND_VERSION))
+		   warningdialog("This file may contain embedded LilyPond from an earlier LilyPond version\nIf you have problems printing from it\nrefresh the directives responsible.");
 		g_free (tmp);
 	      }
 	  }
-	if (ELEM_NAME_EQ (childElem, "lilypond"))
+	if (ELEM_NAME_EQ (childElem, "lilypond"))//backward compatibility only
 	  {
 	    tmp = (gchar *) xmlNodeListGetString (childElem->doc,
 						  childElem->
 						  xmlChildrenNode, 1);
 	    if (tmp != NULL)
 	      {
-		//g_print ("lilypond directive for all music %s", tmp);
-		g_string_assign (gui->lilycontrol.lilypond, tmp);
+		DenemoDirective *directive =  (DenemoDirective*)g_malloc0(sizeof(DenemoDirective));
+		directive->postfix = g_string_new(tmp);
+		directive->tag = g_string_new("UnknownScoreTag");
+		gui->lilycontrol.directives = g_list_append(NULL, directive);
 		g_free (tmp);
 	      }
 	  }
 	else if (ELEM_NAME_EQ (childElem, "fontsize"))
 	  {
 	    gint font = getXMLIntChild (childElem);
-	    gui->lilycontrol.fontsize = font;
+	    gui->lilycontrol.staffsize = g_string_new(g_strdup_printf("%d", font));
 	    //g_print ("Font Size %d", font);
 	  }
 	else if (ELEM_NAME_EQ (childElem, "papersize"))
@@ -1588,6 +1613,13 @@ parseSetupInfo (xmlNodePtr editInfoElem, xmlNsPtr ns, DenemoGUI * gui)
 	    gui->lilycontrol.orientation = orientation;
 	    //g_print ("Orientation %d\n", orientation);
 	  }
+	else if (ELEM_NAME_EQ (childElem, "score-directives"))
+	  {
+	    gui->lilycontrol.directives = parseDirectives(childElem, ns);
+	  }
+
+
+
       }
   }
 
@@ -1692,142 +1724,46 @@ parseScoreInfo (xmlNodePtr scoreInfoElem, xmlNsPtr ns, DenemoScore * si)
 						    xmlChildrenNode, 1);
 	    if (title != NULL)
 	      {
-		g_string_assign (si->headerinfo.title, title);
+		//g_string_assign (si->headerinfo.title, title);
+		gchar *val = g_strdup_printf("title = \"%s\"\n", title);
+		header_directive_put_postfix("Movement-title", val);
+		header_directive_put_display("Movement-title", title);
+		paper_directive_put_postfix("PrintAllHeaders", "printallheaders = ##t\n");
+		g_free(val);
 		g_free (title);
 	      }
 	  }
-	else if (ELEM_NAME_EQ (childElem, "subtitle"))
-	  {
-	    subtitle = (gchar *) xmlNodeListGetString (childElem->doc,
-						       childElem->
-						       xmlChildrenNode, 1);
-	    if (subtitle != NULL)
-	      {
-		g_string_assign (si->headerinfo.subtitle, subtitle);
-		g_free (subtitle);
-	      }
-	  }
-	else if (ELEM_NAME_EQ (childElem, "composer"))
-	  {
-	    composer = (gchar *) xmlNodeListGetString (childElem->doc,
-						       childElem->
-						       xmlChildrenNode, 1);
-	    if (composer != NULL)
-	      {
-		g_string_assign (si->headerinfo.composer, composer);
-		g_free (composer);
-	      }
-	  }
-	else if (ELEM_NAME_EQ (childElem, "poet"))
-	  {
-	    poet = (gchar *) xmlNodeListGetString (childElem->doc,
-						   childElem->
-						   xmlChildrenNode, 1);
-	    if (poet != NULL)
-	      {
-		g_string_assign (si->headerinfo.poet, poet);
-		g_free (poet);
-	      }
-	  }
-	else if (ELEM_NAME_EQ (childElem, "meter"))
-	  {
-	    meter = (gchar *) xmlNodeListGetString (childElem->doc,
-						    childElem->
-						    xmlChildrenNode, 1);
-	    if (meter != NULL)
-	      {
-		g_string_assign (si->headerinfo.meter, meter);
-		g_free (meter);
-	      }
-	  }
-	else if (ELEM_NAME_EQ (childElem, "opus"))
-	  {
-	    opus = (gchar *) xmlNodeListGetString (childElem->doc,
-						   childElem->
-						   xmlChildrenNode, 1);
-	    if (opus != NULL)
-	      {
-		g_string_assign (si->headerinfo.opus, opus);
-		g_free (opus);
-	      }
-	  }
-	else if (ELEM_NAME_EQ (childElem, "arranger"))
-	  {
-	    arranger = (gchar *) xmlNodeListGetString (childElem->doc,
-						       childElem->
-						       xmlChildrenNode, 1);
-	    if (arranger != NULL)
-	      {
-		g_string_assign (si->headerinfo.arranger, arranger);
-		g_free (arranger);
-	      }
-	  }
-	else if (ELEM_NAME_EQ (childElem, "instrument"))
-	  {
-	    instrument = (gchar *) xmlNodeListGetString (childElem->doc,
-							 childElem->
-							 xmlChildrenNode, 1);
-	    if (instrument != NULL)
-	      {
-		g_string_assign (si->headerinfo.instrument, instrument);
-		g_free (instrument);
-	      }
-	  }
-	else if (ELEM_NAME_EQ (childElem, "dedication"))
-	  {
-	    dedication = (gchar *) xmlNodeListGetString (childElem->doc,
-							 childElem->
-							 xmlChildrenNode, 1);
-	    if (dedication != NULL)
-	      {
-		g_string_assign (si->headerinfo.dedication, dedication);
-		g_free (dedication);
-	      }
-	  }
-	else if (ELEM_NAME_EQ (childElem, "piece"))
-	  {
-	    piece = (gchar *) xmlNodeListGetString (childElem->doc,
-						    childElem->
-						    xmlChildrenNode, 1);
-	    if (piece != NULL)
-	      {
-		g_string_assign (si->headerinfo.piece, piece);
-		g_free (piece);
-	      }
-	  }
-	else if (ELEM_NAME_EQ (childElem, "head"))
-	  {
-	    head = (gchar *) xmlNodeListGetString (childElem->doc,
-						   childElem->
-						   xmlChildrenNode, 1);
-	    if (head != NULL)
-	      {
-		g_string_assign (si->headerinfo.head, head);
-		g_free (head);
-	      }
-	  }
-	else if (ELEM_NAME_EQ (childElem, "copyright"))
-	  {
-	    copyright = (gchar *) xmlNodeListGetString (childElem->doc,
-							childElem->
-							xmlChildrenNode, 1);
-	    if (copyright != NULL)
-	      {
-		g_string_assign (si->headerinfo.copyright, copyright);
-		g_free (copyright);
-	      }
-	  }
-	else if (ELEM_NAME_EQ (childElem, "footer"))
-	  {
-	    footer = (gchar *) xmlNodeListGetString (childElem->doc,
-						     childElem->
-						     xmlChildrenNode, 1);
-	    if (footer != NULL)
-	      {
-		g_string_assign (si->headerinfo.footer, footer);
-		g_free (footer);
-	      }
-	  }
+
+#define DO_ELEM(subtitle, dummy)\
+	else if (ELEM_NAME_EQ (childElem, subtitle))\
+	  {\
+	    gchar *field = (gchar *) xmlNodeListGetString (childElem->doc,\
+						       childElem->\
+						       xmlChildrenNode, 1);\
+	    if (field != NULL)\
+	      {\
+		gchar *val = g_strdup_printf(subtitle" = \"%s\"\n", field);\
+	        header_directive_put_postfix("Movement-"subtitle, val);\
+	        header_directive_put_display("Movement-"subtitle, field);\
+                paper_directive_put_postfix("PrintAllHeaders", "printallheaders = ##t\n");\
+		g_free(val);\
+		g_free (field);\
+	      }\
+	  }\
+
+DO_ELEM("subtitle", 0)
+DO_ELEM("composer","HeaderComposer")
+DO_ELEM("poet","HeaderPoet")
+DO_ELEM("meter","HeaderMeter")
+DO_ELEM("opus","HeaderOpus")
+DO_ELEM("arranger","HeaderArranger")
+DO_ELEM("instrument","HeaderInstrument")
+DO_ELEM("dedication","HeaderDedication")
+DO_ELEM("piece","HeaderPiece")
+DO_ELEM("head","HeaderHead")
+DO_ELEM("copyright","HeaderCopyright")
+DO_ELEM("footer","HeaderFooter")
+#undef DO_ELEM
 	else if (ELEM_NAME_EQ (childElem, "tagline"))
 	  {
 	    tagline = (gchar *) xmlNodeListGetString (childElem->doc,
@@ -1835,7 +1771,9 @@ parseScoreInfo (xmlNodePtr scoreInfoElem, xmlNsPtr ns, DenemoScore * si)
 						      xmlChildrenNode, 1);
 	    if (tagline != NULL)
 	      {
-		g_string_assign (si->headerinfo.tagline, tagline);
+		gchar *val = g_strdup_printf("tagline = \"%s\"\n", tagline);
+		scoreheader_directive_put_postfix("Scoretagline", val);
+		g_free(val);
 		g_free (tagline);
 	      }
 	  }
@@ -1846,7 +1784,7 @@ parseScoreInfo (xmlNodePtr scoreInfoElem, xmlNsPtr ns, DenemoScore * si)
 						      xmlChildrenNode, 1);
 	    if (mvmnt_header != NULL)
 	      {
-		g_string_assign (si->headerinfo.extra, mvmnt_header);
+		//g_string_assign (si->headerinfo.extra, mvmnt_header);
 		g_free (mvmnt_header);
 	      }
 	  }
@@ -1857,7 +1795,7 @@ parseScoreInfo (xmlNodePtr scoreInfoElem, xmlNsPtr ns, DenemoScore * si)
 						      xmlChildrenNode, 1);
 	    if (markup_before != NULL)
 	      {
-		g_string_assign (si->headerinfo.lilypond_before, markup_before);
+		//g_string_assign (si->headerinfo.lilypond_before, markup_before);
 		g_free (markup_before);
 	      }
 	  }
@@ -1868,7 +1806,7 @@ parseScoreInfo (xmlNodePtr scoreInfoElem, xmlNsPtr ns, DenemoScore * si)
 						      xmlChildrenNode, 1);
 	    if (markup_after != NULL)
 	      {
-		g_string_assign (si->headerinfo.lilypond_after, markup_after);
+		//g_string_assign (si->headerinfo.lilypond_after, markup_after);
 		g_free (markup_after);
 	      }
 	  }
@@ -1879,7 +1817,7 @@ parseScoreInfo (xmlNodePtr scoreInfoElem, xmlNsPtr ns, DenemoScore * si)
 						      xmlChildrenNode, 1);
 	    if (layout_markup != NULL)
 	      {
-		g_string_assign (si->headerinfo.layout, layout_markup);
+		//g_string_assign (si->headerinfo.layout, layout_markup);
 		g_free (layout_markup);
 	      }
 	  }
@@ -1930,6 +1868,10 @@ parseStaff (xmlNodePtr staffElem, xmlNsPtr ns, DenemoScore * si)
 		curStaff->no_of_lines = 5;
 	      }
 	  }
+	else if (ELEM_NAME_EQ (childElem, "volume"))
+	  {
+  	    curStaff->volume = getXMLIntChild (childElem);
+  	  }	    
         else if (ELEM_NAME_EQ (childElem, "midi_prognum_override"))
 	  {
   	    curStaff->midi_prognum_override = getXMLIntChild (childElem);
@@ -2002,20 +1944,42 @@ parseStaff (xmlNodePtr staffElem, xmlNsPtr ns, DenemoScore * si)
 	    curStaff->staff_prolog = (temp?g_string_new(temp):NULL);
 	    g_free (temp);
 	  }
-	else if (ELEM_NAME_EQ (childElem, "staff-prolog-insert"))
+	else if (ELEM_NAME_EQ (childElem, "staff-prolog-insert"))//backward compatibility only
 	  {
 	    gchar *temp = 
 	      (gchar *) xmlNodeListGetString (childElem->doc, childElem->xmlChildrenNode, 1);
-	    curStaff->staff_prolog_insert = (temp?g_string_new(temp):NULL);
-	    g_free (temp);
+	    if(temp) {
+	      DenemoDirective *directive =  (DenemoDirective*)g_malloc0(sizeof(DenemoDirective));
+	      directive->postfix = g_string_new(temp);
+	      curStaff->staff_directives = g_list_append(NULL, directive);
+	      g_free (temp);
+	    }
 	  }
-	else if (ELEM_NAME_EQ (childElem, "voice-prolog-insert"))
+	else if (ELEM_NAME_EQ (childElem, "voice-prolog-insert"))//backward compatibility only
 	  {
 	    gchar *temp = 
 	      (gchar *) xmlNodeListGetString (childElem->doc, childElem->xmlChildrenNode, 1);
-	    curStaff->voice_prolog_insert = (temp?g_string_new(temp):NULL);
-	    g_free (temp);
+	    if(temp) {
+	      DenemoDirective *directive =  (DenemoDirective*)g_malloc0(sizeof(DenemoDirective));
+	      directive->postfix = g_string_new(temp);
+	      curStaff->voice_directives = g_list_append(NULL, directive);
+	      g_free (temp);
+	    }
 	  }
+	else if (ELEM_NAME_EQ (childElem, "staff-directives"))
+	  {
+	    curStaff->staff_directives = parseDirectives(childElem, ns);
+	  }
+	else if (ELEM_NAME_EQ (childElem, "voice-directives"))
+	  {
+	    curStaff->voice_directives = parseDirectives(childElem, ns);
+	  }
+	else if (ELEM_NAME_EQ (childElem, "clef-directives"))
+	  {
+	    curStaff->clef.directives = parseDirectives(childElem, ns);
+	  }
+
+
 	else if (ELEM_NAME_EQ (childElem, "lyrics-prolog"))
 	  {
 	    gchar *temp = 
@@ -2179,19 +2143,17 @@ parseInitVoiceParams (xmlNodePtr initVoiceParamsElem, xmlNsPtr ns,
 	  }
 	else if (ELEM_NAME_EQ (childElem, "clef"))
 	  {
-	    parseClef (childElem, ns, &(curVoice->sclef));
+	    parseClef (childElem, ns, &(curVoice->clef.type));
 	  }
 	else if (ELEM_NAME_EQ (childElem, "key-signature"))
 	  {
-	    parseKeySignature (childElem, ns, &(curVoice->skey),
-			       &(curVoice->skey_isminor));
-	    initkeyaccs (curVoice->skeyaccs, curVoice->skey);
+	    parseKeySignature (childElem, ns, &(curVoice->keysig));
+	    initkeyaccs (curVoice->keysig.accs, curVoice->keysig.number);
 	    //dnm_setinitialkeysig(curVoice, curVoice->skey, curVoice->skey_isminor);
 	  }
 	else if (ELEM_NAME_EQ (childElem, "time-signature"))
 	  {
-	    parseTimeSignature (childElem, ns, &(curVoice->stime1),
-				&(curVoice->stime2));
+	    parseTimeSignature (childElem, ns, &curVoice->timesig);
 	  }
 	else
 	  {
@@ -2223,7 +2185,7 @@ parseMeasures (xmlNodePtr measuresElem, xmlNsPtr ns, DenemoScore * si)
   xmlNodePtr childElem, objElem, notesElem = NULL;
   DenemoObject *curObj, *prevChord = NULL;
   gboolean startedBeam = FALSE;
-  gint currentClef = ((DenemoStaff *) si->currentstaff->data)->sclef;
+  gint currentClef = ((DenemoStaff *) si->currentstaff->data)->clef.type;
   enum clefs newClef;
   gint keySig;
   gboolean isMinor;
@@ -2259,8 +2221,11 @@ parseMeasures (xmlNodePtr measuresElem, xmlNsPtr ns, DenemoScore * si)
 		  /* FIXME */
 		  g_warning ("Cannot yet handle <barline> elements");
 		}
+
+
 	      else if (ELEM_NAME_EQ (objElem, "beam-end"))
 		{
+#if 0
 		  /* Ignore beam attribute for now. */
 		  if (prevChord == NULL)
 		    {
@@ -2272,11 +2237,14 @@ parseMeasures (xmlNodePtr measuresElem, xmlNsPtr ns, DenemoScore * si)
 		      prevChord->isstart_beamgroup = FALSE;
 		      prevChord->isend_beamgroup = TRUE;
 		    }
+#endif
 		}
 	      else if (ELEM_NAME_EQ (objElem, "beam-start"))
 		{
+#if 0
 		  /* Ignore ID for now. */
 		  startedBeam = TRUE;
+#endif
 		}
 	      else if (ELEM_NAME_EQ (objElem, "chord"))
 		{
@@ -2336,9 +2304,10 @@ parseMeasures (xmlNodePtr measuresElem, xmlNsPtr ns, DenemoScore * si)
 	      else if (ELEM_NAME_EQ (objElem, "key-signature"))
 		{
 #if 1
-		  parseKeySignature (objElem, ns, &keySig, &isMinor);
-		  curObj = dnm_newkeyobj (keySig, isMinor, 0);
-		  initkeyaccs (((keysig *) curObj->object)->accs, keySig);
+		  curObj = dnm_newkeyobj (0, 0, 0);
+		  parseKeySignature (objElem, ns, curObj->object);
+		 
+		  initkeyaccs (((keysig *) curObj->object)->accs, ((keysig *)curObj->object)->number );
 		  //dnm_setinitialkeysig(((keysig *) curObj->object), keySig, isMinor);
 #else
 		  //warningdialog("Dodgy code");
@@ -2373,8 +2342,8 @@ parseMeasures (xmlNodePtr measuresElem, xmlNsPtr ns, DenemoScore * si)
 		}
 	      else if (ELEM_NAME_EQ (objElem, "time-signature"))
 		{
-		  parseTimeSignature (objElem, ns, &numerator, &denominator);
-		  curObj = dnm_newtimesigobj (numerator, denominator);
+		  curObj = dnm_newtimesigobj (4, 4);
+		  parseTimeSignature (objElem, ns, curObj->object);
 		}
 	      else if (ELEM_NAME_EQ (objElem, "tuplet-end"))
 		{
@@ -2535,6 +2504,18 @@ parseScore (xmlNodePtr scoreElem, xmlNsPtr ns, DenemoGUI * gui,
   //if (parseEditInfo (childElem, ns, si, staffnoPtr) != 0)
   //  return -1;
 
+  childElem = getXMLChild (scoreElem, "header-directives", ns);
+  if (childElem != 0)
+    si->header.directives = parseDirectives(childElem, ns);
+
+  childElem = getXMLChild (scoreElem, "layout-directives", ns);
+  if (childElem != 0)
+    si->layout.directives = parseDirectives(childElem, ns);
+
+  childElem = getXMLChild (scoreElem, "movementcontrol-directives", ns);
+  if (childElem != 0)
+    si->movementcontrol.directives = parseDirectives(childElem, ns);
+
   childElem = getXMLChild (scoreElem, "score-info", ns);
   RETURN_IF_ELEM_NOT_FOUND ("score", childElem, "score-info");
   if(type==REPLACE_SCORE)
@@ -2610,6 +2591,7 @@ static gint   parseMovement(xmlNodePtr childElem, xmlNsPtr ns, DenemoGUI *gui, I
 gint
 importXML (gchar * filename, DenemoGUI *gui, ImportType type)
 {
+
   gint ret = 0;
   xmlDocPtr doc = NULL;
   xmlNsPtr ns;
@@ -2626,6 +2608,7 @@ importXML (gchar * filename, DenemoGUI *gui, ImportType type)
       ret = -1;
       return ret;
     }
+  g_signal_handlers_block_by_func(G_OBJECT (gui->scorearea), G_CALLBACK (scorearea_expose_event), NULL);
 
   /*
    * Do a couple of sanity checks to make sure we've actually got a Denemo
@@ -2680,7 +2663,9 @@ importXML (gchar * filename, DenemoGUI *gui, ImportType type)
       FOREACH_CHILD_ELEM(childElem, rootElem){
 	if (ELEM_NAME_EQ (childElem, "lilycontrol") 
 	    || ELEM_NAME_EQ (childElem, "custom_scoreblock")
-	    || ELEM_NAME_EQ (childElem, "visible_scoreblock")){
+	    || ELEM_NAME_EQ (childElem, "visible_scoreblock")
+	    || ELEM_NAME_EQ (childElem, "scoreheader-directives")
+	    || ELEM_NAME_EQ (childElem, "paper-directives")){
 	  continue;
 	} else
 	ret |=  parseMovement(childElem, ns, gui, type);
@@ -2692,12 +2677,16 @@ importXML (gchar * filename, DenemoGUI *gui, ImportType type)
       FOREACH_CHILD_ELEM(childElem, rootElem){
 	if (ELEM_NAME_EQ (childElem, "lilycontrol") 
 	    || ELEM_NAME_EQ (childElem, "custom_scoreblock")
-	    || ELEM_NAME_EQ (childElem, "visible_scoreblock")){
+	    || ELEM_NAME_EQ (childElem, "visible_scoreblock")
+	    || ELEM_NAME_EQ (childElem, "scoreheader-directives")
+	    || ELEM_NAME_EQ (childElem, "paper-directives")){
 	  continue;/* do not change the header when adding movements parseScoreInfo(childElem, ns, gui);*/
-	} else {
-	  new_empty_score(gui);
+	} else	if (ELEM_NAME_EQ (childElem, "movement")) {
+	  point_to_empty_movement(gui);
 	  ret |=  parseMovement(childElem, ns, gui, type);
 	  //g_print("parsed movement\n");
+	} else {
+	  g_warning("Unexpected %s\n", childElem->name); 
 	}
       }
       break;
@@ -2706,60 +2695,80 @@ importXML (gchar * filename, DenemoGUI *gui, ImportType type)
       deleteSchemeText();
       /* this is dependent on the order of elements, which is not strictly correct */
       FOREACH_CHILD_ELEM(childElem, rootElem){
-
+	
 	if (ELEM_NAME_EQ (childElem, "scheme")) {
 	  gchar *tmp = (gchar *) xmlNodeListGetString (childElem->doc,
-						  childElem->
-						  xmlChildrenNode, 1);
+						       childElem->
+						       xmlChildrenNode, 1);
 	  if (tmp != NULL) {
 	    appendSchemeText(tmp);
 	    g_free (tmp);
 	  }
 	} else
-	if (ELEM_NAME_EQ (childElem, "lilycontrol")){
-	  parseSetupInfo(childElem, ns, gui);
-	} else
-	if (ELEM_NAME_EQ (childElem, "custom_scoreblock")){
+	  if (ELEM_NAME_EQ (childElem, "custom_prolog")){
 	    gchar *tmp = (gchar *) xmlNodeListGetString (childElem->doc,
-						  childElem->
-						  xmlChildrenNode, 1);
-	    if (tmp != NULL)
-	      {
-		DenemoScoreblock *sb = g_malloc0 (sizeof(DenemoScoreblock));
-		sb->scoreblock = g_string_new(tmp);
-		gui->custom_scoreblocks = g_list_prepend(gui->custom_scoreblocks, sb);
-		g_free (tmp);
-	      }
+							 childElem->
+							 xmlChildrenNode, 1);
+	    //gui->custom_prolog = g_string_new(tmp);
+	    g_print("The custom prolog \n\"%s\"\n is being ignored\n", tmp);
+	    warningdialog("custom prolog no longer supported. Use score directive prefix instead");
+	    g_free (tmp);
 	  } else
-	    if (ELEM_NAME_EQ (childElem, "visible_scoreblock")){
-	      {
-		if (gui->custom_scoreblocks)
-		  {
-		    DenemoScoreblock *sb =  (DenemoScoreblock*)gui->custom_scoreblocks->data;
-		    sb->visible = TRUE;
-		  }
-	      }
-	    }
-	    else {
-	      new_empty_score(gui);
-	      ret |=  parseMovement(childElem, ns, gui, type);
-	    }
+	    if (ELEM_NAME_EQ (childElem, "lilycontrol")){
+	      parseSetupInfo(childElem, ns, gui);
+	    } else
+	      if (ELEM_NAME_EQ (childElem, "scoreheader-directives")){
+		gui->scoreheader.directives = parseDirectives(childElem, ns);
+	      } else
+		if (ELEM_NAME_EQ (childElem, "paper-directives")){
+		  gui->paper.directives = parseDirectives(childElem, ns);
+		} else
+		  if (ELEM_NAME_EQ (childElem, "custom_scoreblock")){
+		    gchar *tmp = (gchar *) xmlNodeListGetString (childElem->doc,
+								 childElem->
+								 xmlChildrenNode, 1);
+		    if (tmp != NULL)
+		      {
+			DenemoScoreblock *sb = g_malloc0 (sizeof(DenemoScoreblock));
+			sb->scoreblock = g_string_new(tmp);
+			gui->custom_scoreblocks = g_list_prepend(gui->custom_scoreblocks, sb);
+			g_free (tmp);
+		      }
+		  } else
+		    if (ELEM_NAME_EQ (childElem, "visible_scoreblock")){
+		      {
+			if (gui->custom_scoreblocks)
+			  {
+			    DenemoScoreblock *sb =  (DenemoScoreblock*)gui->custom_scoreblocks->data;
+			    sb->visible = TRUE;
+			  }
+		      }
+		    }  else 
+		      if (ELEM_NAME_EQ (childElem, "movement")){
+			point_to_empty_movement (gui);
+			ret |=  parseMovement(childElem, ns, gui, type);
+		      } else 
+			{
+			  g_warning("unrecognized element in score -assuming movement");
+			  point_to_empty_movement(gui);
+			  ret |=  parseMovement(childElem, ns, gui, type);
+			}
       }
-
-      if(getNumCharsSchemeText())
+	
+	if(getNumCharsSchemeText())
 	  executeScript(); 
-      break;
-    default:
-      warningdialog("Erroneous call");
-      goto cleanup;
-    } 
-  } else {//version 1
+	break;
+      default:
+	warningdialog("Erroneous call");
+	goto cleanup;
+      } 
+    } else {//version 1
     switch(type) {
     case ADD_STAFFS:
       ret +=  parseMovement(rootElem, ns, gui, type);
       break;
     case ADD_MOVEMENTS:
-      new_empty_score(gui);
+      point_to_empty_movement(gui);
       ret =  parseMovement(rootElem, ns, gui, type);
       break;
     case REPLACE_SCORE:
@@ -2787,7 +2796,7 @@ importXML (gchar * filename, DenemoGUI *gui, ImportType type)
   g_hash_table_destroy (sXMLIDToElemMap);
   sXMLIDToElemMap = NULL;
 
-
+  g_signal_handlers_unblock_by_func(G_OBJECT (gui->scorearea), G_CALLBACK (scorearea_expose_event), NULL);
   //g_print("Number of movements %d\n", g_list_length(gui->movements));
   return ret;
 }
