@@ -37,14 +37,21 @@
 #include <glib/gstdio.h>
 #include "midiseq.h"
 #include <libguile.h>
-struct DenemoRoot Denemo;
-midi_seq *sq;
 #include "view.h"
 #include "exportxml.h"
 #include "runsilent.h"
 #include "utils.h"
 #include "alsaplayback.h"
+#ifdef _HAVE_JACK_
+#include "jackmidi.h"
+#endif
+#ifdef WITH_LASH
+#include <lash/lash.h>
+#include "lash_support.h"
+#endif
 
+struct DenemoRoot Denemo;
+midi_seq *sq;
 
 
 static const GtkStockItem denemo_stock_items[] = {
@@ -439,8 +446,8 @@ main (int argc, char *argv[])
 
   register_stock_items ();
   //g_print("Calling scm boot guile with %d and %p\n", argc, argv);
- 
   scm_boot_guile (argc, argv, inner_main, NULL);
+  
   return 0;
 }
 
@@ -540,10 +547,16 @@ COPYING for details.\n\n") ;
   //readHistory();
   /* Set up the keymap */
   //init_keymap();
-  
+
+#ifdef _HAVE_JACK_
+  g_debug("\nDenemo.prefs.jack_at_startup = %d\n", Denemo.prefs.jack_at_startup);
+  if (Denemo.prefs.jack_at_startup)
+    init_jack();
+#else
   /* audio initialization */
   ext_init ();                  /* external players (midi...) */
 
+
   /* Immediate Playback */
   if(Denemo.prefs.immediateplayback) {
     if( midi_init ()  )  {           /* Opens Denemo.prefs.sequencer, if this is set to an empty
@@ -554,6 +567,17 @@ COPYING for details.\n\n") ;
 
     }
   }
+#endif
+
+#ifdef WITH_LASH
+  lash_client_t* lash_client;
+  int flags = 0;
+  flags = LASH_Config_Data_Set;
+
+  lash_client = lash_init(lash_extract_args(&argc, &argv), "denemo",
+		                           flags, LASH_PROTOCOL(2, 0));
+  start_init_lash(lash_client);
+#endif
 
 
 
@@ -659,5 +683,6 @@ COPYING for details.\n\n") ;
           g_print ("Attempt to read in file %s failed\n", argv[optind]);
           return 1;
         } 
-    }
+    } else
+      open_user_default_template();
 }
