@@ -63,10 +63,15 @@ addmeasures (DenemoScore * si, gint pos, guint nummeasures, gint all)
 	  ((DenemoStaff *) si->currentstaff->data)->nummeasures++;
 
 	}
-      if (g_list_length (si->measurewidths) <
-	  ((DenemoStaff *) si->currentstaff->data)->nummeasures)
+
+      gint maxmeasures=0;
+      for (curstaff = si->thescore; curstaff; curstaff = curstaff->next)
+	{
+	  maxmeasures = MAX(maxmeasures,  ((DenemoStaff *) curstaff->data)->nummeasures);
+	}
+
+      if (g_list_length (si->measurewidths) < maxmeasures)
 	{
-/* ???????????????? what if different staffs have different nummeasures??????? */
 	  si->measurewidths = g_list_insert (si->measurewidths,
 					     GINT_TO_POINTER (si->
 							      measurewidth),
@@ -669,9 +674,10 @@ showwhichaccidentals (objnode * theobjs, gint initialnum, gint * initialaccs)
 		/* A new accidental not present in the original chord */
 		thetone->showaccidental =
 		  ((chord *) theobj->object)->hasanacc = TRUE;
-	      else if (thetone->postfix && (*thetone->postfix->str=='!'|| *thetone->postfix->str=='?'))
-		thetone->showaccidental =
-		  ((chord *) theobj->object)->hasanacc = TRUE;
+	      // FIXME - you should use a script to apply these directives & set hasnacc with that.
+	      else if (thetone->directives && ((DenemoDirective*)thetone->directives->data)->postfix && (* ((DenemoDirective*)thetone->directives->data)    ->postfix->str=='!'|| *  ((DenemoDirective*)thetone->directives->data)    ->postfix->str=='?'))
+	     	thetone->showaccidental =
+	     	  ((chord *) theobj->object)->hasanacc = TRUE;
 	      else
 		thetone->showaccidental = FALSE;
 	    }			/* End second loop through chord */
