@@ -1,4 +1,4 @@
-/* mousing.cpp
+/* mousing.c
  * callback functions for handling mouse clicks, drags, etc.
  *
  *  for Denemo, a gtk+ frontend to GNU Lilypond
@@ -63,18 +63,18 @@ set_cursor_y_from_click (DenemoGUI * gui, gdouble y)
   DenemoStaff *staff;
   gint extra_space = 0;
   for(  curstaff = g_list_nth(gui->si->thescore,gui->si->top_staff-1) ; curstaff;curstaff=curstaff->next) {
-    //    g_print("extra space %d\n", extra_space);
+    //g_print("before extra space %d\n", extra_space);
     staff = (DenemoStaff *) curstaff->data;
     if(staff->voicenumber == 1)
-      extra_space += (staff->space_above );
+      extra_space += (staff->space_above*2 );
     if(curstaff == gui->si->currentstaff)
       break;
     if(staff->voicenumber == 1){
       // FIXME this cannot work, different amounts of space_xxx may be stored in different voices
-      extra_space += ((staffs_from_top?staff->space_below:0) + (staff->haslyrics?LYRICS_HEIGHT:0));
+      extra_space += ((staff->space_below) + (staff->haslyrics?LYRICS_HEIGHT:0));
       staffs_from_top++;
     }
-
+    //g_print("after extra space %d\n", extra_space);
   }
 
   click_height =
@@ -277,6 +277,7 @@ perform_command(gint modnum, mouse_gesture press, gboolean left)
   g_string_free(modname, TRUE);
 }  
 
+static gboolean selecting = FALSE;
 
 /**
  * Mouse motion callback 
@@ -286,7 +287,8 @@ gint
 scorearea_motion_notify (GtkWidget * widget, GdkEventButton * event)
 {
   DenemoGUI *gui = Denemo.gui;
-    if (gui->si->markstaffnum){
+  //  g_print("Marked %d\n", gui->si->markstaffnum);
+    if (selecting && gui->si->markstaffnum){
       struct placement_info pi; 
       if (event->y < 0)
 	get_placement_from_coordinates (&pi, event->x, 0, gui->si);
@@ -328,10 +330,43 @@ scorearea_button_press (GtkWidget * widget, GdkEventButton * event)
 DenemoGUI *gui = Denemo.gui;
   struct placement_info pi;
   gboolean left = (event->button != 3);
+
+  if(gui->si->top_staff==1 && 
+     event->y < ((DenemoStaff *) gui->si->thescore->data)->space_above) {
+    popup_menu("/ScorePopup");
+    return TRUE;
+  }
+  gint key = gui->si->maxkeywidth;
+  gint cmajor = key?0:5;//allow some area for keysig in C-major
+  if(left && (gui->si->leftmeasurenum>1) && (event->x<KEY_MARGIN+SPACE_FOR_TIME+key)  && (event->x>LEFT_MARGIN)){
+    set_currentmeasurenum (gui, gui->si->leftmeasurenum-1);
+    gtk_widget_queue_draw (gui->scorearea);
+    return TRUE;
+  } 
   if (event->y < 0)
     get_placement_from_coordinates (&pi, event->x, 0, gui->si);
   else
     get_placement_from_coordinates (&pi, event->x, event->y, gui->si);
+
+  gui->si->currentstaff = pi.the_staff;
+  gui->si->currentstaffnum = pi.staff_number;
+
+
+  if(event->x<LEFT_MARGIN) {
+    popup_menu("/StaffMenuPopup");
+    return TRUE;
+  } else if(gui->si->leftmeasurenum==1) {
+    if(event->x<KEY_MARGIN-cmajor) {
+      popup_menu("/InitialClefEditPopup");
+      return TRUE;
+    }  else  if(event->x<KEY_MARGIN+key+cmajor) {
+      popup_menu("/InitialKeyEditPopup");
+      return TRUE;
+    } else  if(event->x<KEY_MARGIN+SPACE_FOR_TIME+key) {
+      popup_menu("/InitialTimeEditPopup");
+      return TRUE;
+    }
+  }
   if (pi.the_measure != NULL){ /*don't place cursor in a place that is not there*/
 	 
     gui->si->currentstaffnum = pi.staff_number;
@@ -350,10 +385,12 @@ DenemoGUI *gui = Denemo.gui;
     
     if(left)
       set_mark(gui);
+    selecting = TRUE;
     write_status(gui);
     /* Redraw to show new cursor position, note a real draw is needed because of side effects on display*/
     gtk_widget_draw (gui->scorearea, NULL);
-    g_signal_handlers_unblock_by_func(gui->scorearea, G_CALLBACK (scorearea_motion_notify), gui);   
+
+    //g_signal_handlers_unblock_by_func(gui->scorearea, G_CALLBACK (scorearea_motion_notify), gui);   
   }
   set_cursor_for(event->state | (left?GDK_BUTTON1_MASK:GDK_BUTTON3_MASK));
   perform_command(event->state | (left?GDK_BUTTON1_MASK:GDK_BUTTON3_MASK), GESTURE_PRESS, left);
@@ -371,8 +408,8 @@ scorearea_button_release (GtkWidget * widget, GdkEventButton * event)
 {
 DenemoGUI *gui = Denemo.gui;
  gboolean left = (event->button != 3);
- g_signal_handlers_block_by_func(gui->scorearea, G_CALLBACK (scorearea_motion_notify), gui); 
-
+ //g_signal_handlers_block_by_func(gui->scorearea, G_CALLBACK (scorearea_motion_notify), gui); 
+ selecting = FALSE;
  set_cursor_for(event->state&DENEMO_MODIFIER_MASK);
  perform_command(event->state, GESTURE_RELEASE, left);
 
