@@ -28,6 +28,22 @@ freeobject (DenemoObject * mudobj)
       case CHORD:
 	freechord (mudobj);	/* Which also frees mudobj itself */
 	break;
+      case CLEF:
+	free_directives(((clef*)mudobj->object)->directives);
+	g_free (mudobj);
+	break;
+
+      case KEYSIG:
+	free_directives(((keysig*)mudobj->object)->directives);
+	g_free (mudobj);
+	break;
+      case TIMESIG:
+	free_directives(((timesig*)mudobj->object)->directives);
+	g_free (mudobj);
+	break;
+
+
+
       default:
 	g_free (mudobj);
 	break;
@@ -194,7 +210,56 @@ newstaffbreakobject ()
   return ret;
 }
 
+DenemoDirective *clone_directive(DenemoDirective *directive) {
+  DenemoDirective *ret = (DenemoDirective *)g_malloc0(sizeof(DenemoDirective));
+  memcpy(ret, directive, sizeof(DenemoDirective));//BEWARE all pointers in DenemoDirective require code, as follows:
+#define CLONE(field) \
+      if(directive->field && directive->field->len)\
+        ret->field = g_string_new(directive->field->str);
+  CLONE(tag);
+  CLONE(prefix);
+  CLONE(postfix);
+  CLONE(display);
+  CLONE(graphic_name);
+#undef CLONE
+  if(directive->graphic) {    
+    ret->graphic = directive->graphic;//alternatively could load it via loadGraphicItem, is the same
+  }
+  return ret;
+}
 
+
+GList *clone_directives(GList *directives) {
+  GList *ret=NULL;
+  for(;directives;directives=directives->next)
+    ret = g_list_append(ret, clone_directive(directives->data));
+  return ret;
+}
+void
+free_directive_data(DenemoDirective *directive) {
+#define DFREE(field) if(directive->field) g_string_free(directive->field, TRUE);
+    DFREE(tag);
+    DFREE(display);
+    DFREE(prefix);
+    DFREE(postfix);
+    DFREE(graphic_name);
+#undef DFREE
+    //if(directive->graphic)
+    //  g_object_unref(directive->graphic); we leave these in a hash table now, and never discard them
+}
+void
+free_directive(DenemoDirective *directive) {
+  free_directive_data(directive);
+  g_free(directive);
+}
+void
+free_directives(GList *directives) {
+  for(;directives;directives=directives->next) {
+    DenemoDirective *directive = directives->data;
+    free_directive(directive);
+  } 
+  g_list_free(directives);
+}
 /**
  * Create a clone of the given object
  * @param orig the object to clone
@@ -203,26 +268,57 @@ newstaffbreakobject ()
 DenemoObject *
 dnm_clone_object (DenemoObject * orig)
 {
-  DenemoObject *ret;
+  DenemoObject *ret=NULL;
   if (orig != NULL) {
 	  switch (orig->type)
 	    {
 	    case CHORD:
 	      ret = clone_chord (orig);
 	      break;
+	    
+	    case TUPOPEN:
+	      ret  = newtupopen(((tupopen*)orig->object)->numerator, ((tupopen*)orig->object)->denominator);	  
+	      break;
+	    case TUPCLOSE:
+	      ret  = newtupclose();
+	      break;
+	    case CLEF:
+	      ret = dnm_newclefobj (((clef *)orig->object)->type);
+	      ((clef *)ret->object)->directives = clone_directives(((clef *)orig->object)->directives);
+	      break;
+	    case TIMESIG:
+	      ret = dnm_newtimesigobj (((timesig *)orig->object)->time1,((timesig *)orig->object)->time2 );
+	      ((timesig *)ret->object)->directives = clone_directives(((timesig *)orig->object)->directives);
+
+	      break;
+	    case KEYSIG:
+	      ret = dnm_newkeyobj (((keysig *)orig->object)->number,((keysig *)orig->object)->isminor,((keysig *)orig->object)->mode);
+	      ((keysig *)ret->object)->directives = clone_directives(((keysig *)orig->object)->directives);
+
+	      break;
+	      break;
+	    case STEMDIRECTIVE:
+	      ret = dnm_stem_directive_new  (((stemdirective *)orig->object)->type);
+	      break;
+	    case MEASUREBREAK:
+	      ret = newmeasurebreakobject ();
+	      break;
+	    case STAFFBREAK:
+	      ret = newstaffbreakobject ();
+	      break;
+	    case GRACE_START:
+	      ret = newgracestart ();
+	      break;
+	    case GRACE_END:
+	      ret = newgraceend ();
+	      break;
 	    case LILYDIRECTIVE: {
 	      lilydirective *curlily = (lilydirective*)orig->object;
-	      ret = lily_directive_new(curlily->directive->str);
-	      lilydirective *newlily = (lilydirective *)ret->object;
-	      if(curlily->display && curlily->display->len)
-		newlily->display = g_string_new(curlily->display->str);
-	      ret->minpixelsalloted = orig->minpixelsalloted;
-	      newlily->locked = curlily->locked;
-		 }
+	      ret = directive_object_new(clone_directive(curlily));
+	    }
 	      break;
 	    default:
-	      ret = (DenemoObject *) g_malloc (sizeof (DenemoObject));
-	      memcpy (ret, orig, sizeof (DenemoObject));//dangerous ret->object is duplicated pointer
+	      g_warning("Unknown object type"); 
 	      break;
 	    }
   }
@@ -262,16 +358,26 @@ lily_directive_new (gchar * type)
 {
   DenemoObject *ret;
   lilydirective *newlily =
-    (lilydirective *) g_malloc (sizeof (lilydirective));
-  ret = (DenemoObject *) g_malloc (sizeof (DenemoObject));
+    (lilydirective *) g_malloc0 (sizeof (lilydirective));
+  ret = (DenemoObject *) g_malloc0 (sizeof (DenemoObject));
   ret->type = LILYDIRECTIVE;
-  newlily->directive = g_string_new (type);
+  newlily->postfix = g_string_new (type);
   ret->object = newlily;
   set_basic_numticks (ret);
   setpixelmin (ret);
   return ret;
 }
 
+DenemoObject *
+directive_object_new(DenemoDirective *directive) {
+  DenemoObject *ret;
+  ret = (DenemoObject *) g_malloc0 (sizeof (DenemoObject));
+  ret->type = LILYDIRECTIVE;
+  ret->object = directive;
+  set_basic_numticks (ret);
+  setpixelmin (ret);
+  return ret;
+}
 
 /**
  * Create a new dynamic object
@@ -348,12 +454,12 @@ void
 dnm_setinitialkeysig (DenemoStaff * curstaff, gint tokey, gint type)
 {
 
-  curstaff->skey = tokey;
-  curstaff->skey_isminor = type;
-
-  initkeyaccs (curstaff->leftmost_keyaccs, tokey);
-  memcpy (curstaff->skeyaccs, curstaff->leftmost_keyaccs, SEVENGINTS);
+  curstaff->keysig.number = tokey;
+  curstaff->keysig.isminor = type;
 
+  initkeyaccs (curstaff->keysig.accs, tokey);
+  //memcpy (curstaff->keysig.keyaccs, curstaff->leftmost_keyaccs, SEVENGINTS);
+  curstaff->leftmost_keysig = &curstaff->keysig;
   showwhichaccidentalswholestaff (curstaff);
 
 }
