@@ -418,7 +418,7 @@ static gboolean  apply_tones(DenemoScore *si) {
 	    modify_note((chord*)theobj->object, mid_c_offset, thetone->enshift, dclef);
 	    tone_stored=TRUE;
 	    if(!si->cursor_appending)
-	      cursorright(Denemo.gui);
+	      cursorright(NULL);
 	    store_el = store_el->next;
 
 	  }// tone available
@@ -696,8 +696,12 @@ gint pitchentry(DenemoGUI *gui) {
 	display_pitch(note, gui);
 	if(gui->input_source==INPUTMIDI)
 	  play_pitch(found->pitch * (pow(2,(octave))), 0.3, 0.5, 0);
-	if(!Denemo.prefs.overlays)
+	if(!Denemo.prefs.overlays) {
 	  enter_note_in_score(gui, found, octave);
+	  if(gui->mode & INPUTRHYTHM) {
+	    scheme_next_note(NULL);
+	  }
+	}
 	else
 	  enter_tone_in_store(gui, found, octave);
       }
@@ -1265,6 +1269,9 @@ gint setup_pitch_input(void){
       set_threshold(0.3);
       set_smoothing(6.0);
     }
+    if(gui->input_source==INPUTMIDI) {
+      PR_time = 5;
+    }
   } else
     return -1;
   transposition_required = 1.0;
@@ -1319,7 +1326,7 @@ gchar *determine_interval(gint bass, gint harmony){
   gint bass_octave, harmony_octave;
   gdouble deviation;
   gint semitones = harmony - bass;
-  gint *accs = ((DenemoStaff*)Denemo.gui->si->currentstaff->data)->skeyaccs;
+  gint *accs = ((DenemoStaff*)Denemo.gui->si->currentstaff->data)->keysig.accs;
  notepitch bassnote = PR_temperament->notepitches[bass%12];
  notepitch harmonynote = PR_temperament->notepitches[harmony%12];
  gint interval =  harmonynote.spec.step - bassnote.spec.step + 1;
