@@ -28,6 +28,7 @@
 #include <wait.h>
 #endif
 #include <errno.h>
+#include "jackmidi.h"
 
 static gint timeout_id = 0, kill_id=0;
 static gdouble duration;
@@ -170,27 +171,34 @@ ext_midi_playback_control (gboolean start)
   if(gui->si->end==0) {//0 means not set, we move the cursor on unless the specific range was specified
     DenemoStaff *staff = (DenemoStaff *) gui->si->currentstaff->data;
   //FIXME add a delay before starting the timer.
-  timeout_id = g_timeout_add ( 4*((double)staff->stime1/(double)staff->stime2)/(gui->si->tempo/(60.0*1000.0)), 
+  timeout_id = g_timeout_add ( 4*((double)staff->timesig.time1/(double)staff->timesig.time2)/(gui->si->tempo/(60.0*1000.0)), 
 			       (GSourceFunc)move_on, gui);
   kill_id = g_timeout_add (duration*1000, (GSourceFunc)kill_timer, NULL);
   }
   return;
 }
 
-
 /* start or restart an external midi player
  * trying avoid multiple instances of it
  */
 void
 ext_midi_playback (GtkAction * action, gpointer param)
 {
+#ifdef _HAVE_JACK_
+  jack_midi_playback_start();
+#else
   ext_midi_playback_control (TRUE);
-
+#endif
 }
 
 void stop_midi_playback (GtkAction * action, gpointer param) {
+#ifdef _HAVE_JACK_
+ jack_midi_playback_stop();
+ jack_kill_timer();
+#else
  ext_midi_playback_control (FALSE);
  kill_timer();
+#endif
 }
 
 
