@@ -19,23 +19,33 @@
 #include "prefops.h"
 #include "utils.h"
 #include "plugin.h"
+#ifdef _HAVE_JACK_
+#include "jackmidi.h"
+#endif
 
 struct callbackdata
 {
   DenemoPrefs *prefs;
-  GtkWidget *lilypathentry;
-  GtkWidget *checkimmediateplayback;
-  GtkWidget *checkautosaveparts;
-  GtkWidget *checkautosave;
-  GtkWidget *checknotationpalette;
-  GtkWidget *checkrhythmpalette;
-  GtkWidget *checkarticulationpalette;
-  GtkWidget *autosaveentry;
+  GtkWidget *lilypath;
+  GtkWidget *immediateplayback;
+  GtkWidget *saveparts;
+  GtkWidget *autosave;
+  GtkWidget *notation_palette;
+  GtkWidget *rhythm_palette;
+  GtkWidget *articulation_palette;
+  GtkWidget *visible_titles;
+  GtkWidget *autosave_timeout;
   GtkWidget *maxhistory;
-  GtkWidget *browserentry;
+  GtkWidget *browser;
   GtkWidget *pdfviewer;
+  GtkWidget *imageviewer;
   GtkWidget *sequencer;
   GtkWidget *midi_in;
+#ifdef _HAVE_JACK_
+  GtkWidget *jacktransport;
+  GtkWidget *jacktransport_start_stopped;
+  GtkWidget *jack_at_startup;
+#endif
   GtkWidget *texteditor;
   GtkWidget *denemopath;
   GtkWidget *temperament;
@@ -59,9 +69,11 @@ struct callbackdata1
  * clicked
  */
 static void
-toggle_autosave (GtkToggleButton * togglebutton, GtkWidget * autosaveentry)
+toggle_autosave (GtkToggleButton * togglebutton, GtkWidget * autosave_timeout)
 {
-  gtk_widget_set_sensitive (autosaveentry,
+  g_debug("autosave now %d\n", 
+     gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(autosave_timeout)));
+  gtk_widget_set_sensitive (autosave_timeout,
 			    gtk_toggle_button_get_active (togglebutton));
 }
 
@@ -109,70 +121,52 @@ set_preferences (struct callbackdata *cbdata)
   DenemoPrefs *prefs = cbdata->prefs;
 
 
-  g_string_assign (prefs->lilypath,
-		   gtk_entry_get_text (GTK_ENTRY (cbdata->lilypathentry)));
-  g_string_assign (prefs->browser,
-		   gtk_entry_get_text (GTK_ENTRY (cbdata->browserentry)));
-  g_string_assign (prefs->pdfviewer,
-		   gtk_entry_get_text (GTK_ENTRY (cbdata->pdfviewer)));
-  g_string_assign (prefs->texteditor,
-		   gtk_entry_get_text (GTK_ENTRY (cbdata->texteditor)));
-  g_string_assign (prefs->denemopath,
-                   gtk_entry_get_text (GTK_ENTRY (cbdata->denemopath)));
-
 #define ASSIGNTEXT(field) \
   g_string_assign (prefs->field,\
-                   gtk_entry_get_text (GTK_ENTRY (cbdata->field)))
-
-
-  ASSIGNTEXT(sequencer);
-  ASSIGNTEXT(midi_in);
+                   gtk_entry_get_text (GTK_ENTRY (cbdata->field)));
 
 #define ASSIGNBOOLEAN(field) \
   prefs->field =\
     gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(cbdata->field));
 
-  ASSIGNTEXT(sequencer);
-  ASSIGNTEXT(midi_in);
-  ASSIGNTEXT(temperament);
-  ASSIGNBOOLEAN(strictshortcuts);
-  ASSIGNBOOLEAN(overlays);
-  ASSIGNBOOLEAN(continuous);
-
 #define ASSIGNINT(field) \
    prefs->field =\
     gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(cbdata->field));
 
-  ASSIGNINT(resolution);
-  ASSIGNINT(maxhistory);
 
-  prefs->immediateplayback =
-    gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON
-				  (cbdata->checkimmediateplayback));
-
-  prefs->autosave =
-    gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (cbdata->checkautosave));
-  prefs->autosave_timeout =
-    gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
-				      (cbdata->autosaveentry));
-
-  prefs->articulation_palette =
-    gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON
-				  (cbdata->checkarticulationpalette));
-  prefs->notation_palette =
-    gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON
-				  (cbdata->checknotationpalette));
-  prefs->rhythm_palette =
-    gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON
-				  (cbdata->checkrhythmpalette));
-  prefs->saveparts =
-  	gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON
-  				  (cbdata->checkautosaveparts));
+  ASSIGNTEXT(lilypath)
+  ASSIGNTEXT(browser) 
+  ASSIGNTEXT(pdfviewer)
+  ASSIGNTEXT(imageviewer)
+  ASSIGNTEXT(texteditor)
+  ASSIGNTEXT(denemopath)
+  ASSIGNTEXT(sequencer)
+  ASSIGNTEXT(midi_in)
+  ASSIGNTEXT(sequencer)
+  ASSIGNTEXT(midi_in)
+#ifdef _HAVE_JACK_
+  ASSIGNBOOLEAN(jacktransport)
+  ASSIGNBOOLEAN(jacktransport_start_stopped)
+  ASSIGNBOOLEAN(jack_at_startup)
+#endif
+  ASSIGNTEXT(temperament)
+  ASSIGNBOOLEAN(strictshortcuts)
+  ASSIGNBOOLEAN(overlays)
+  ASSIGNBOOLEAN(continuous)
+  ASSIGNINT(resolution)
+  ASSIGNINT(maxhistory)
+  ASSIGNBOOLEAN(immediateplayback)
+  ASSIGNBOOLEAN(autosave)
+  ASSIGNINT(autosave_timeout)
+  ASSIGNBOOLEAN(articulation_palette)
+  ASSIGNBOOLEAN(visible_titles)
+  ASSIGNBOOLEAN(notation_palette)
+  ASSIGNBOOLEAN(rhythm_palette)
+  ASSIGNBOOLEAN(saveparts)
   //g_print ("Timeout %d \n", prefs->autosave_timeout);
 
   /* Now write it all to denemorc */
   writeXMLPrefs (prefs);
-
 }
 
 void
@@ -182,29 +176,9 @@ preferences_change (GtkAction *action, gpointer param)
   GtkWidget *dialog;
   GtkWidget *label;
   GtkWidget *main_vbox;
-  GtkWidget *lilypathentry;
-  GtkWidget *browserentry;
-  GtkWidget *checkimmediateplayback;
-  GtkWidget *checkautosaveparts;
-  GtkWidget *checkautosave;
-  GtkWidget *autosaveentry;
+  GtkWidget *autosave;
+  GtkWidget *autosave_timeout;
   GtkWidget *maxhistory;
-  GtkWidget *pdfviewer;
-  GtkWidget *midi_in;
-  GtkWidget *sequencer;
-  GtkWidget *texteditor;
-  GtkWidget *denemopath;
-  GtkWidget *checknotationpalette;
-  GtkWidget *checkrhythmpalette;
-  GtkWidget *checkarticulationpalette;
-  GtkWidget *strictshortcuts;
-  GtkWidget *resolution;
-  GtkWidget *overlays;
-  GtkWidget *continuous;
-
-
-
-
   GtkWidget *notebook;
   GtkWidget *hbox;
   GtkWidget *vbox;
@@ -215,7 +189,6 @@ preferences_change (GtkAction *action, gpointer param)
   GtkCellRenderer *renderer;
   GtkWidget *entrywidget;
   static struct callbackdata cbdata;
-  static struct callbackdata1 cbdata1;
   g_assert (gui != NULL);
 
   dialog = gtk_dialog_new_with_buttons (_("Preferences - Denemo"),
@@ -232,73 +205,19 @@ preferences_change (GtkAction *action, gpointer param)
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), notebook, TRUE,
 		      TRUE, 0);
 
-  /*
-   * Note entry settings
-   */
-  main_vbox = gtk_vbox_new (FALSE, 1);
-  
+#define NEWPAGE(thelabel) \
+    main_vbox = gtk_vbox_new (FALSE, 1);\
+    gtk_notebook_append_page (GTK_NOTEBOOK (notebook), main_vbox, NULL);\
+    gtk_notebook_set_tab_label_text (GTK_NOTEBOOK (notebook), main_vbox,\
+                                                           _(thelabel));
 
-  gtk_notebook_append_page (GTK_NOTEBOOK (notebook), main_vbox, NULL);
-  gtk_notebook_set_tab_label_text (GTK_NOTEBOOK (notebook), main_vbox,
-				   _("View"));
-
-  checkimmediateplayback =
-    gtk_check_button_new_with_label (_
-				     ("Play back entered notes immediately"));
-  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkimmediateplayback),
-				Denemo.prefs.immediateplayback);
-
-  gtk_box_pack_start (GTK_BOX (main_vbox), checkimmediateplayback, FALSE, TRUE, 0);
-
-  checknotationpalette =
-    gtk_check_button_new_with_label (_("Display durations toolbar"));
-  gtk_widget_set_sensitive (checknotationpalette, TRUE);
-  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checknotationpalette),
-				Denemo.prefs.notation_palette);
-
-  gtk_box_pack_start (GTK_BOX (main_vbox), checknotationpalette      , FALSE, TRUE, 0);
- 
-
-  checkarticulationpalette =
-    gtk_check_button_new_with_label (_("Display articulation palette"));
-  gtk_widget_set_sensitive (checkarticulationpalette, TRUE);
-  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkarticulationpalette),
-				Denemo.prefs.articulation_palette);
-  gtk_box_pack_start (GTK_BOX (main_vbox), checkarticulationpalette   , FALSE, TRUE, 0);
-
-
-  checkrhythmpalette =
-    gtk_check_button_new_with_label (_("Display rhythm pattern toolbar"));
-  gtk_widget_set_sensitive (checkrhythmpalette, TRUE);
-  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkrhythmpalette),
-				Denemo.prefs.rhythm_palette);
-  gtk_box_pack_start (GTK_BOX (main_vbox),checkrhythmpalette, FALSE, TRUE, 0);
-
-  hbox = gtk_hbox_new (FALSE, 8);
-  gtk_box_pack_start (GTK_BOX (main_vbox), hbox, FALSE, TRUE, 0);
-
-  checkautosave = gtk_check_button_new_with_label (_("Autosave every"));
-  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkautosave),
-				Denemo.prefs.autosave);
-  gtk_box_pack_start (GTK_BOX (hbox), checkautosave, FALSE, FALSE, 0);
-
-  autosaveentry = gtk_spin_button_new_with_range (1, 50, 1.0);
-  gtk_spin_button_set_value (GTK_SPIN_BUTTON (autosaveentry),
-			     Denemo.prefs.autosave_timeout);
-  gtk_widget_set_sensitive (autosaveentry, Denemo.prefs.autosave);
-  gtk_box_pack_start (GTK_BOX (hbox), autosaveentry, FALSE, FALSE, 0);
-
-  label = gtk_label_new (_("minute(s)"));
-  gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-  g_signal_connect (GTK_OBJECT (checkautosave),
-		    "toggled", G_CALLBACK (toggle_autosave), autosaveentry);
-
-
-  checkautosaveparts = gtk_check_button_new_with_label(_("Autosave Parts"));
-  gtk_widget_set_sensitive (checkautosaveparts, FALSE);
-  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkautosaveparts),
-				Denemo.prefs.saveparts);
-  gtk_box_pack_start (GTK_BOX (main_vbox), checkautosaveparts, FALSE, TRUE, 0);
+#define BOOLEANENTRY(thelabel, field) \
+  GtkWidget *field =\
+    gtk_check_button_new_with_label (thelabel); \
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (field),\
+				Denemo.prefs.field);\
+  gtk_box_pack_start (GTK_BOX (main_vbox), field, FALSE, TRUE, 0);\
+  cbdata.field = field;
 
 #define TEXTENTRY(thelabel, field) \
   hbox = gtk_hbox_new (FALSE, 8);\
@@ -306,12 +225,65 @@ preferences_change (GtkAction *action, gpointer param)
   label = gtk_label_new (_(thelabel));\
   gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);\
   gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);\
-  entrywidget = gtk_entry_new ();\
-  gtk_entry_set_text (GTK_ENTRY (entrywidget), Denemo.prefs.field->str);\
-  gtk_box_pack_start (GTK_BOX (hbox), entrywidget, TRUE, TRUE, 0);\
-  cbdata.field = entrywidget;
- 
+  GtkWidget *field = gtk_entry_new ();\
+  gtk_entry_set_text (GTK_ENTRY (field), Denemo.prefs.field->str);\
+  gtk_box_pack_start (GTK_BOX (hbox), field, TRUE, TRUE, 0);\
+  cbdata.field = field;
 
+#define INTENTRY(thelabel, field) \
+  hbox = gtk_hbox_new (FALSE, 8);\
+  gtk_box_pack_start (GTK_BOX (main_vbox), hbox, FALSE, TRUE, 0);\
+  label = gtk_label_new (thelabel);\
+  gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);\
+  gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);\
+  field = gtk_spin_button_new_with_range (1, 50, 1.0);\
+  gtk_spin_button_set_value (GTK_SPIN_BUTTON (field), Denemo.prefs.field);\
+  gtk_box_pack_start (GTK_BOX (hbox), field, FALSE, FALSE, 0);\
+  cbdata.field = field;
+
+#define INTENTRY_LIMITS(thelabel, field, min, max) \
+  hbox = gtk_hbox_new (FALSE, 8);\
+  gtk_box_pack_start (GTK_BOX (main_vbox), hbox, FALSE, TRUE, 0);\
+  label = gtk_label_new (thelabel);\
+  gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);\
+  gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);\
+  GtkWidget *field = gtk_spin_button_new_with_range (min, max, 1.0);\
+  gtk_spin_button_set_value (GTK_SPIN_BUTTON (field), Denemo.prefs.field);\
+  gtk_box_pack_start (GTK_BOX (hbox), field, FALSE, FALSE, 0);\
+  cbdata.field = field;
+
+  /*
+   * Note entry settings
+   */
+  
+  NEWPAGE("View");
+  
+  BOOLEANENTRY("Play back entered notes immediately", immediateplayback);  
+  BOOLEANENTRY("Display duration toolbar", notation_palette);
+  BOOLEANENTRY("Display articulation palette", articulation_palette);
+  BOOLEANENTRY("Display Score Titles", visible_titles);
+  BOOLEANENTRY("Display rhythm pattern toolbar", rhythm_palette);
+
+  hbox = gtk_hbox_new (FALSE, 8);
+  gtk_box_pack_start (GTK_BOX (main_vbox), hbox, FALSE, TRUE, 0);
+  autosave = gtk_check_button_new_with_label (_("Autosave every"));
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (autosave),
+				Denemo.prefs.autosave);
+  gtk_box_pack_start (GTK_BOX (hbox), autosave, FALSE, FALSE, 0);
+
+  autosave_timeout = gtk_spin_button_new_with_range (1, 50, 1.0);
+  gtk_spin_button_set_value (GTK_SPIN_BUTTON (autosave_timeout),
+			     Denemo.prefs.autosave_timeout);
+  gtk_widget_set_sensitive (autosave_timeout, Denemo.prefs.autosave);
+  gtk_box_pack_start (GTK_BOX (hbox), autosave_timeout, FALSE, FALSE, 0);
+  g_debug("autosave %p\n", autosave);
+  label = gtk_label_new (_("minute(s)"));
+  gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+  g_signal_connect (GTK_OBJECT (autosave),
+		    "toggled", G_CALLBACK (toggle_autosave), autosave_timeout);
+
+
+  BOOLEANENTRY("Autosave Parts", saveparts);
   TEXTENTRY("Sequencer Device", sequencer)
   TEXTENTRY("Midi Input Device", midi_in)
 
@@ -319,44 +291,16 @@ preferences_change (GtkAction *action, gpointer param)
   /*
    * Pitch Entry Parameters 
    */
-
-  main_vbox = gtk_vbox_new (FALSE, 1);
-  
-
-
-  gtk_notebook_append_page (GTK_NOTEBOOK (notebook), main_vbox, NULL);
-  gtk_notebook_set_tab_label_text (GTK_NOTEBOOK (notebook), main_vbox,
-				   _("Pitch Entry"));
-
-
-
+  NEWPAGE("Pitch Entry");
 
   TEXTENTRY("Temperament", temperament)
-
-#define BOOLEANENTRY(thelabel, field) \
-  field =\
-    gtk_check_button_new_with_label (thelabel); \
-  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (field),\
-				Denemo.prefs.field);\
-  gtk_box_pack_start (GTK_BOX (main_vbox), field, FALSE, TRUE, 0);
-
   BOOLEANENTRY("Use Overlays", overlays);
   BOOLEANENTRY("Continuous Entry", continuous);
 
-
- /*
+  /*
    * Shortcut control 
    */
-
-  main_vbox = gtk_vbox_new (FALSE, 1);
-  
-
-
-  gtk_notebook_append_page (GTK_NOTEBOOK (notebook), main_vbox, NULL);
-  gtk_notebook_set_tab_label_text (GTK_NOTEBOOK (notebook), main_vbox,
-				   _("Shortcuts"));
-
-
+  NEWPAGE("Shortcuts");
 
   //  TEXTENTRY("Strict", strictshortcuts)
   BOOLEANENTRY("Strict Shortcuts", strictshortcuts);
@@ -364,61 +308,13 @@ preferences_change (GtkAction *action, gpointer param)
   /*
    * External (Helper) Programs 
    */
-
-  main_vbox = gtk_vbox_new (FALSE, 1);
-  
-
-
-  gtk_notebook_append_page (GTK_NOTEBOOK (notebook), main_vbox, NULL);
-  gtk_notebook_set_tab_label_text (GTK_NOTEBOOK (notebook), main_vbox,
-				   _("Externals"));
-
-  
-  hbox = gtk_hbox_new (FALSE, 8);
-  gtk_box_pack_start (GTK_BOX (main_vbox), hbox, FALSE, TRUE, 0);
-
-  label = gtk_label_new (_("Path to Lilypond:"));
-  gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
-  gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-  lilypathentry = gtk_entry_new ();
-  gtk_entry_set_text (GTK_ENTRY (lilypathentry), Denemo.prefs.lilypath->str);
-  gtk_box_pack_start (GTK_BOX (hbox), lilypathentry, TRUE, TRUE, 0);
-
-
-  hbox = gtk_hbox_new (FALSE, 8);
-  
-  label = gtk_label_new (_("Pdf Viewer"));
-  gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-
-  pdfviewer = gtk_entry_new ();
-  gtk_entry_set_text (GTK_ENTRY (pdfviewer), Denemo.prefs.pdfviewer->str);
-  gtk_box_pack_start (GTK_BOX (hbox), pdfviewer, TRUE, TRUE, 0);
-
-  gtk_box_pack_start (GTK_BOX (main_vbox), hbox, FALSE, FALSE, 0);
-  hbox = gtk_hbox_new (FALSE, 8);
-  
-
-  label = gtk_label_new (_("Text Editor"));
-  gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-
-
-  texteditor = gtk_entry_new ();
-  gtk_entry_set_text (GTK_ENTRY (texteditor), Denemo.prefs.texteditor->str);
-  gtk_box_pack_start (GTK_BOX (hbox), texteditor, TRUE, TRUE, 0);
-
-  gtk_box_pack_start (GTK_BOX (main_vbox), hbox, FALSE, FALSE, 0);
-  hbox = gtk_hbox_new (FALSE, 8);
-
-  label = gtk_label_new (_("Default Save Path"));
-  gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+  NEWPAGE("Externals");
  
-  denemopath = gtk_entry_new ();
-  if (Denemo.prefs.denemopath != NULL)
-  	gtk_entry_set_text (GTK_ENTRY (denemopath), Denemo.prefs.denemopath->str);
-  gtk_box_pack_start (GTK_BOX (hbox), denemopath, TRUE, TRUE, 0);
-
-  gtk_box_pack_start (GTK_BOX (main_vbox), hbox, FALSE, FALSE, 0);
-
+  TEXTENTRY("Path to Lilypond", lilypath)
+  TEXTENTRY("Pdf Viewer", pdfviewer)
+  TEXTENTRY("Image Viewer", imageviewer)
+  TEXTENTRY("Text Editor", texteditor)
+  TEXTENTRY("Default Save Path", denemopath)
 
   /*
    * Plugins settings
@@ -492,97 +388,60 @@ preferences_change (GtkAction *action, gpointer param)
 
   gtk_tree_view_append_column (GTK_TREE_VIEW (tree), column);
   */
-
-#define INTENTRY(thelabel, field) \
-  hbox = gtk_hbox_new (FALSE, 8);\
-  gtk_box_pack_start (GTK_BOX (main_vbox), hbox, FALSE, TRUE, 0);\
-  label = gtk_label_new (thelabel);\
-  gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);\
-  gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);\
-  field = gtk_spin_button_new_with_range (1, 50, 1.0);\
-  gtk_spin_button_set_value (GTK_SPIN_BUTTON (field), Denemo.prefs.field);\
-  gtk_box_pack_start (GTK_BOX (hbox), field, FALSE, FALSE, 0);
-
-#define INTENTRY_LIMITS(thelabel, field, min, max) \
-  hbox = gtk_hbox_new (FALSE, 8);\
-  gtk_box_pack_start (GTK_BOX (main_vbox), hbox, FALSE, TRUE, 0);\
-  label = gtk_label_new (thelabel);\
-  gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);\
-  gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);\
-  field = gtk_spin_button_new_with_range (min, max, 1.0);\
-  gtk_spin_button_set_value (GTK_SPIN_BUTTON (field), Denemo.prefs.field);\
-  gtk_box_pack_start (GTK_BOX (hbox), field, FALSE, FALSE, 0);
-
  
   /*
    * Excerpt Menu 
    */
-
-  main_vbox = gtk_vbox_new (FALSE, 1);
-  gtk_notebook_append_page (GTK_NOTEBOOK (notebook), main_vbox, NULL);
-  gtk_notebook_set_tab_label_text (GTK_NOTEBOOK (notebook), main_vbox,
-				   _("Excerpt"));
-
+  NEWPAGE("Excerpt");
+ 
   INTENTRY_LIMITS(_("resolution"), resolution, 72, 600);
 
+  /*
+   * Jack Menu
+   */
+#ifdef _HAVE_JACK_
+  NEWPAGE("JACK");
+  BOOLEANENTRY("Enable Jack Transport", jacktransport);
+  BOOLEANENTRY("Jack Transport starts stopped", jacktransport_start_stopped);
+  BOOLEANENTRY("Enable Jack at startup", jack_at_startup);
+  /* Start/Restart Button */
+  hbox = gtk_hbox_new (FALSE, 8);
+  gtk_box_pack_start (GTK_BOX (main_vbox), hbox, FALSE, TRUE, 0);
+  GtkWidget *jack_activate = gtk_button_new_with_label("Start/Restart Jack Client");
+  gtk_box_pack_start (GTK_BOX (hbox), jack_activate, FALSE, FALSE, 0);
+  g_signal_connect (G_OBJECT (jack_activate), "clicked",
+    G_CALLBACK (jack_start_restart), (gpointer) NULL);
+
+#endif
+
+
   /*
    * Help settings
    */
-
-  main_vbox = gtk_vbox_new (FALSE, 1);
-  
-  gtk_notebook_append_page (GTK_NOTEBOOK (notebook), main_vbox, NULL);
-  gtk_notebook_set_tab_label_text (GTK_NOTEBOOK (notebook), main_vbox,
-				   _("Help Settings"));
-
-  hbox = gtk_hbox_new (FALSE, 8);
-  gtk_box_pack_start (GTK_BOX (main_vbox), hbox, FALSE, TRUE, 0);
-
-  label = gtk_label_new (_("Help Browser:"));
-  gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
-  gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-  browserentry = gtk_entry_new ();
-  gtk_entry_set_text (GTK_ENTRY (browserentry), Denemo.prefs.browser->str);
-  gtk_box_pack_start (GTK_BOX (hbox), browserentry, TRUE, TRUE, 0);
-
-  INTENTRY(_("Max recent files"), maxhistory);
+  NEWPAGE("Help Settings")
+  TEXTENTRY("Help Browser", browser)
+  INTENTRY(_("Max recent files"), maxhistory)
 
   /* Set up the callback data */
-  cbdata.prefs = &Denemo.prefs;
-  cbdata.lilypathentry = lilypathentry;
-  cbdata.checkimmediateplayback = checkimmediateplayback;
 
 #define SETCALLBACKDATA(field) \
   cbdata.field = field;
-
-
-  SETCALLBACKDATA(strictshortcuts);
-  SETCALLBACKDATA(resolution);  
-  SETCALLBACKDATA(overlays);
-  SETCALLBACKDATA(continuous);
-
-  cbdata.checkautosaveparts = checkautosaveparts;
-  cbdata.checkarticulationpalette = checkarticulationpalette;
-  cbdata.checknotationpalette = checknotationpalette;
-  cbdata.checkrhythmpalette = checkrhythmpalette;
-  cbdata.checkautosave = checkautosave;
-  cbdata.autosaveentry = autosaveentry;
-  cbdata.maxhistory = maxhistory;
-  cbdata.browserentry = browserentry;
-  cbdata.pdfviewer = pdfviewer;
-  cbdata.texteditor = texteditor;
-  cbdata.denemopath = denemopath;
-
-  gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
-  gtk_entry_set_activates_default (GTK_ENTRY (lilypathentry), TRUE);
-  gtk_entry_set_activates_default (GTK_ENTRY (autosaveentry), TRUE);
-  gtk_entry_set_activates_default (GTK_ENTRY (maxhistory), TRUE);
-  gtk_entry_set_activates_default (GTK_ENTRY (browserentry), TRUE);
-  gtk_entry_set_activates_default (GTK_ENTRY (pdfviewer), TRUE);
-  gtk_entry_set_activates_default (GTK_ENTRY (texteditor), TRUE);
-  gtk_entry_set_activates_default (GTK_ENTRY (denemopath), TRUE);
   
-  gtk_widget_grab_focus (lilypathentry);
+  cbdata.prefs = &Denemo.prefs;
+  SETCALLBACKDATA(autosave);
+  SETCALLBACKDATA(autosave_timeout); 
+  SETCALLBACKDATA(maxhistory);
+  
+  //gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
+  //gtk_entry_set_activates_default (GTK_ENTRY (lilypath), TRUE);
+  //gtk_entry_set_activates_default (GTK_ENTRY (autosave_timeout), TRUE);
+  //gtk_entry_set_activates_default (GTK_ENTRY (maxhistory), TRUE);
+  //gtk_entry_set_activates_default (GTK_ENTRY (browser), TRUE);
+  //gtk_entry_set_activates_default (GTK_ENTRY (pdfviewer), TRUE);
+  //gtk_entry_set_activates_default (GTK_ENTRY (texteditor), TRUE);
+  //gtk_entry_set_activates_default (GTK_ENTRY (denemopath), TRUE);
+  
+  //gtk_widget_grab_focus (lilypath);
   gtk_widget_show_all (dialog);
   if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT)
     {
