@@ -56,6 +56,7 @@ register_command(Denemo.map, gtk_action_group_get_action(action_group, "StemDown
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "AddDot"), "AddDot", "Add Dot", "No Tooltip yet", add_dot_key);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "RemoveDot"), "RemoveDot", "Remove Dot", "No Tooltip yet", remove_dot_key);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertTiedNote"), "InsertTiedNote", "Tied note", "Inserts a duplicate of the current note, tied", tie_notes_key);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "ToggleTie"), "ToggleTie", "Toggle Tie", "Ties/unties the note at the cursor", toggle_tie);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "DeleteObject"), "DeleteObject", "Delete Object", "Delete the object at the cursor", deleteobject);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "DeletePreviousObject"), "DeletePreviousObject", "Delete Previous Object", "Delete to the left of the cursor.", deletepreviousobject);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertMeasure"), "InsertMeasure", "Insert Measure", "Insert a blank measure before the current one (in all staffs)", insert_measure_key);
@@ -256,20 +257,30 @@ register_command(Denemo.map, gtk_action_group_get_action(action_group, "DeleteAf
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "AddVoice"), "AddVoice", "Add Voice", "Adds a new voice (part), to the current staff. It is tricky to switch between the voices. Suggest to use merge staffs", dnm_newstaffvoice);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "StaffProperties"), "StaffProperties", "Staff Properties", "Change the properties of the current staff", staff_properties_change_cb);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "InitialClef"), "InitialClef", "Initial Clef", "Change the initial clef of the current staff", clef_change_initial);
-register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertClef"), "InsertClef", "Clef Change", "Insert a change of clef at the cursor", clef_change_insert);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertClef"), "InsertClef", "Clef Change", "Insert/Edit a change of clef at the cursor", clef_change_insert);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "InitialKey"), "InitialKey", "Initial Key", "Set the initial key signature of the current staff", key_change_initial);
-register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertKey"), "InsertKey", "Insert Key Change", "Insert a key change at the cursor position", key_change_insert);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertKey"), "InsertKey", "Key Signature Change", "Insert/Edit a key change at the cursor position", key_change_insert);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "InitialTimeSig"), "InitialTimeSig", "Inital Time Signature", "Set the initial time signature of the current staff", timesig_change_initial);
-register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertTimeSig"), "InsertTimeSig", "Insert Time Signature", "Edit/Insert a time signature change for the current measure", timesig_change_insert);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertTimeSig"), "InsertTimeSig", "Time Signature Change", "Edit/Insert a time signature change for the current measure", timesig_change_insert);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "ChangeNotehead"), "ChangeNotehead", "Set Notehead", "Change the type of notehead for the current note", set_notehead);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertStem"), "InsertStem", "Auto Stemming", "Inserts a stem neutral object. After this automatic stem directions are active. You can click on this tag and use Sharpen/StemUp etc commands to change stem direction", stem_directive_insert);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "EditLyric"), "EditLyric", "Insert/Edit Lyric", "Add a lyric to current note. Beware: all previous notes must have lyrics for printing correctly", lyric_insert);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "EditFiguredBass"), "EditFiguredBass", "Insert/Edit Figured Bass", "Add a bass figure to the current note. Use | sign to split the duration of a note so as to have multiple figures on one note. See Lilypond docs for other notation", figure_insert);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "EditChords"), "EditChords", "Edit Chord Symbols", "Allows chord symbols to be added to the current note. E.G.cis:dim7 for c-sharp diminished 7th. See Lilypond docs for notation", fakechord_insert);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertDynamic"), "InsertDynamic", "Insert Dynamics", "Inserts a dynamic marking at the cursor position", insert_dynamic);
-register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertLilyDirective"), "InsertLilyDirective", "Insert Lilypond", "Insert or edit a directive in the LilyPond music typesetting language. This can be used for extra spacing, transposing or almost anything. See LilyPond documentation for ideas.", lily_directive_insert);
-register_command(Denemo.map, gtk_action_group_get_action(action_group, "AttachLilyToNote"), "AttachLilyToNote", "Attach Lilypond to Note", "Attach or edit attached LilyPond text to the note at the cursor. This can be used for guitar fingerings, cautionary accidentals and much more. See LilyPond documentation.", lily_directive_attach_note);
-register_command(Denemo.map, gtk_action_group_get_action(action_group, "AttachLilyToChord"), "AttachLilyToChord", "Attach Lilypond to Chord", "Attach or edit attached LilyPond text to the chord at the cursor. This can be used for attaching and placing text and much more. See LilyPond documentation.", lily_directive_attach_chord);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertLilyDirective"), "InsertLilyDirective", "Insert Lilypond", "Insert or edit a directive in the LilyPond music typesetting language. This can be used for extra spacing, transposing or almost anything. See LilyPond documentation for ideas.", standalone_directive);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "EditObject"), "EditObject", "Edit Object", "Edit the object at the cursor.", edit_object);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "EditDirective"), "EditDirective", "Edit Directives", "Edit any directives attached to chord/note at cursor.", edit_object_directive);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "EditStaffDirective"), "EditStaffDirective", "Edit Staff Directives", "Edit any directives attached to staff.", edit_staff_directive);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "EditVoiceDirective"), "EditVoiceDirective", "Edit Voice Directives", "Edit any directives attached to voice.", edit_voice_directive);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "EditScoreDirective"), "EditScoreDirective", "Edit Score Directives", "Edit any directives attached to score.", edit_score_directive);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "EditMovementDirective"), "EditMovementDirective", "Edit Movement Directives", "Edit any directives attached to movement.", edit_movement_directive);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "EditClefDirective"), "EditClefDirective", "Edit Clef Directives", "Edit any directives attached to clef.", edit_clef_directive);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "EditTimesigDirective"), "EditTimesigDirective", "Edit Time Signature Directives", "Edit any directives attached to time signature.", edit_timesig_directive);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "EditKeysigDirective"), "EditKeysigDirective", "Edit Key Signature Directives", "Edit any directives attached to key signature.", edit_keysig_directive);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "DeleteDirective"), "DeleteDirective", "Delete a Directive", "Delete a directive attached to chord/note at cursor.", delete_object_directive);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "AttachLilyToNote"), "AttachLilyToNote", "Attach Lilypond to Note", "Attach or edit attached LilyPond text to the note at the cursor. This can be used for guitar fingerings, cautionary accidentals and much more. See LilyPond documentation.", note_directive);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "AttachLilyToChord"), "AttachLilyToChord", "Attach Lilypond to Chord", "Attach or edit attached LilyPond text to the chord at the cursor. This can be used for attaching and placing text and much more. See LilyPond documentation.", chord_directive);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertBarline"), "InsertBarline", "Insert Barline", "Inserts specialized barline at the cursor position. Mostly not working", insert_barline);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "GoToMeasure"), "GoToMeasure", "Go to Measure", "Opens a dialog for going to a numbered measure", tomeasurenum);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "GoToBeginning"), "GoToBeginning", "Go To Beginning", "Go To Beginning", tohome);
