@@ -231,6 +231,10 @@ g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "RemoveDot")), "scm", (gpo
 SCM scheme_InsertTiedNote(SCM optional);
 install_scm_function ("d-InsertTiedNote", scheme_InsertTiedNote);
 g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "InsertTiedNote")), "scm", (gpointer)1);
+/*ToggleTie toggle_tie*/
+SCM scheme_ToggleTie(SCM optional);
+install_scm_function ("d-ToggleTie", scheme_ToggleTie);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "ToggleTie")), "scm", (gpointer)1);
 /*DeleteObject deleteobject*/
 SCM scheme_DeleteObject(SCM optional);
 install_scm_function ("d-DeleteObject", scheme_DeleteObject);
@@ -1075,15 +1079,55 @@ g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "EditChords")), "scm", (gp
 SCM scheme_InsertDynamic(SCM optional);
 install_scm_function ("d-InsertDynamic", scheme_InsertDynamic);
 g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "InsertDynamic")), "scm", (gpointer)1);
-/*InsertLilyDirective lily_directive_insert*/
+/*InsertLilyDirective standalone_directive*/
 SCM scheme_InsertLilyDirective(SCM optional);
 install_scm_function ("d-InsertLilyDirective", scheme_InsertLilyDirective);
 g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "InsertLilyDirective")), "scm", (gpointer)1);
-/*AttachLilyToNote lily_directive_attach_note*/
+/*EditObject edit_object*/
+SCM scheme_EditObject(SCM optional);
+install_scm_function ("d-EditObject", scheme_EditObject);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "EditObject")), "scm", (gpointer)1);
+/*EditDirective edit_object_directive*/
+SCM scheme_EditDirective(SCM optional);
+install_scm_function ("d-EditDirective", scheme_EditDirective);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "EditDirective")), "scm", (gpointer)1);
+/*EditStaffDirective edit_staff_directive*/
+SCM scheme_EditStaffDirective(SCM optional);
+install_scm_function ("d-EditStaffDirective", scheme_EditStaffDirective);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "EditStaffDirective")), "scm", (gpointer)1);
+/*EditVoiceDirective edit_voice_directive*/
+SCM scheme_EditVoiceDirective(SCM optional);
+install_scm_function ("d-EditVoiceDirective", scheme_EditVoiceDirective);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "EditVoiceDirective")), "scm", (gpointer)1);
+/*EditScoreDirective edit_score_directive*/
+SCM scheme_EditScoreDirective(SCM optional);
+install_scm_function ("d-EditScoreDirective", scheme_EditScoreDirective);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "EditScoreDirective")), "scm", (gpointer)1);
+/*EditMovementDirective edit_movement_directive*/
+SCM scheme_EditMovementDirective(SCM optional);
+install_scm_function ("d-EditMovementDirective", scheme_EditMovementDirective);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "EditMovementDirective")), "scm", (gpointer)1);
+/*EditClefDirective edit_clef_directive*/
+SCM scheme_EditClefDirective(SCM optional);
+install_scm_function ("d-EditClefDirective", scheme_EditClefDirective);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "EditClefDirective")), "scm", (gpointer)1);
+/*EditTimesigDirective edit_timesig_directive*/
+SCM scheme_EditTimesigDirective(SCM optional);
+install_scm_function ("d-EditTimesigDirective", scheme_EditTimesigDirective);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "EditTimesigDirective")), "scm", (gpointer)1);
+/*EditKeysigDirective edit_keysig_directive*/
+SCM scheme_EditKeysigDirective(SCM optional);
+install_scm_function ("d-EditKeysigDirective", scheme_EditKeysigDirective);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "EditKeysigDirective")), "scm", (gpointer)1);
+/*DeleteDirective delete_object_directive*/
+SCM scheme_DeleteDirective(SCM optional);
+install_scm_function ("d-DeleteDirective", scheme_DeleteDirective);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "DeleteDirective")), "scm", (gpointer)1);
+/*AttachLilyToNote note_directive*/
 SCM scheme_AttachLilyToNote(SCM optional);
 install_scm_function ("d-AttachLilyToNote", scheme_AttachLilyToNote);
 g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "AttachLilyToNote")), "scm", (gpointer)1);
-/*AttachLilyToChord lily_directive_attach_chord*/
+/*AttachLilyToChord chord_directive*/
 SCM scheme_AttachLilyToChord(SCM optional);
 install_scm_function ("d-AttachLilyToChord", scheme_AttachLilyToChord);
 g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "AttachLilyToChord")), "scm", (gpointer)1);
