@@ -10,6 +10,9 @@
 #include "staffops.h"
 #include "scoreops.h"
 #include "prefops.h"
+#ifdef _HAVE_JACK_
+#include "jackmidi.h"
+#endif
 #define INITIAL_WHOLEWIDTH 160
 #define INITIAL_STAFFHEIGHT 100
 
@@ -17,11 +20,11 @@ static remove_all_staffs(DenemoScore * si);
 
 
 /**
- * Create new DenemoScore with one empty staff
- * 
+ * Create new DenemoScore with no staff
+ * set it as gui->si but do not add it to the movements list.
  */
 void
-new_empty_score (DenemoGUI *gui)
+point_to_empty_movement (DenemoGUI *gui)
 {
   DenemoScore *newscore = (DenemoScore *) g_malloc0 (sizeof (DenemoScore));
   init_score (newscore, gui);
@@ -29,19 +32,19 @@ new_empty_score (DenemoGUI *gui)
 }
 /**
  * Create new DenemoScore with one empty staff
- * 
+ * set it as gui->si but do not add it to the movements list.
  */
 void
-new_score (DenemoGUI *gui)
+point_to_new_movement (DenemoGUI *gui)
 {
-  new_empty_score(gui);
+  point_to_empty_movement(gui);
   newstaff (gui, INITIAL, DENEMO_NONE);
 }
 
 
 static void
 new_movement(DenemoGUI *gui, gboolean before) {
-  new_score(gui);
+  point_to_new_movement(gui);
   if(before) 
     gui->movements = g_list_prepend(gui->movements, gui->si);//FIXME insert before g_list_find(gui->movements, si)
   else
@@ -88,7 +91,7 @@ delete_movement(GtkAction *action, gpointer param) {
     }
   } else { // more than one movement
     gint num = g_list_index(gui->movements, gui->si);
-    g_string_printf(primary,_("This is movement #%d, entitled %s"), num+1, gui->si->headerinfo.piece->str);
+    g_string_printf(primary,_("This is movement #%d"), num+1);
     g_string_assign(secondary,_("Delete entire movement?"));
     if( confirm(primary->str, secondary->str)) {
       free_score(gui);
@@ -156,13 +159,18 @@ goto_movement_staff_obj (DenemoGUI * gui, gint movementnum, gint staffnum, gint
  * @return none
 */
 void
-next_movement (GtkAction *action, gpointer param)
+next_movement (GtkAction *action, DenemoScriptParam *param)
 {
   DenemoGUI *gui = Denemo.gui;
   GList *this = g_list_find( gui->movements, gui->si);
   this = this->next;
+  if(param)
+    param->status = TRUE;
   if(this==NULL){
-    warningdialog(_("This is the last movement"));
+    if(param)
+      param->status = FALSE;
+    else
+      warningdialog(_("This is the last movement"));
     return;
   }
   gui->si = this->data;
@@ -187,13 +195,18 @@ next_movement (GtkAction *action, gpointer param)
  * @return none
 */
 void
-prev_movement (GtkAction *action, gpointer param)
+prev_movement (GtkAction *action, DenemoScriptParam *param)
 {
   DenemoGUI *gui = Denemo.gui;
   GList *this = g_list_find( gui->movements, gui->si);
   this = this->prev;
+  if(param)
+    param->status = TRUE;
   if(this==NULL){
-    warningdialog(_("This is the first movement"));
+    if(param)
+      param->status = FALSE;
+    else
+      warningdialog(_("This is the first movement"));
     return;
   }
   gui->si = this->data; 
@@ -250,28 +263,7 @@ init_score (DenemoScore * si, DenemoGUI *gui)
 
   si->savebuffer = NULL;
   si->bookmarks = NULL;
-#define HEADER(field) si->headerinfo.field = g_string_new ("");
-  HEADER(title);
-  HEADER(subtitle);
-  HEADER(poet);
-  HEADER(composer);
-  HEADER(meter);
-  HEADER(piece);
-  HEADER(opus);
-  HEADER(arranger);
-  HEADER(instrument);
-  HEADER(dedication);
-  HEADER(head);
-  HEADER(copyright);
-  HEADER(footer);
 
-  si->headerinfo.tagline = g_string_new ("Generated by Denemo Version "VERSION", go to http://www.denemo.org");
-
-  si->headerinfo.extra = g_string_new ("breakbefore = ##f");
-  HEADER(lilypond_before);
-  HEADER(lilypond_after);
-  HEADER(layout);
-#undef HEADER
   if(gui->filename==NULL) {
     gui->filename = g_string_new ("");
     gui->autosavename = g_string_new (dir);
@@ -296,7 +288,7 @@ init_score (DenemoScore * si, DenemoGUI *gui)
     //    }
     // FIXME initialize from current movement    g_list_find(gui->movements, si)
     //gint number = g_list_index( gui->movements, gui->si);
-    g_string_printf(si->headerinfo.piece, "Movement %d", 1+g_list_length(gui->movements));
+    //g_string_printf(si->headerinfo.piece, "Movement %d", 1+g_list_length(gui->movements));
   }
   //gui->movements = g_list_append(gui->movements, si);
 }
@@ -310,6 +302,9 @@ static delete_all_staffs(DenemoGUI * gui) {
       si->currentstaff = g_list_nth (si->thescore, i - 1);
       deletestaff (gui, FALSE);
     }
+#ifdef _HAVE_JACK_
+  remove_all_jack_midi_ports();
+#endif
 }
 
 /**
@@ -321,26 +316,9 @@ void
 free_score (DenemoGUI * gui)
 {
   delete_all_staffs(gui);
-#define  HEADER(field)   g_string_free(gui->si->headerinfo.field, TRUE)
-  HEADER(title);
-  HEADER(subtitle);
-  HEADER(poet);
-  HEADER(composer);
-  HEADER(meter);
-  HEADER(piece);
-  HEADER(opus);
-  HEADER(arranger);
-  HEADER(instrument);
-  HEADER(dedication);
-  HEADER(head);
-  HEADER(copyright);
-  HEADER(footer);
-  HEADER(tagline);
-  HEADER(lilypond_before);
-  HEADER(lilypond_after);
-  HEADER(layout);
-  HEADER(extra);
-#undef HEADER
+  delete_directives(&gui->si->layout.directives);
+  delete_directives(&gui->si->header.directives);
+
 
   g_queue_free (gui->si->undodata);
   g_queue_free (gui->si->redodata);
