@@ -9,13 +9,13 @@
 #ifndef SCOREOPS_H
 #define SCOREOPS_H
 
-void new_empty_score(DenemoGUI * gui);
-void new_score(DenemoGUI * gui);
+void point_to_empty_movement/*new_empty_score*/(DenemoGUI * gui);
+void point_to_new_movement/*new_score*/(DenemoGUI * gui);
 void init_score (DenemoScore *si, DenemoGUI * gui);
 
 void free_score (DenemoGUI *gui);
-void next_movement (GtkAction *action, gpointer param);
-void prev_movement (GtkAction *action, gpointer param);
+void next_movement (GtkAction *action, DenemoScriptParam *param);
+void prev_movement (GtkAction *action, DenemoScriptParam *param);
 void insert_movement_before (GtkAction *action, gpointer param);
 void insert_movement_after (GtkAction *action, gpointer param);
 void delete_movement (GtkAction *action, gpointer param);
