@@ -489,7 +489,7 @@ papersetup(GtkWidget *notebook, DenemoGUI *gui, gboolean isnotebook)
     }
 
   gtk_entry_set_text(GTK_ENTRY(GTK_BIN(papersize)->child), 
-		     gui->lilycontrol.papersize->str);
+		    gui->lilycontrol.papersize->len? gui->lilycontrol.papersize->str:"");
   gtk_table_attach(GTK_TABLE(table), papersize,1,2,0,1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
@@ -505,9 +505,9 @@ papersetup(GtkWidget *notebook, DenemoGUI *gui, gboolean isnotebook)
       gtk_combo_box_append_text(GTK_COMBO_BOX(fontsize), fontsizes[i]);
     }
   gchar *tmp;
-  tmp = g_strdup_printf( "%d", gui->lilycontrol.fontsize);
-  gtk_entry_set_text (GTK_ENTRY (GTK_BIN(fontsize)->child), tmp);
-  g_free(tmp);
+  //tmp = g_strdup_printf( "%d", gui->lilycontrol.fontsize);
+  gtk_entry_set_text (GTK_ENTRY (GTK_BIN(fontsize)->child),  gui->lilycontrol.staffsize->len?gui->lilycontrol.staffsize->str:"");
+  //g_free(tmp);
   gtk_table_attach(GTK_TABLE(table), fontsize, 1,2,1,2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
@@ -522,20 +522,12 @@ papersetup(GtkWidget *notebook, DenemoGUI *gui, gboolean isnotebook)
   gtk_table_attach(GTK_TABLE(table), lilyversion, 1,2,2,3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
-  gtk_entry_set_text(GTK_ENTRY(lilyversion), 
-		     gui->lilycontrol.lilyversion->str);
+  gtk_entry_set_text(GTK_ENTRY(lilyversion), gui->lilycontrol.lilyversion->len?
+		     gui->lilycontrol.lilyversion->str:"");
+
+
 
-  label = gtk_label_new(_("LilyPond Control"));
-  gtk_table_attach(GTK_TABLE(table), label, 0,1,3,4,
-                   (GtkAttachOptions) (GTK_FILL),
-                   (GtkAttachOptions) (0), 0, 0);
 
-  GtkWidget *lilypond = gtk_entry_new();
-  gtk_table_attach(GTK_TABLE(table), lilypond, 1,2,3,4,
-                   (GtkAttachOptions) (GTK_FILL),
-                   (GtkAttachOptions) (0), 0, 0);
-  gtk_entry_set_text(GTK_ENTRY(lilypond), 
-		     gui->lilycontrol.lilypond->str);
 
 
   GtkWidget *vbox = gtk_vbox_new(FALSE,0);
@@ -571,7 +563,7 @@ papersetup(GtkWidget *notebook, DenemoGUI *gui, gboolean isnotebook)
   setup->fontsize = fontsize;
   setup->portrait = portraitradio;
   setup->lilyversion = lilyversion;
-  setup->lilypond = lilypond;
+
   score_status(gui, TRUE);
   return setup;
 }
@@ -650,7 +642,7 @@ timekeysig(wizarddata *wdata, gboolean isnotebook)
  
   gtk_spin_button_set_digits (GTK_SPIN_BUTTON (numerator), 0);
   gtk_spin_button_set_value (GTK_SPIN_BUTTON (numerator),
-			     (gdouble) curstaffstruct->stime1);
+			     (gdouble) curstaffstruct->timesig.time1);
   gtk_entry_set_activates_default (GTK_ENTRY (numerator), TRUE);
 
   GtkWidget *denominator = gtk_spin_button_new_with_range (1, 16, 1.0);
@@ -660,7 +652,7 @@ timekeysig(wizarddata *wdata, gboolean isnotebook)
  
   gtk_spin_button_set_digits (GTK_SPIN_BUTTON (denominator), 0);
   gtk_spin_button_set_value (GTK_SPIN_BUTTON (denominator),
-			     (gdouble) curstaffstruct->stime2);
+			     (gdouble) curstaffstruct->timesig.time2);
   gtk_entry_set_activates_default (GTK_ENTRY (denominator), TRUE);
 
   /*key signature*/
@@ -716,7 +708,7 @@ timekeysig(wizarddata *wdata, gboolean isnotebook)
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radiobutton1), TRUE);
   majorcallback (NULL, mdata);
   gtk_entry_set_text(GTK_ENTRY (GTK_COMBO (combobox)->entry),
-		     majorkeys[curstaffstruct->skey + KEYNAME_ARRAY_OFFSET]);
+		     majorkeys[curstaffstruct->keysig.number + KEYNAME_ARRAY_OFFSET]);
    
   if(isnotebook)
     {
@@ -745,234 +737,7 @@ timekeysig(wizarddata *wdata, gboolean isnotebook)
   return timekeysigdata;
 }
 
-void
-applyheader_settings(headersetupcb *hsetup, DenemoGUI *gui)
-{
-  //DenemoScore *si = wdata->gui->si;
-  //headersetupcb *hsetup = wdata->hsetup;
-  g_string_assign(gui->si->headerinfo.title, (gchar *) gtk_entry_get_text (GTK_ENTRY (hsetup->title)));
-  g_string_assign(gui->si->headerinfo.subtitle, (gchar *) gtk_entry_get_text (GTK_ENTRY (hsetup->subtitle)));
-  g_string_assign(gui->si->headerinfo.poet, (gchar *) gtk_entry_get_text (GTK_ENTRY (hsetup->poet)));
-  g_string_assign(gui->si->headerinfo.composer, (gchar *) gtk_entry_get_text (GTK_ENTRY (hsetup->composer)));
-  g_string_assign(gui->si->headerinfo.meter, (gchar *) gtk_entry_get_text (GTK_ENTRY (hsetup->meter)));
-  g_string_assign(gui->si->headerinfo.opus, (gchar *) gtk_entry_get_text (GTK_ENTRY (hsetup->opus)));
-  g_string_assign(gui->si->headerinfo.arranger, (gchar *) gtk_entry_get_text (GTK_ENTRY (hsetup->arranger)));
-  g_string_assign(gui->si->headerinfo.instrument, (gchar *) gtk_entry_get_text (GTK_ENTRY (hsetup->instrument)));
-  g_string_assign(gui->si->headerinfo.dedication, (gchar *) gtk_entry_get_text (GTK_ENTRY (hsetup->dedication)));
-  g_string_assign(gui->si->headerinfo.piece, (gchar *) gtk_entry_get_text (GTK_ENTRY (hsetup->piece)));
-  g_string_assign(gui->si->headerinfo.head, (gchar *) gtk_entry_get_text (GTK_ENTRY (hsetup->head)));
-  g_string_assign(gui->si->headerinfo.copyright, (gchar *) gtk_entry_get_text (GTK_ENTRY (hsetup->copyright)));
-  g_string_assign(gui->si->headerinfo.footer, (gchar *) gtk_entry_get_text (GTK_ENTRY (hsetup->footer)));
-  g_string_assign(gui->si->headerinfo.tagline, (gchar *) gtk_entry_get_text (GTK_ENTRY (hsetup->tagline)));
-  score_status(gui, TRUE);
-}
 
-headersetupcb *
-headersetup(GtkWidget *notebook, DenemoGUI *gui, gboolean isnotebook)
-{
-
-  headersetupcb *setup = (headersetupcb *) g_malloc0(sizeof(headersetupcb));
-  GtkWidget *label,*table, *title,*subtitle,*poet,*composer,*meter, *opus, *arranger,*instrument, *dedication, *piece, *head, *copyright, *footer, *tagline;
-
-  table = gtk_table_new(3, 3 , FALSE);
-  gtk_container_set_border_width (GTK_CONTAINER (table), 12);
-
-  gtk_table_set_row_spacings (GTK_TABLE (table), 0);
-  gtk_table_set_col_spacings (GTK_TABLE (table), 8);
-
-  /** title **/
-#define SET_TEXT(label) gtk_entry_set_text (GTK_ENTRY (label), gui->si->headerinfo.label->str);
-  label = gtk_label_new(_("Title"));
-  gtk_table_attach(GTK_TABLE(table), label, 0,1,1,2,
-                   (GtkAttachOptions) (GTK_FILL),
-                   (GtkAttachOptions) (0), 0, 0);
-
-  title = gtk_entry_new();
-  SET_TEXT(title);
-  gtk_table_attach(GTK_TABLE(table), title, 1,2,1,2,
-                   (GtkAttachOptions) (GTK_FILL),
-                   (GtkAttachOptions) (0), 0, 0);
-
-  /** subtitle **/
-  label = gtk_label_new(_("Subtitle"));
-  gtk_table_attach(GTK_TABLE(table), label, 0,1,2,3,
-                   (GtkAttachOptions) (GTK_FILL),
-                   (GtkAttachOptions) (0), 0, 0);
-
-  subtitle = gtk_entry_new();
-  SET_TEXT(subtitle);
-  gtk_table_attach(GTK_TABLE(table), subtitle, 1,2,2,3,
-                   (GtkAttachOptions) (GTK_FILL),
-                   (GtkAttachOptions) (0), 0, 0);
-
-  /** Poet **/
-  label = gtk_label_new(_("Poet"));
-  gtk_table_attach(GTK_TABLE(table), label, 0,1,3,4,
-                   (GtkAttachOptions) (GTK_FILL),
-                   (GtkAttachOptions) (0), 0, 0);
-
-  poet = gtk_entry_new();
-  SET_TEXT(poet);
-  gtk_table_attach(GTK_TABLE(table), poet, 1,2,3,4,
-                   (GtkAttachOptions) (GTK_FILL),
-                   (GtkAttachOptions) (0), 0, 0);
-  /** Composer **/
-  label = gtk_label_new(_("Composer"));
-  gtk_table_attach(GTK_TABLE(table), label, 0,1,4,5,
-                   (GtkAttachOptions) (GTK_FILL),
-                   (GtkAttachOptions) (0), 0, 0);
-
-  composer = gtk_entry_new();
-  SET_TEXT(composer);
-  gtk_table_attach(GTK_TABLE(table), composer, 1,2,4,5,
-                   (GtkAttachOptions) (GTK_FILL),
-                   (GtkAttachOptions) (0), 0, 0);
-  /** Meter **/
-  label = gtk_label_new(_("Meter"));
-  gtk_table_attach(GTK_TABLE(table), label, 0,1,5,6,
-                   (GtkAttachOptions) (GTK_FILL),
-                   (GtkAttachOptions) (0), 0, 0);
-
-  meter = gtk_entry_new();
-  SET_TEXT(meter);
-  gtk_table_attach(GTK_TABLE(table), meter, 1,2,5,6,
-                   (GtkAttachOptions) (GTK_FILL),
-                   (GtkAttachOptions) (0), 0, 0);
-  /** Opus **/
-  label = gtk_label_new(_("Opus"));
-  gtk_table_attach(GTK_TABLE(table), label, 0,1,6,7,
-                   (GtkAttachOptions) (GTK_FILL),
-                   (GtkAttachOptions) (0), 0, 0);
-
-  opus = gtk_entry_new();
-  SET_TEXT(opus);
-  gtk_table_attach(GTK_TABLE(table), opus, 1,2,6,7,
-                   (GtkAttachOptions) (GTK_FILL),
-                   (GtkAttachOptions) (0), 0, 0);
-  /** Arranger **/
-  label = gtk_label_new(_("Arranger"));
-  gtk_table_attach(GTK_TABLE(table), label, 0,1,7,8,
-                   (GtkAttachOptions) (GTK_FILL),
-                   (GtkAttachOptions) (0), 0, 0);
-
-  arranger = gtk_entry_new();
-  SET_TEXT(arranger);
-  gtk_table_attach(GTK_TABLE(table), arranger, 1,2,7,8,
-                   (GtkAttachOptions) (GTK_FILL),
-                   (GtkAttachOptions) (0), 0, 0);
-
-  /** Instrument **/
-  label = gtk_label_new(_("Instrument"));
-  gtk_table_attach(GTK_TABLE(table), label, 0,1,8,9,
-                   (GtkAttachOptions) (GTK_FILL),
-                   (GtkAttachOptions) (0), 0, 0);
-
-  instrument = gtk_entry_new();
-  SET_TEXT(instrument);
-  gtk_table_attach(GTK_TABLE(table), instrument, 1,2,8,9,
-                   (GtkAttachOptions) (GTK_FILL),
-                   (GtkAttachOptions) (0), 0, 0);
-
-  /** Dedication **/
-  label = gtk_label_new(_("Dedication"));
-  gtk_table_attach(GTK_TABLE(table), label, 0,1,9,10,
-                   (GtkAttachOptions) (GTK_FILL),
-                   (GtkAttachOptions) (0), 0, 0);
-
-  dedication = gtk_entry_new();
-  SET_TEXT(dedication);
-  gtk_table_attach(GTK_TABLE(table), dedication, 1,2,9,10,
-                   (GtkAttachOptions) (GTK_FILL),
-                   (GtkAttachOptions) (0), 0, 0);
-
-  label = gtk_label_new(_("Piece"));
-  gtk_table_attach(GTK_TABLE(table), label, 0,1,10,11,
-                   (GtkAttachOptions) (GTK_FILL),
-                   (GtkAttachOptions) (0), 0, 0);
-
-  piece = gtk_entry_new();
-  gtk_entry_set_text (GTK_ENTRY (piece), gui->si->headerinfo.piece->str);
-  gtk_table_attach(GTK_TABLE(table), piece, 1,2,10,11,
-                   (GtkAttachOptions) (GTK_FILL),
-                   (GtkAttachOptions) (0), 0, 0);
-
-  /** Head **/
-  label = gtk_label_new(_("Head"));
-  gtk_table_attach(GTK_TABLE(table), label, 0,1,11,12,
-                   (GtkAttachOptions) (GTK_FILL),
-                   (GtkAttachOptions) (0), 0, 0);
-
-  head = gtk_entry_new();
-  SET_TEXT(head);
-  gtk_table_attach(GTK_TABLE(table), head, 1,2,11,12,
-                   (GtkAttachOptions) (GTK_FILL),
-                   (GtkAttachOptions) (0), 0, 0);
-
-  /** Copyright **/
-  label = gtk_label_new(_("Copyright"));
-  gtk_table_attach(GTK_TABLE(table), label, 0,1,12,13,
-                   (GtkAttachOptions) (GTK_FILL),
-                   (GtkAttachOptions) (0), 0, 0);
-
-  copyright = gtk_entry_new();
-  SET_TEXT(copyright);
-  gtk_table_attach(GTK_TABLE(table), copyright, 1,2,12,13,
-                   (GtkAttachOptions) (GTK_FILL),
-                   (GtkAttachOptions) (0), 0, 0);
-
-  /** Footer **/
-  label = gtk_label_new(_("Footer"));
-  gtk_table_attach(GTK_TABLE(table), label, 0,1,13,14,
-                   (GtkAttachOptions) (GTK_FILL),
-                   (GtkAttachOptions) (0), 0, 0);
-
-  footer = gtk_entry_new();
-  SET_TEXT(footer);
-  gtk_table_attach(GTK_TABLE(table), footer, 1,2,13,14,
-                   (GtkAttachOptions) (GTK_FILL),
-                   (GtkAttachOptions) (0), 0, 0);
-
-  /** Tagline **/
-  label = gtk_label_new(_("Tagline"));
-  gtk_table_attach(GTK_TABLE(table), label, 0,1,14,15,
-                   (GtkAttachOptions) (GTK_FILL),
-                   (GtkAttachOptions) (0), 0, 0);
-
-  tagline = gtk_entry_new();
-  SET_TEXT(tagline);
-  gtk_table_attach(GTK_TABLE(table), tagline, 1,2,14,15,
-                   (GtkAttachOptions) (GTK_FILL),
-                   (GtkAttachOptions) (0), 0, 0);
-
-
-  if(isnotebook)
-    {
-      gtk_notebook_append_page (GTK_NOTEBOOK (notebook), table, NULL);
-      gtk_notebook_set_tab_label_text (GTK_NOTEBOOK (notebook), table,
-                                       _("Score Header"));
-    }
-  else
-    {
-      gtk_box_pack_start(GTK_BOX(GTK_DIALOG(notebook)->vbox), table, TRUE, TRUE,0);
-    }
-  
-  setup->title = title;
-  setup->subtitle = subtitle;
-  setup->poet = poet;
-  setup->composer = composer;
-  setup->meter = meter;
-  setup->opus = opus;
-  setup->arranger = arranger;
-  setup->instrument = instrument;
-  setup->dedication = dedication;
-  setup->piece = piece;
-  setup->head = head;
-  setup->copyright = copyright;
-  setup->footer = footer;
-  setup->tagline = tagline;
-  score_status(gui, TRUE);
-  return setup;
-}
 
 /**
  * Function to set the printed score parameters
@@ -986,12 +751,9 @@ void setpaperconfig(papersetupcb *cbdata, DenemoGUI *gui)
   g_string_assign(gui->lilycontrol.lilyversion, 
 		  (gchar *)gtk_entry_get_text 
 		  (GTK_ENTRY (cbdata->lilyversion)));
-  g_string_assign(gui->lilycontrol.lilypond, 
-		  (gchar *)gtk_entry_get_text 
-		  (GTK_ENTRY (cbdata->lilypond)));
 
-  gui->lilycontrol.fontsize = 
-    atoi((gchar *) gtk_entry_get_text 
+  g_string_assign(gui->lilycontrol.staffsize,
+    (gchar *) gtk_entry_get_text 
 	 (GTK_ENTRY (GTK_BIN (cbdata->fontsize)->child)));
   if(gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(cbdata->portrait)))
     {
@@ -1026,9 +788,9 @@ static void applykeytimesig_settings(wizarddata *wdata)
   si->tempo = atoi( (gchar *) gtk_entry_get_text (GTK_ENTRY (tsetup->tempo)));
   /*apply timesig*/
 
-  curstaffstruct->stime1 = 
+  curstaffstruct->timesig.time1 = 
     gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (tsetup->numerator));
-  curstaffstruct->stime2 = 
+  curstaffstruct->timesig.time2 = 
     gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (tsetup->denominator));
 
   // wdata->gui->haschanged = TRUE;???????? why was this set???
@@ -1063,7 +825,7 @@ static void applykeytimesig_settings(wizarddata *wdata)
 static void setupscore(GtkButton *button, wizarddata *wdata)
 {
   setpaperconfig(wdata->paper, wdata->gui);
-  applyheader_settings(wdata->hsetup,wdata->gui);
+  //applyheader_settings(wdata->hsetup,wdata->gui);
   applykeytimesig_settings(wdata);
   setstaffconfig(wdata, wdata->gui->si);
   score_status(wdata->gui, TRUE);
@@ -1136,7 +898,7 @@ void scorewizard(GtkAction *action, gpointer param)
 
   /* create pages of notebook */
   wdata->paper = papersetup (wdata->notebook, gui, TRUE);
-  wdata->hsetup = headersetup (wdata->notebook, gui, TRUE);
+  //wdata->hsetup = headersetup (wdata->notebook, gui, TRUE);
   instrumentsetup(wdata);
   wdata->tsetup = timekeysig (wdata, TRUE);
 
