@@ -20,6 +20,9 @@
 #include <gtk/gtk.h>
 #include "calculatepositions.h"
 #include "commandfuncs.h"
+#ifdef _HAVE_JACK_
+#include "jackmidi.h"
+#endif
 
 /**
  * Return the first object node of the given measure
@@ -101,12 +104,13 @@ setcurrentprimarystaff (DenemoScore * si)
 static void
 copy_staff_bits (DenemoStaff * src, DenemoStaff * dest)
 {
-  dest->sclef = src->sclef;
-  dest->skey = src->skey;
-  dest->skey_isminor = src->skey_isminor;
-  memcpy (dest->skeyaccs, src->skeyaccs, SEVENGINTS);
-  dest->stime1 = src->stime1;
-  dest->stime2 = src->stime2;
+  dest->clef.type = src->clef.type;//other fields - take care if dynamic
+  dest->keysig.number = src->keysig.number;
+  dest->keysig.isminor = src->keysig.isminor;
+  memcpy (dest->keysig.accs, src->keysig.accs, SEVENGINTS);
+  dest->timesig.time1 = src->timesig.time1;
+  dest->timesig.time2 = src->timesig.time2;
+  dest->volume = 65;
   dest->no_of_lines = 5;
   dest->transposition = 0;
   dest->pos_in_half_lines = 0;
@@ -179,7 +183,7 @@ newstaff (DenemoGUI * gui, enum newstaffcallbackaction action,
   DenemoScore *si = gui->si;
   g_assert (si != NULL);
   /* What gets added */
-  gint ret = -1;
+  gint ret = -1, err;
   DenemoStaff *thestaffstruct =
     (DenemoStaff *) g_malloc (sizeof (DenemoStaff));
   struct newstaffinfotopass itp;
@@ -196,19 +200,18 @@ newstaff (DenemoGUI * gui, enum newstaffcallbackaction action,
       action = INITIAL;
       n = 1;
 
-      thestaffstruct->sclef = DENEMO_TREBLE_CLEF;
-      thestaffstruct->skey = 0;
-      thestaffstruct->skey_isminor = FALSE;
-      memset (thestaffstruct->skeyaccs, 0, SEVENGINTS);
-      thestaffstruct->stime1 = 4;
-      thestaffstruct->stime2 = 4;
-
+      thestaffstruct->clef.type = DENEMO_TREBLE_CLEF;
+      thestaffstruct->keysig.number = 0;
+      thestaffstruct->keysig.isminor = FALSE;
+      memset (thestaffstruct->keysig.accs, 0, SEVENGINTS);
+      thestaffstruct->timesig.time1 = 4;
+      thestaffstruct->timesig.time2 = 4;
+      thestaffstruct->volume = 65;
       thestaffstruct->no_of_lines = 5;
       thestaffstruct->transposition = 0;
       thestaffstruct->pos_in_half_lines = 0;
       thestaffstruct->space_above = 0;
       thestaffstruct->space_below = 0;
-      thestaffstruct->volume = 128;
       thestaffstruct->nummeasures = 1;
 
 #if 0
@@ -291,8 +294,8 @@ newstaff (DenemoGUI * gui, enum newstaffcallbackaction action,
 		      numstaffs + 1);
   set_lily_name (thestaffstruct->denemo_name, thestaffstruct->lily_name);
   thestaffstruct->midi_instrument = g_string_new ("acoustic grand");
-  thestaffstruct->leftmost_time1context = thestaffstruct->stime1;
-      thestaffstruct->leftmost_time2context = thestaffstruct->stime2;
+  thestaffstruct->leftmost_timesig = &thestaffstruct->timesig;
+
   /* In what position should the scrollbar be added?  */
   switch (action)
     {
@@ -322,6 +325,7 @@ newstaff (DenemoGUI * gui, enum newstaffcallbackaction action,
   itp.gui = gui;
   itp.staff = thestaffstruct;
   itp.addat = addat;
+  
   if (action != INITIAL && action != ADDFROMLOAD)
     {
       if (action == NEWVOICE)
@@ -332,8 +336,8 @@ newstaff (DenemoGUI * gui, enum newstaffcallbackaction action,
 	}
       else
 	{
+	  thestaffstruct->jack_midi_out_port = -1;
 	  ret = staff_properties_change (&itp);
-
 	  if (ret)
 	    {
 	      /* 
@@ -364,6 +368,9 @@ newstaff (DenemoGUI * gui, enum newstaffcallbackaction action,
       insert_staff (si, thestaffstruct, action, addat);
       si->leftmeasurenum = 1;
     }
+#ifdef _HAVE_JACK_
+      thestaffstruct->jack_midi_out_port = create_jack_midi_port(thestaffstruct->lily_name->str);
+#endif
 
   //si->haschanged = TRUE;
 }
@@ -394,18 +401,24 @@ void
 deletestaff (DenemoGUI * gui, gboolean interactive)
 {
   DenemoScore *si = gui->si;
+  DenemoStaff *curstaffstruct = si->currentstaff->data;
+ 
+#ifdef _HAVE_JACK_
+  int err = remove_jack_midi_port(curstaffstruct->jack_midi_out_port);
+#endif
+
   if(interactive && !confirm_deletestaff_custom_scoreblock(gui))
     return;
   if(si->currentstaff==NULL)
     return;
-  DenemoStaff *curstaffstruct = si->currentstaff->data;
-
+  
   gboolean give_info=FALSE;//give info about removing matching context
   if(interactive && (curstaffstruct->context!=DENEMO_NONE) &&
      (!confirm("A context is set on this staff", "You will need to alter/delete the matching staff; Proceed?")))
     return;
   if(interactive &&  (curstaffstruct->context!=DENEMO_NONE))
     give_info = TRUE;
+    
   gboolean isprimary = ((int) curstaffstruct->voicenumber == 1);
   //FIXME free_staff()
   g_list_foreach (curstaffstruct->measures, freeobjlist, NULL);
@@ -414,6 +427,11 @@ deletestaff (DenemoGUI * gui, gboolean interactive)
   g_string_free (curstaffstruct->lily_name, FALSE);
   g_string_free (curstaffstruct->midi_instrument, FALSE);
   g_free (curstaffstruct);
+
+  free_directives(curstaffstruct->staff_directives);
+  free_directives(curstaffstruct->timesig.directives);
+  free_directives(curstaffstruct->keysig.directives);
+
   if(si->currentstaff==g_list_last(si->thescore))
     si->currentstaffnum--;//deleting the last, so the currentstaffnum must decrease
   si->thescore = g_list_delete_link (si->thescore, si->currentstaff);
@@ -432,11 +450,19 @@ deletestaff (DenemoGUI * gui, gboolean interactive)
     }
 
   //FIXME none of this works to get the current measure stem direction correct
-      setcurrents (si);
+  setcurrents (si);
       //     find_xes_in_all_measures (si);
       //   beamsandstemdirswholestaff ((DenemoStaff *) si->currentstaff->data);
       //   si->markstaffnum = 0;
       //  displayhelper (gui);
+  //  if(gui->si->currentstaffnum > gui->si->top_staff)
+  //    gui->si->top_staff++;
+  //  else
+  if(gui->si->currentstaffnum < gui->si->top_staff)
+    gui->si->top_staff = gui->si->currentstaffnum; 
+  update_vscrollbar (gui);
+
+  displayhelper (gui);
   score_status(gui,TRUE);
   if(give_info)
     infodialog ("The staff deleted had a start/end context; if you still have the staff with the matching end/start context\n then you should remove it (or its context) now.\nSee Staff->properties->context\nYou will not be able to print with miss-matched contexts.");
@@ -454,9 +480,9 @@ beamsandstemdirswholestaff (DenemoStaff * thestaff)
   measurenode *curmeasure;
   gint nclef, time1, time2, stem_directive;
 
-  nclef = thestaff->sclef;
-  time1 = thestaff->stime1;
-  time2 = thestaff->stime2;
+  nclef = thestaff->clef.type;
+  time1 = thestaff->timesig.time1;
+  time2 = thestaff->timesig.time2;
   stem_directive = DENEMO_STEMBOTH;
 
   for (curmeasure = thestaff->measures; curmeasure;
@@ -479,8 +505,8 @@ showwhichaccidentalswholestaff (DenemoStaff * thestaff)
   gint feednum;
   measurenode *curmeasure;
 
-  memcpy (feed, thestaff->skeyaccs, SEVENGINTS);
-  feednum = thestaff->skey;
+  memcpy (feed, thestaff->keysig.accs, SEVENGINTS);
+  feednum = thestaff->keysig.number;
   for (curmeasure = thestaff->measures; curmeasure;
        curmeasure = curmeasure->next)
     feednum =
@@ -495,10 +521,10 @@ showwhichaccidentalswholestaff (DenemoStaff * thestaff)
 void
 fixnoteheights (DenemoStaff * thestaff)
 {
-  gint nclef = thestaff->sclef;
-  gint time1 = thestaff->stime1;
-  gint time2 = thestaff->stime2;
-  gint initialclef;
+  gint nclef = thestaff->clef.type;
+  //gint time1 = thestaff->stime1;//USELESS
+  //gint time2 = thestaff->stime2;//USELESS
+  //gint initialclef;//USELESS
   measurenode *curmeasure;
   objnode *curobj;
   DenemoObject *theobj;
@@ -506,7 +532,7 @@ fixnoteheights (DenemoStaff * thestaff)
   for (curmeasure = thestaff->measures; curmeasure;
        curmeasure = curmeasure->next)
     {
-      initialclef = nclef;
+      //initialclef = nclef;
       for (curobj = (objnode *) curmeasure->data; curobj;
 	   curobj = curobj->next)
 	{
@@ -516,9 +542,9 @@ fixnoteheights (DenemoStaff * thestaff)
 	    case CHORD:
 	      newclefify (theobj, nclef);
 	      break;
-	    case TIMESIG:
-	      time1 = ((timesig *) theobj->object)->time1;
-	      time2 = ((timesig *) theobj->object)->time2;
+	    case TIMESIG://USELESS
+	      //time1 = ((timesig *) theobj->object)->time1;
+	      // time2 = ((timesig *) theobj->object)->time2;
 	      break;
 	    case CLEF:
 	      nclef = ((clef *) theobj->object)->type;
