@@ -21,6 +21,16 @@
 #include "binreloc.h"
 #endif
 
+
+/**
+   Popups up the menu named.
+ */
+void popup_menu(gchar *name) {
+  GtkWidget *menu = gtk_ui_manager_get_widget (Denemo.ui_manager, name);
+ gtk_menu_popup (GTK_MENU(menu), NULL, NULL, NULL, NULL,0, gtk_get_current_event_time()); 
+}
+
+
 /**
  * Pops up a warning dialog and blocks until it is dismissed
  *  @param msg warning message to display
@@ -193,30 +203,37 @@ setpixelmin (DenemoObject * theobj)
       chordval = *(chord *) theobj->object;
       baseduration = chordval.baseduration;
       headtype = MIN (baseduration, 2);
+      gint directive_pixels = 0;// the largest amount of extra space asked for by any directive
+      GList *g = chordval.directives;
+      for(;g;g=g->next)
+	directive_pixels =  MAX(directive_pixels, ((DenemoDirective*)g->data)->minpixels);
       if (chordval.notes)
 	{
-	  /* if (theobj->isstart_beamgroup && theobj->isend_beamgroup &&
-	     chordval.is_stemup)
-	     theobj->minpixelsalloted = headwidths[headtype] + STEM_WIDTH;
-	     else
-	     theobj->minpixelsalloted = headwidths[headtype];  */
-	  /* We can get away with that because the stems are narrower
-	   * than even the narrowest notes; upstemmed notes are
-	   * the unusual case here */
-
-	  /* The above code will allow extra space for the stem of
-	   * stemup notes. It's commented out 'cause we no longer want
-	   * that behavior */
 	  theobj->minpixelsalloted = headwidths[headtype];
+	  //search through notes and their attached directives, find max display space requested
+	  //use this below
+	  
+	  g=chordval.notes;
+	  for(;g;g=g->next) {
+	    GList *h = ((note *)g->data)->directives;
+	  for(;h;h=h->next)
+	    directive_pixels = MAX(directive_pixels, ((DenemoDirective*)h->data)->minpixels);
+	  }
 	}
       else			/* a rest */
 	theobj->minpixelsalloted = restwidths[baseduration];
 
+      // Allow extra space specified by attached LilyPond directives - example:     
+      theobj->minpixelsalloted += directive_pixels;
+
+
+
       /* 12 pixels for the first dot, 6 for each dot thereafter */
       if (chordval.numdots)
 	theobj->minpixelsalloted += 6;
       for (i = 0; i < chordval.numdots; i++)
 	theobj->minpixelsalloted += 6;
+
       theobj->space_before = 0;
       if (chordval.hasanacc)
 	for (tnode = chordval.notes; tnode; tnode = tnode->next)
@@ -251,7 +268,10 @@ setpixelmin (DenemoObject * theobj)
       theobj->space_before = 0;
       break;
     case LILYDIRECTIVE:
-      //theobj->minpixelsalloted = 8;
+      {
+	DenemoDirective *directive = (DenemoDirective*)theobj->object;	
+	theobj->minpixelsalloted = directive->minpixels;
+      }
       break;
     case CLEF:
       theobj->minpixelsalloted = 35;
@@ -415,12 +435,12 @@ void *chord2lilyduration(struct chord *chordobject, GString *ret){
 
 void *chord2lilybaseduration(struct chord *chordobject, GString *ret){
   int baseduration = chordobject->baseduration;
-  g_string_append_printf (ret, baseduration);
+  g_string_append_printf (ret,  "%d", baseduration);
 }
 
 void *chord2lilynumdots(struct chord *chordobject, GString *ret){
   int numdots = chordobject->numdots;
-  g_string_append_printf (ret, numdots);
+  g_string_append_printf (ret, "%d",numdots);
 }
 
 /**
@@ -761,10 +781,14 @@ void write_status(DenemoGUI *gui) {
 	GList *g;
 	for(g= thechord->notes;g;g=g->next) {
 	  note *thenote = (note *) g->data;
-	  if(thenote->postfix || thenote->prefix) {
-	    gchar *old = selection;
-	    selection = g_strdup_printf("%.50s (%s) %.50s",thenote->prefix?thenote->prefix->str:"",selection,  thenote->postfix? thenote->postfix->str:"");
-	    g_free(old);
+	  GList *h;
+	  for(h=thenote->directives;h;h=h->next) {
+	    DenemoDirective *directive= (DenemoDirective *)h->data;
+	    if(directive->postfix || directive->prefix) {
+	      gchar *old = selection;
+	      selection = g_strdup_printf("%.50s (%s) %.50s",directive->prefix?directive->prefix->str:"",selection, directive->postfix? directive->postfix->str:"");
+	      g_free(old);
+	    }
 	  }
 	}
       }
@@ -819,8 +843,13 @@ void write_status(DenemoGUI *gui) {
       break;
 
     case LILYDIRECTIVE:
-      selection = g_strdup_printf("Lily directive: %.50s", ((GString *)((lilydirective *) curObj->object)->directive)->str);
+      {
+	DenemoDirective *directive = (DenemoDirective *)curObj->object;
+	
+      selection = g_strdup_printf("Lily directive: %.50s", directive->postfix?directive->postfix->str:directive->prefix?directive->prefix->str:directive->graphic_name?directive->graphic_name->str:directive->display?directive->display->str:"empty");
+      }
       break;
+
     case FAKECHORD:
       selection = g_strdup_printf("Fakechord"   );
       break;
@@ -834,13 +863,10 @@ void write_status(DenemoGUI *gui) {
     selection = g_strdup_printf("Cursor not on any object");
 
   gchar *status;
-  if(gui->si->headerinfo.subtitle->len)
-    status = gui->si->headerinfo.subtitle->str;
-  else if(gui->si->headerinfo.piece->len)
-    status = gui->si->headerinfo.piece->str;
-  else
-    status = "";
-  status = g_strdup_printf("%s: %s", status, selection);
+
+  status = "Movement";
+  gint index = g_list_index(gui->movements, gui->si);
+  status = g_strdup_printf("%s %d: %s", status, index+1, selection);
 
   g_free(selection);
   gtk_statusbar_pop(GTK_STATUSBAR (Denemo.statusbar), Denemo.status_context_id);
@@ -975,3 +1001,46 @@ string_dialog_entry_with_widget (DenemoGUI *gui, gchar *wlabel, gchar *direction
 	}
 
 }
+
+static gboolean
+option_choice(GtkWidget *widget, DenemoDirective **response) {
+  if( gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget)))
+    *response = g_object_get_data(G_OBJECT(widget), "choice");
+  return TRUE;
+}
+
+/* run a dialog for the user to select a string from the NULL separated strings, str
+ return NULL if user cancels.*/ 
+gchar * get_option(gchar *str, gint length) {
+  gchar *response=NULL;
+  GtkWidget *dialog = gtk_dialog_new_with_buttons ("Select an Option (or Cancel)",
+						   GTK_WINDOW (Denemo.window),
+						   (GtkDialogFlags) (GTK_DIALOG_MODAL |
+								     GTK_DIALOG_DESTROY_WITH_PARENT),
+						   GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
+						   GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
+						   NULL);
+  GtkWidget *vbox = gtk_vbox_new(FALSE, 8);
+  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), vbox,
+		      TRUE, TRUE, 0);
+  gchar *opt;
+  gint i;
+  GtkWidget *widget1, *widget2, *widget;
+  for(opt = str;(opt-str)<length;opt += strlen(opt)+1) {
+    if(opt==str) {
+      widget = widget1 =   gtk_radio_button_new_with_label(NULL, opt);
+      response = opt;
+    } else {
+      widget =  widget2  =   gtk_radio_button_new_with_label_from_widget(GTK_RADIO_BUTTON (widget1), opt);
+    }	
+    g_object_set_data(G_OBJECT(widget), "choice", (gpointer)opt);
+    g_signal_connect(G_OBJECT(widget), "toggled", G_CALLBACK(option_choice), &response);
+    gtk_box_pack_start (GTK_BOX (vbox), widget, FALSE, TRUE, 0);
+  }
+  gtk_widget_show_all (dialog);
+  if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_REJECT){ 
+    response = NULL;
+  }
+  gtk_widget_destroy(dialog);
+  return response;
+}
