@@ -5,13 +5,15 @@
  * also includes useful constants
  *
  * for Denemo, a gtk+ frontend to GNU Lilypond
- * (c) 1999-2005 Matthew Hiller
+ * (c) 1999-2005 Matthew Hiller, 2008, 2009 Richard Shann
  */
 #ifndef UTILS_H
 #define UTILS_H
 
 #include <denemo/denemo.h>
 
+#define MAXEXTRASPACE (150) /* maximum space for ledger lines, for sanity */
+
 #define LINE_SPACE 10
 #define HALF_LINE_SPACE 5
 #define NO_OF_LINES 5
@@ -20,7 +22,7 @@
 #define MID_STAFF_HEIGHT 2*LINE_SPACE
 #define LEFT_MARGIN 20
 #define KEY_MARGIN (LEFT_MARGIN+35)
-#define SPACE_FOR_TIME 30
+#define SPACE_FOR_TIME 35
 #define RIGHT_MARGIN 20
 #define SPACE_FOR_BARLINE 10
 #define HALF_BARLINE_SPACE 5
@@ -93,6 +95,9 @@ setpixelmin (DenemoObject *theobj);
 void
 freeit (gpointer data, gpointer user_data);
 
+void 
+popup_menu(gchar *name);
+
 void
 warningdialog(gchar *msg);
 void
@@ -138,7 +143,7 @@ void *chord2lilyduration(struct chord *chordobject, GString *ret);
 void *chord2lilynumdots(struct chord *chordobject, GString *ret);	
 
 #define UTILS_H_PARAM_ASSIGN(param_name) if( (str = g_strstr_len(values->str+i,strlen(values->str+i), #param_name)))\
-param_name = (*(str+strlen(#param_name))=='=')?str+strlen(#param_name)+1:NULL;
+nothing=FALSE,param_name = (*(str+strlen(#param_name))=='=')?str+strlen(#param_name)+1:NULL;
 
 #define GET_1PARAM(action, param, param_name) \
 gchar * query = NULL;\
@@ -149,6 +154,7 @@ gchar * param_name = NULL;\
     param = &dummy;\
   param->status = FALSE;\
 if(!action && param){\
+    gboolean nothing=TRUE;\
     GString *values = ((DenemoScriptParam *)param)->string;\
     if(values) {\
       gchar *str;\
@@ -172,6 +178,7 @@ gchar * param_name2 = NULL;\
     param = &dummy;\
   param->status = FALSE;\
 if(!action && param){\
+    gboolean nothing=TRUE;\
     GString *values = ((DenemoScriptParam *)param)->string;\
     if(values) {\
      gchar *str;\
@@ -182,7 +189,7 @@ if(!action && param){\
           UTILS_H_PARAM_ASSIGN(param_name2)\
        }\
      }\
-     if(param_name1==NULL)\
+     if(nothing)\
       param_name1=values?values->str:NULL;\
 }
 #define GET_3PARAMS(action, param, param_name1, param_name2, param_name3) \
@@ -196,6 +203,7 @@ gchar * param_name3 = NULL;\
     param = &dummy;\
   param->status = FALSE;\
 if(!action && param){\
+    gboolean nothing=TRUE;\
     GString *values = ((DenemoScriptParam *)param)->string;\
     if(values) {\
      gchar *str;\
@@ -207,7 +215,7 @@ if(!action && param){\
           UTILS_H_PARAM_ASSIGN(param_name3)\
        }\
      }\
-     if(param_name1==NULL)\
+     if(nothing)\
       param_name1=values?values->str:NULL;\
 }
 #define GET_4PARAMS(action, param, param_name1, param_name2, param_name3, param_name4) \
@@ -223,6 +231,7 @@ gchar * param_name4 = NULL;\
   param->status = FALSE;\
 if(!action && param){\
     GString *values = ((DenemoScriptParam *)param)->string;\
+    gboolean nothing=TRUE;\
     if(values) {\
      gchar *str;\
      gint i;\
@@ -234,9 +243,10 @@ if(!action && param){\
           UTILS_H_PARAM_ASSIGN(param_name4)\
        }\
      }\
-     if(param_name1==NULL)\
+     if(nothing)\
       param_name1=values?values->str:NULL;\
 }
 
+gchar * get_option(gchar *str, gint length);
 
 #endif /* UTILS_H */
