@@ -45,7 +45,7 @@
 #define EXTRA_ACCELS "extra.accels"
 
 
-void newview(GtkAction*, gpointer param);
+/* void newview(GtkAction*, gpointer param); */
 
 void free_gui(DenemoGUI *gui);/* frees all movement data from gui, leaving gui interface intact */
 void addhistorymenuitem(gchar *filename);
@@ -63,6 +63,8 @@ void	  unhighlight_rhythm(RhythmPattern *r);
 void	  highlight_duration(DenemoGUI *gui, gint dur);
 void	  highlight_rest(DenemoGUI *gui, gint dur);
 
+gboolean loadGraphicItem(gchar *name, GdkBitmap **xbm, gint *width, gint *height );
+
 
 gchar *getSchemeText(void); 
 void deleteSchemeText(void);
@@ -75,4 +77,9 @@ void
 create_scheme_function_for_script(gchar *name);
 void 
 inner_main(void*closure, int argc, char **argv);
+
+gchar *
+create_xbm_data_from_pixbuf (GdkPixbuf *pixbuf, int lox, int loy, int hix, int hiy);
+gchar *
+get_icon_for_name(gchar *name, gchar *label);
 #endif
